--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'SQL_ASCII';
SET standard_conforming_strings = on;
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: plpgsql; Type: EXTENSION; Schema: -; Owner: 
--

CREATE EXTENSION IF NOT EXISTS plpgsql WITH SCHEMA pg_catalog;


--
-- Name: EXTENSION plpgsql; Type: COMMENT; Schema: -; Owner: 
--

COMMENT ON EXTENSION plpgsql IS 'PL/pgSQL procedural language';


SET search_path = public, pg_catalog;

--
-- Name: add_user(bigint, numeric, integer, integer); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION add_user(bigint, numeric, integer, integer) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into users (user_id, credit, owner_id, group_id) values ($1, $2, $3, $4);
return 1;
END;
$_$;


ALTER FUNCTION public.add_user(bigint, numeric, integer, integer) OWNER TO ibs;

--
-- Name: change_user_credit(bigint, numeric); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION change_user_credit(bigint, numeric) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
    update users set credit = credit + $2 where user_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.change_user_credit(bigint, numeric) OWNER TO ibs;

--
-- Name: delete_group_attr(bigint, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION delete_group_attr(bigint, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
delete from group_attrs where attr_name = $2 and group_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.delete_group_attr(bigint, text) OWNER TO ibs;

--
-- Name: delete_normal_user(bigint); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION delete_normal_user(bigint) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
delete from normal_users where user_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.delete_normal_user(bigint) OWNER TO ibs;

--
-- Name: delete_user_attr(bigint, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION delete_user_attr(bigint, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
delete from user_attrs where attr_name = $2 and user_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.delete_user_attr(bigint, text) OWNER TO ibs;

--
-- Name: get_mail_dir(text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION get_mail_dir(text) RETURNS text
    LANGUAGE plpgsql
    AS $_$
DECLARE
  mail_dir text;
BEGIN
select into mail_dir email_attr.attr_value||'/' from user_attrs as email_attr
					    where 
					email_attr.attr_name = 'email_address'
					    and 
					email_attr.attr_value = $1 
					    and not exists 
					(select user_attrs.user_id 
					    from 
					user_attrs 
					    where 
					user_attrs.user_id=email_attr.user_id 
					    and 
					user_attrs.attr_name='lock');
return mail_dir;
END;
$_$;


ALTER FUNCTION public.get_mail_dir(text) OWNER TO ibs;

--
-- Name: get_mail_quota(text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION get_mail_quota(text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
  quota INTEGER;
BEGIN
select into quota attr_value::integer 
	    from 
	user_attrs 
	    where 
	attr_name='mail_quota' 
	    and exists(
	select email_attr.user_id 
	    from 
	user_attrs as email_attr
	    where 
	user_attrs.user_id=email_attr.user_id 
	    and 
	email_attr.attr_name = 'email_address'
	    and
	email_attr.attr_value = $1); 
	    
IF NOT FOUND THEN
  select into quota attr_value::integer 
	from 
    group_attrs 
	where 
    attr_name='mail_quota' 
	and exists(
    select user_attrs.user_id 
	from 
    user_attrs,users 
	where 
    attr_name='email_address'
	and
    attr_value=$1 
	and 
    user_attrs.user_id=users.user_id 
	and 
    group_attrs.group_id=users.group_id); 
END IF;	
return quota;
END;
$_$;


ALTER FUNCTION public.get_mail_quota(text) OWNER TO ibs;

--
-- Name: insert_connection_log(bigint, numeric, timestamp without time zone, timestamp without time zone, boolean, smallint, integer, text[], text[]); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_connection_log(bigint, numeric, timestamp without time zone, timestamp without time zone, boolean, smallint, integer, text[], text[]) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
    l_user_id alias for $1;
    l_credit_used alias for $2;
    l_login_time alias for $3;
    l_logout_time alias for $4;
    l_successful alias for $5;
    l_service alias for $6;
    l_ras_id alias for $7;
    l_names_array alias for $8;
    l_values_array alias for $9;
    l_connection_log_id integer;
BEGIN
    l_connection_log_id := nextval('connection_log_id');
    insert into connection_log (connection_log_id, user_id, credit_used, login_time, logout_time, successful, service, ras_id)
				values
			       (l_connection_log_id, l_user_id, l_credit_used, l_login_time, l_logout_time, l_successful, l_service, l_ras_id);

    FOR i in array_lower(l_names_array,1) .. array_upper(l_names_array,1) LOOP
	insert into connection_log_details (connection_log_id, name, value) 
					    values
					   (l_connection_log_id, l_names_array[i], l_values_array[i]);
    END LOOP;
    return 1;
END;
$_$;


ALTER FUNCTION public.insert_connection_log(bigint, numeric, timestamp without time zone, timestamp without time zone, boolean, smallint, integer, text[], text[]) OWNER TO ibs;

--
-- Name: insert_group_attr(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_group_attr(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into group_attrs (group_id, attr_name, attr_value) values($1,$2,$3);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_group_attr(bigint, text, text) OWNER TO ibs;

--
-- Name: insert_ias_event(bigint, smallint, text, numeric, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_ias_event(bigint, smallint, text, numeric, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into ias_event (event_id, event_type, actor, amount, destinations, comment) values ($1, $2, $3, $4, $5, $6);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_ias_event(bigint, smallint, text, numeric, text, text) OWNER TO ibs;

--
-- Name: insert_normal_user(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_normal_user(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into normal_users (user_id, normal_username, normal_password) values($1,$2,$3);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_normal_user(bigint, text, text) OWNER TO ibs;

--
-- Name: insert_user_attr(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_user_attr(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into user_attrs (user_id, attr_name, attr_value) values($1,$2,$3);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_user_attr(bigint, text, text) OWNER TO ibs;

--
-- Name: insert_user_audit_log(integer, boolean, bigint, text, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_user_audit_log(integer, boolean, bigint, text, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
insert into user_audit_log (admin_id, is_user, object_id, attr_name, old_value, new_value) values ($1, $2, $3, $4, $5, $6);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_user_audit_log(integer, boolean, bigint, text, text, text) OWNER TO ibs;

--
-- Name: insert_web_analyzer_log(timestamp without time zone, bigint, inet, text, integer, integer, smallint, smallint, smallint, smallint, integer); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION insert_web_analyzer_log(timestamp without time zone, bigint, inet, text, integer, integer, smallint, smallint, smallint, smallint, integer) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
    _id bigint;
BEGIN
select into _id nextval('web_analyzer_log_log_id');
insert into web_analyzer_log (log_id, _date, user_id, ip_addr, url, elapsed, bytes, miss, hit, successful, failure, _count ) values(_id,$1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11);
return 1;
END;
$_$;


ALTER FUNCTION public.insert_web_analyzer_log(timestamp without time zone, bigint, inet, text, integer, integer, smallint, smallint, smallint, smallint, integer) OWNER TO ibs;

--
-- Name: update_group_attr(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION update_group_attr(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
update group_attrs set attr_value = $3 where attr_name = $2 and group_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.update_group_attr(bigint, text, text) OWNER TO ibs;

--
-- Name: update_normal_user(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION update_normal_user(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
update normal_users set normal_username = $2, normal_password = $3 where user_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.update_normal_user(bigint, text, text) OWNER TO ibs;

--
-- Name: update_user_attr(bigint, text, text); Type: FUNCTION; Schema: public; Owner: ibs
--

CREATE FUNCTION update_user_attr(bigint, text, text) RETURNS integer
    LANGUAGE plpgsql
    AS $_$
DECLARE
BEGIN
update user_attrs set attr_value = $3 where attr_name = $2 and user_id = $1;
return 1;
END;
$_$;


ALTER FUNCTION public.update_user_attr(bigint, text, text) OWNER TO ibs;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: add_user_save_details; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE add_user_save_details (
    add_user_save_id integer NOT NULL,
    user_id bigint NOT NULL,
    username text,
    password text
);


ALTER TABLE public.add_user_save_details OWNER TO ibs;

--
-- Name: add_user_save_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE add_user_save_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.add_user_save_id_seq OWNER TO ibs;

--
-- Name: add_user_saves; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE add_user_saves (
    add_user_save_id integer NOT NULL,
    add_date timestamp without time zone DEFAULT now(),
    admin_id integer,
    type integer,
    comment text
);


ALTER TABLE public.add_user_saves OWNER TO ibs;

--
-- Name: admin_deposit_change; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_deposit_change (
    admin_deposit_change_id integer NOT NULL,
    admin_id integer,
    to_admin_id integer,
    deposit_change numeric(12,2),
    change_time timestamp without time zone DEFAULT now(),
    remote_addr inet,
    comment text
);


ALTER TABLE public.admin_deposit_change OWNER TO ibs;

--
-- Name: admin_deposit_change_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE admin_deposit_change_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admin_deposit_change_id OWNER TO ibs;

--
-- Name: admin_locks; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_locks (
    lock_id bigint NOT NULL,
    locker_admin_id integer,
    admin_id integer,
    reason text
);


ALTER TABLE public.admin_locks OWNER TO ibs;

--
-- Name: admin_locks_lock_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE admin_locks_lock_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admin_locks_lock_id_seq OWNER TO ibs;

--
-- Name: admin_messages; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_messages (
    message_id bigint NOT NULL,
    user_id bigint,
    message_text text,
    post_date timestamp without time zone DEFAULT now()
);


ALTER TABLE public.admin_messages OWNER TO ibs;

--
-- Name: admin_messages_message_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE admin_messages_message_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admin_messages_message_id OWNER TO ibs;

--
-- Name: admin_perm_template_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE admin_perm_template_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admin_perm_template_id OWNER TO ibs;

--
-- Name: admin_perm_templates; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_perm_templates (
    template_id integer NOT NULL,
    template_name text
);


ALTER TABLE public.admin_perm_templates OWNER TO ibs;

--
-- Name: admin_perm_templates_detail; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_perm_templates_detail (
    template_id integer NOT NULL,
    perm_name text NOT NULL,
    perm_value text
);


ALTER TABLE public.admin_perm_templates_detail OWNER TO ibs;

--
-- Name: admin_perms; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admin_perms (
    admin_id integer NOT NULL,
    perm_name text NOT NULL,
    perm_value text
);


ALTER TABLE public.admin_perms OWNER TO ibs;

--
-- Name: admins; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admins (
    admin_id integer NOT NULL,
    username text,
    password character(34),
    deposit numeric(12,2) DEFAULT 0,
    due numeric(12,2) DEFAULT 0,
    name text,
    comment text,
    creator_id integer
);


ALTER TABLE public.admins OWNER TO ibs;

--
-- Name: admins_extended_attrs; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE admins_extended_attrs (
    admin_id integer NOT NULL,
    attr_name text NOT NULL,
    attr_value text
);


ALTER TABLE public.admins_extended_attrs OWNER TO ibs;

--
-- Name: admins_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE admins_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admins_id_seq OWNER TO ibs;

--
-- Name: bw_interface; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE bw_interface (
    interface_id integer NOT NULL,
    interface_name text,
    comment text
);


ALTER TABLE public.bw_interface OWNER TO ibs;

--
-- Name: bw_interface_interface_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE bw_interface_interface_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.bw_interface_interface_id_seq OWNER TO ibs;

--
-- Name: bw_leaf; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE bw_leaf (
    leaf_id integer NOT NULL,
    leaf_name text,
    interface_id integer,
    parent_id integer,
    default_rate_kbits integer,
    default_ceil_kbits integer,
    total_rate_kbits integer,
    total_ceil_kbits integer
);


ALTER TABLE public.bw_leaf OWNER TO ibs;

--
-- Name: bw_leaf_leaf_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE bw_leaf_leaf_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.bw_leaf_leaf_id_seq OWNER TO ibs;

--
-- Name: bw_leaf_services; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE bw_leaf_services (
    leaf_service_id integer NOT NULL,
    leaf_id integer,
    protocol text,
    filter text,
    rate_kbits integer,
    ceil_kbits integer
);


ALTER TABLE public.bw_leaf_services OWNER TO ibs;

--
-- Name: bw_leaf_services_leaf_service_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE bw_leaf_services_leaf_service_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.bw_leaf_services_leaf_service_id_seq OWNER TO ibs;

--
-- Name: bw_node; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE bw_node (
    node_id integer NOT NULL,
    interface_id integer,
    parent_id integer,
    rate_kbits integer,
    ceil_kbits integer
);


ALTER TABLE public.bw_node OWNER TO ibs;

--
-- Name: bw_node_node_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE bw_node_node_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.bw_node_node_id_seq OWNER TO ibs;

--
-- Name: bw_static_ip; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE bw_static_ip (
    bw_static_ip_id integer NOT NULL,
    ip inet,
    transmit_leaf_id integer,
    receive_leaf_id integer
);


ALTER TABLE public.bw_static_ip OWNER TO ibs;

--
-- Name: bw_static_ip_bw_static_ip_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE bw_static_ip_bw_static_ip_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.bw_static_ip_bw_static_ip_id_seq OWNER TO ibs;

--
-- Name: caller_id_users; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE caller_id_users (
    user_id bigint,
    caller_id text NOT NULL
);


ALTER TABLE public.caller_id_users OWNER TO ibs;

--
-- Name: charge_rule_day_of_weeks; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE charge_rule_day_of_weeks (
    charge_rule_id integer NOT NULL,
    day_of_week integer NOT NULL
);


ALTER TABLE public.charge_rule_day_of_weeks OWNER TO ibs;

--
-- Name: charge_rule_ports; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE charge_rule_ports (
    charge_rule_id integer NOT NULL,
    ras_port text NOT NULL
);


ALTER TABLE public.charge_rule_ports OWNER TO ibs;

--
-- Name: charge_rules; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE charge_rules (
    charge_id integer,
    charge_rule_id integer NOT NULL,
    start_time time without time zone,
    end_time time without time zone,
    time_limit integer,
    ras_id integer
);


ALTER TABLE public.charge_rules OWNER TO ibs;

--
-- Name: charge_rules_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE charge_rules_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.charge_rules_id_seq OWNER TO ibs;

--
-- Name: charges; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE charges (
    charge_id integer NOT NULL,
    name text,
    charge_type text,
    comment text,
    admin_id integer,
    visible_to_all boolean DEFAULT false
);


ALTER TABLE public.charges OWNER TO ibs;

--
-- Name: charges_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE charges_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.charges_id_seq OWNER TO ibs;

--
-- Name: connection_log; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE connection_log (
    connection_log_id bigint NOT NULL,
    user_id bigint,
    credit_used numeric(12,2),
    login_time timestamp without time zone,
    logout_time timestamp without time zone,
    successful boolean,
    service smallint,
    ras_id integer
);


ALTER TABLE public.connection_log OWNER TO ibs;

--
-- Name: connection_log_details; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE connection_log_details (
    connection_log_id bigint NOT NULL,
    name text NOT NULL,
    value text
);


ALTER TABLE public.connection_log_details OWNER TO ibs;

--
-- Name: connection_log_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE connection_log_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.connection_log_id OWNER TO ibs;

--
-- Name: credit_change; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE credit_change (
    credit_change_id bigint NOT NULL,
    admin_id integer,
    action smallint,
    per_user_credit numeric(12,2),
    admin_credit numeric(12,2),
    change_time timestamp without time zone DEFAULT now(),
    remote_addr inet,
    comment text
);


ALTER TABLE public.credit_change OWNER TO ibs;

--
-- Name: credit_change_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE credit_change_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.credit_change_id OWNER TO ibs;

--
-- Name: credit_change_userid; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE credit_change_userid (
    credit_change_id bigint NOT NULL,
    user_id bigint NOT NULL
);


ALTER TABLE public.credit_change_userid OWNER TO ibs;

--
-- Name: defs; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE defs (
    name text NOT NULL,
    value text,
    type text
);


ALTER TABLE public.defs OWNER TO ibs;

--
-- Name: group_attrs; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE group_attrs (
    group_id integer NOT NULL,
    attr_name text NOT NULL,
    attr_value text
);


ALTER TABLE public.group_attrs OWNER TO ibs;

--
-- Name: groups; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE groups (
    group_id integer NOT NULL,
    group_name text,
    owner_id integer,
    comment text
);


ALTER TABLE public.groups OWNER TO ibs;

--
-- Name: groups_group_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE groups_group_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.groups_group_id_seq OWNER TO ibs;

--
-- Name: ias_event; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ias_event (
    event_id bigint NOT NULL,
    event_type smallint,
    event_date timestamp without time zone DEFAULT now(),
    actor text,
    amount numeric(12,2),
    destinations text,
    comment text
);


ALTER TABLE public.ias_event OWNER TO ibs;

--
-- Name: ias_event_event_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE ias_event_event_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.ias_event_event_id OWNER TO ibs;

--
-- Name: ias_event_extended; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ias_event_extended (
    event_id bigint NOT NULL,
    name text NOT NULL,
    value text
);


ALTER TABLE public.ias_event_extended OWNER TO ibs;

--
-- Name: ibs_states; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ibs_states (
    name text NOT NULL,
    value text
);


ALTER TABLE public.ibs_states OWNER TO ibs;

--
-- Name: internet_bw_snapshot; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE internet_bw_snapshot (
    snp_date timestamp without time zone DEFAULT now() NOT NULL,
    user_id integer NOT NULL,
    in_rate integer,
    out_rate integer
);


ALTER TABLE public.internet_bw_snapshot OWNER TO ibs;

--
-- Name: internet_charge_rules; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE internet_charge_rules (
    cpm numeric(12,2),
    cpk numeric(12,2),
    assumed_kps integer,
    bandwidth_limit_kbytes integer DEFAULT (-1),
    bw_transmit_leaf_id integer,
    bw_receive_leaf_id integer
)
INHERITS (charge_rules);


ALTER TABLE public.internet_charge_rules OWNER TO ibs;

--
-- Name: internet_onlines_snapshot; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE internet_onlines_snapshot (
    snp_date timestamp without time zone DEFAULT now() NOT NULL,
    ras_id integer NOT NULL,
    value integer
);


ALTER TABLE public.internet_onlines_snapshot OWNER TO ibs;

--
-- Name: ippool; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ippool (
    ippool_id integer NOT NULL,
    ippool_name text,
    ippool_comment text
);


ALTER TABLE public.ippool OWNER TO ibs;

--
-- Name: ippool_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE ippool_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.ippool_id_seq OWNER TO ibs;

--
-- Name: ippool_ips; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ippool_ips (
    ippool_id integer NOT NULL,
    ip inet NOT NULL
);


ALTER TABLE public.ippool_ips OWNER TO ibs;

--
-- Name: normal_users; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE normal_users (
    user_id bigint,
    normal_username text,
    normal_password text
);


ALTER TABLE public.normal_users OWNER TO ibs;

--
-- Name: persistent_lan_users; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE persistent_lan_users (
    user_id bigint,
    persistent_lan_mac macaddr NOT NULL,
    persistent_lan_ip cidr NOT NULL,
    persistent_lan_ras_id integer
);


ALTER TABLE public.persistent_lan_users OWNER TO ibs;

--
-- Name: ras; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ras (
    ras_id integer NOT NULL,
    ras_description text,
    ras_ip inet,
    ras_type text,
    radius_secret text,
    active boolean DEFAULT true,
    comment text
);


ALTER TABLE public.ras OWNER TO ibs;

--
-- Name: ras_attrs; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ras_attrs (
    ras_id integer NOT NULL,
    attr_name text NOT NULL,
    attr_value text
);


ALTER TABLE public.ras_attrs OWNER TO ibs;

--
-- Name: ras_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE ras_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.ras_id_seq OWNER TO ibs;

--
-- Name: ras_ippools; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ras_ippools (
    serial integer NOT NULL,
    ras_id integer,
    ippool_id integer
);


ALTER TABLE public.ras_ippools OWNER TO ibs;

--
-- Name: ras_ippools_serial_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE ras_ippools_serial_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.ras_ippools_serial_seq OWNER TO ibs;

--
-- Name: ras_ippools_serial_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: ibs
--

ALTER SEQUENCE ras_ippools_serial_seq OWNED BY ras_ippools.serial;


--
-- Name: ras_ports; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE ras_ports (
    ras_id integer NOT NULL,
    port_name text NOT NULL,
    phone text,
    type text,
    comment text
);


ALTER TABLE public.ras_ports OWNER TO ibs;

--
-- Name: tariff_prefix_list; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE tariff_prefix_list (
    tariff_id integer,
    prefix_id integer NOT NULL,
    prefix_code text,
    prefix_name text,
    cpm numeric(12,2),
    free_seconds smallint,
    min_duration smallint,
    round_to smallint,
    min_chargable_duration smallint
);


ALTER TABLE public.tariff_prefix_list OWNER TO ibs;

--
-- Name: tariff_prefix_list_tariff_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE tariff_prefix_list_tariff_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.tariff_prefix_list_tariff_id_seq OWNER TO ibs;

--
-- Name: user_attrs; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE user_attrs (
    user_id bigint NOT NULL,
    attr_name text NOT NULL,
    attr_value text
);


ALTER TABLE public.user_attrs OWNER TO ibs;

--
-- Name: user_audit_log; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE user_audit_log (
    user_audit_log integer NOT NULL,
    admin_id integer,
    is_user boolean,
    object_id bigint,
    attr_name text,
    old_value text,
    new_value text,
    change_time timestamp without time zone DEFAULT now()
);


ALTER TABLE public.user_audit_log OWNER TO ibs;

--
-- Name: user_audit_log_user_audit_log_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE user_audit_log_user_audit_log_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.user_audit_log_user_audit_log_seq OWNER TO ibs;

--
-- Name: user_audit_log_user_audit_log_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: ibs
--

ALTER SEQUENCE user_audit_log_user_audit_log_seq OWNED BY user_audit_log.user_audit_log;


--
-- Name: user_messages; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE user_messages (
    message_id bigint NOT NULL,
    user_id bigint,
    message_text text,
    post_date timestamp without time zone DEFAULT now()
);


ALTER TABLE public.user_messages OWNER TO ibs;

--
-- Name: user_messages_message_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE user_messages_message_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.user_messages_message_id OWNER TO ibs;

--
-- Name: users; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE users (
    user_id bigint NOT NULL,
    owner_id integer,
    credit numeric(12,2),
    group_id integer,
    creation_date timestamp without time zone DEFAULT now()
);


ALTER TABLE public.users OWNER TO ibs;

--
-- Name: users_user_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE users_user_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.users_user_id_seq OWNER TO ibs;

--
-- Name: voip_charge_rule_tariff; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE voip_charge_rule_tariff (
    tariff_id integer NOT NULL,
    tariff_name text,
    comment text
);


ALTER TABLE public.voip_charge_rule_tariff OWNER TO ibs;

--
-- Name: voip_charge_rule_tariff_tariff_id_seq; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE voip_charge_rule_tariff_tariff_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.voip_charge_rule_tariff_tariff_id_seq OWNER TO ibs;

--
-- Name: voip_charge_rules; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE voip_charge_rules (
    tariff_id integer
)
INHERITS (charge_rules);


ALTER TABLE public.voip_charge_rules OWNER TO ibs;

--
-- Name: voip_onlines_snapshot; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE voip_onlines_snapshot (
    snp_date timestamp without time zone DEFAULT now() NOT NULL,
    ras_id integer NOT NULL,
    value integer
);


ALTER TABLE public.voip_onlines_snapshot OWNER TO ibs;

--
-- Name: voip_users; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE voip_users (
    user_id bigint,
    voip_username text,
    voip_password text
);


ALTER TABLE public.voip_users OWNER TO ibs;

--
-- Name: web_analyzer_log; Type: TABLE; Schema: public; Owner: ibs; Tablespace: 
--

CREATE TABLE web_analyzer_log (
    log_id bigint NOT NULL,
    _date timestamp without time zone DEFAULT now(),
    user_id bigint,
    ip_addr inet,
    url text,
    elapsed integer,
    bytes integer,
    miss smallint,
    hit smallint,
    successful smallint,
    failure smallint,
    _count integer
);


ALTER TABLE public.web_analyzer_log OWNER TO ibs;

--
-- Name: web_analyzer_log_log_id; Type: SEQUENCE; Schema: public; Owner: ibs
--

CREATE SEQUENCE web_analyzer_log_log_id
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.web_analyzer_log_log_id OWNER TO ibs;

--
-- Name: serial; Type: DEFAULT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ras_ippools ALTER COLUMN serial SET DEFAULT nextval('ras_ippools_serial_seq'::regclass);


--
-- Name: user_audit_log; Type: DEFAULT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY user_audit_log ALTER COLUMN user_audit_log SET DEFAULT nextval('user_audit_log_user_audit_log_seq'::regclass);


--
-- Data for Name: add_user_save_details; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY add_user_save_details (add_user_save_id, user_id, username, password) FROM stdin;
144	134	bama2000	1891
144	135	bama2001	7436
144	136	bama2002	5284
144	137	bama2003	6752
144	138	bama2004	7618
144	139	bama2005	7684
144	140	bama2006	8261
144	141	bama2007	7621
144	142	bama2008	2266
144	143	bama2009	7832
251	250	zand	8881
299	289	bama2020	7763
299	290	bama2021	5183
299	291	bama2022	1354
299	292	bama2023	6164
299	293	bama2024	5896
299	294	bama2025	5678
299	295	bama2026	5595
299	296	bama2027	9836
299	297	bama2028	8834
245	235	bama2010	7197
245	236	bama2011	3538
245	237	bama2012	5138
245	238	bama2013	3181
245	239	bama2014	1836
245	240	bama2015	6768
245	241	bama2016	7436
245	242	bama2017	9923
245	243	bama2018	4747
245	244	bama2019	1747
299	298	bama2029	9463
334	324	bama2030	2575
334	325	bama2031	8266
334	326	bama2032	2563
334	327	bama2033	6824
334	328	bama2034	6584
334	329	bama2035	9396
334	330	bama2036	4992
334	331	bama2037	9844
334	332	bama2038	1611
334	333	bama2039	1952
378	368	bama2040	9321
378	369	bama2041	6891
378	370	bama2042	8588
378	371	bama2043	5424
378	372	bama2044	1942
378	373	bama2045	7951
378	374	bama2046	1828
378	375	bama2047	7466
378	376	bama2048	2959
378	377	bama2049	5192
389	379	bama2050	5576
389	380	bama2051	3283
389	381	bama2052	6138
389	382	bama2053	4837
389	383	bama2054	5754
389	384	bama2055	1868
389	385	bama2056	2596
389	386	bama2057	2696
389	387	bama2058	5745
389	388	bama2059	4932
456	455	sanjabi10	1010
555	545	bama2071	8821
555	546	bama2072	4958
555	547	bama2073	2246
555	548	bama2074	4492
555	549	bama2075	8496
555	550	bama2076	5999
555	551	bama2077	4597
555	552	bama2078	2644
555	553	bama2079	6541
555	554	bama2080	8898
503	493	bama2060	9347
503	494	bama2061	8597
503	495	bama2062	8352
503	496	bama2063	3985
503	497	bama2064	4918
503	498	bama2065	7182
503	499	bama2066	9888
503	500	bama2067	5262
503	501	bama2068	4731
503	502	bama2069	6925
578	568	bama2081	4496
578	569	bama2082	1961
578	570	bama2083	9711
578	571	bama2084	8859
578	572	bama2085	4125
578	573	bama2086	7738
578	574	bama2087	4154
578	575	bama2088	6425
578	576	bama2089	9539
578	577	bama2090	4712
600	590	bama2092	2822
600	591	bama2093	3614
600	592	bama2094	5775
600	593	bama2095	7592
600	594	bama2096	5967
600	595	bama2097	3559
600	596	bama2098	8363
600	597	bama2099	7756
600	598	bama2100	4636
600	599	bama2101	2271
625	615	bama2102	4732
625	616	bama2103	2994
625	617	bama2104	1628
625	618	bama2105	5733
625	619	bama2106	5685
625	620	bama2107	8226
625	621	bama2108	9819
625	622	bama2109	7351
625	623	bama2110	5615
625	624	bama2111	2768
641	631	bama2112	6452
641	632	bama2113	3432
641	633	bama2114	4837
641	634	bama2115	7986
641	635	bama2116	6648
641	636	bama2117	3632
641	637	bama2118	3699
641	638	bama2119	8483
641	639	bama2120	6171
641	640	bama2121	3721
642	631	bama2112	9126
642	632	bama2113	1538
642	633	bama2114	4926
642	634	bama2115	1118
642	635	bama2116	1629
642	636	bama2117	9653
642	637	bama2118	2491
642	638	bama2119	5664
642	639	bama2120	5991
642	640	bama2121	1945
\.


--
-- Name: add_user_save_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('add_user_save_id_seq', 1, false);


--
-- Data for Name: add_user_saves; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY add_user_saves (add_user_save_id, add_date, admin_id, type, comment) FROM stdin;
144	2024-02-12 05:12:08.092914	0	1	
251	2024-02-21 16:26:57.10119	0	1	
245	2024-02-20 12:16:22.578632	0	1	
299	2024-02-28 16:33:16.423524	0	1	
334	2024-03-05 05:01:32.451994	0	1	
378	2024-03-10 18:06:02.961335	0	1	
389	2024-03-10 18:10:32.646583	0	1	
456	2024-03-30 15:11:32.937843	0	1	
555	2024-04-26 11:22:31.07957	0	1	
503	2024-04-09 07:01:23.530214	0	1	
578	2024-04-30 14:19:32.736252	0	1	
600	2024-05-11 12:55:16.880378	0	1	
625	2024-05-20 05:44:50.68122	0	1	
641	2024-05-26 17:24:07.16982	0	1	
642	2024-05-26 17:24:44.598313	0	1	
\.


--
-- Data for Name: admin_deposit_change; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_deposit_change (admin_deposit_change_id, admin_id, to_admin_id, deposit_change, change_time, remote_addr, comment) FROM stdin;
\.


--
-- Name: admin_deposit_change_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('admin_deposit_change_id', 1, false);


--
-- Data for Name: admin_locks; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_locks (lock_id, locker_admin_id, admin_id, reason) FROM stdin;
\.


--
-- Name: admin_locks_lock_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('admin_locks_lock_id_seq', 1, false);


--
-- Data for Name: admin_messages; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_messages (message_id, user_id, message_text, post_date) FROM stdin;
\.


--
-- Name: admin_messages_message_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('admin_messages_message_id', 1, false);


--
-- Name: admin_perm_template_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('admin_perm_template_id', 1, false);


--
-- Data for Name: admin_perm_templates; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_perm_templates (template_id, template_name) FROM stdin;
\.


--
-- Data for Name: admin_perm_templates_detail; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_perm_templates_detail (template_id, perm_name, perm_value) FROM stdin;
\.


--
-- Data for Name: admin_perms; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admin_perms (admin_id, perm_name, perm_value) FROM stdin;
0	GOD	
\.


--
-- Data for Name: admins; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admins (admin_id, username, password, deposit, due, name, comment, creator_id) FROM stdin;
0	system	$1$JQGNsGLB$52VXZ7zKyq87aBlj7sYPI1	-733.00	0.00	IBS Internal System Account		0
\.


--
-- Data for Name: admins_extended_attrs; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY admins_extended_attrs (admin_id, attr_name, attr_value) FROM stdin;
\.


--
-- Name: admins_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('admins_id_seq', 1, false);


--
-- Data for Name: bw_interface; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY bw_interface (interface_id, interface_name, comment) FROM stdin;
\.


--
-- Name: bw_interface_interface_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('bw_interface_interface_id_seq', 1, false);


--
-- Data for Name: bw_leaf; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY bw_leaf (leaf_id, leaf_name, interface_id, parent_id, default_rate_kbits, default_ceil_kbits, total_rate_kbits, total_ceil_kbits) FROM stdin;
\.


--
-- Name: bw_leaf_leaf_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('bw_leaf_leaf_id_seq', 1, false);


--
-- Data for Name: bw_leaf_services; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY bw_leaf_services (leaf_service_id, leaf_id, protocol, filter, rate_kbits, ceil_kbits) FROM stdin;
\.


--
-- Name: bw_leaf_services_leaf_service_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('bw_leaf_services_leaf_service_id_seq', 1, false);


--
-- Data for Name: bw_node; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY bw_node (node_id, interface_id, parent_id, rate_kbits, ceil_kbits) FROM stdin;
\.


--
-- Name: bw_node_node_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('bw_node_node_id_seq', 1, false);


--
-- Data for Name: bw_static_ip; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY bw_static_ip (bw_static_ip_id, ip, transmit_leaf_id, receive_leaf_id) FROM stdin;
\.


--
-- Name: bw_static_ip_bw_static_ip_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('bw_static_ip_bw_static_ip_id_seq', 1, false);


--
-- Data for Name: caller_id_users; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY caller_id_users (user_id, caller_id) FROM stdin;
\.


--
-- Data for Name: charge_rule_day_of_weeks; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY charge_rule_day_of_weeks (charge_rule_id, day_of_week) FROM stdin;
1	0
1	1
1	2
1	3
1	4
1	5
1	6
\.


--
-- Data for Name: charge_rule_ports; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY charge_rule_ports (charge_rule_id, ras_port) FROM stdin;
1	_ALL_
\.


--
-- Data for Name: charge_rules; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY charge_rules (charge_id, charge_rule_id, start_time, end_time, time_limit, ras_id) FROM stdin;
\.


--
-- Name: charge_rules_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('charge_rules_id_seq', 1, true);


--
-- Data for Name: charges; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY charges (charge_id, name, charge_type, comment, admin_id, visible_to_all) FROM stdin;
1	Normal	Internet		0	t
\.


--
-- Name: charges_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('charges_id_seq', 1, true);


--
-- Data for Name: connection_log; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY connection_log (connection_log_id, user_id, credit_used, login_time, logout_time, successful, service, ras_id) FROM stdin;
3426297	601	0.00	2024-05-29 07:52:05	2024-05-29 08:00:02	t	1	9
3426298	39	0.00	2024-05-29 07:59:15	2024-05-29 08:00:03	t	1	5
3426299	580	0.00	2024-05-29 07:59:02	2024-05-29 08:00:03	t	1	1
\.


--
-- Data for Name: connection_log_details; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY connection_log_details (connection_log_id, name, value) FROM stdin;
3426297	username	maral2
3426297	terminate_cause	Lost-Carrier
3426297	bytes_in	9257698
3426297	nas_port_type	Async
3426297	bytes_out	1184394
3426297	port	15826601
3426297	unique_id	port
3426297	remote_ip	172.31.0.34
3426298	username	sania
3426298	terminate_cause	Lost-Carrier
3426298	bytes_in	82666
3426298	nas_port_type	Async
3426298	bytes_out	12276
3426298	port	15832215
3426298	unique_id	port
3426298	remote_ip	172.31.0.139
3426299	username	hidokht
3426299	terminate_cause	Lost-Carrier
3426299	bytes_in	75530
3426299	nas_port_type	Async
3426299	bytes_out	8753
3426299	port	15905221
3426299	unique_id	port
3426299	remote_ip	172.31.0.74
\.


--
-- Name: connection_log_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('connection_log_id', 3426300, true);


--
-- Data for Name: credit_change; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY credit_change (credit_change_id, admin_id, action, per_user_credit, admin_credit, change_time, remote_addr, comment) FROM stdin;
1	0	1	1.00	1.00	2024-02-08 12:07:25.485885	178.131.98.246	
2	0	1	1.00	1.00	2024-02-08 12:43:16.953177	178.131.96.102	
3	0	1	1.00	1.00	2024-02-08 12:46:42.473675	178.131.96.102	
4	0	1	1.00	1.00	2024-02-08 12:49:54.994137	178.131.96.102	
5	0	1	1.00	1.00	2024-02-08 13:00:20.369133	178.131.96.102	
6	0	1	1.00	1.00	2024-02-08 13:05:46.990989	178.131.96.102	
7	0	1	1.00	1.00	2024-02-08 13:15:42.117472	178.131.96.102	
8	0	1	1.00	1.00	2024-02-08 13:21:26.471115	178.131.96.102	
9	0	1	1.00	1.00	2024-02-08 13:22:57.92397	178.131.96.102	
10	0	1	1.00	1.00	2024-02-08 13:26:52.914974	178.131.96.102	
11	0	1	1.00	1.00	2024-02-08 13:29:16.156715	178.131.96.102	
12	0	1	1.00	1.00	2024-02-08 13:29:23.12075	178.131.96.102	
13	0	1	1.00	1.00	2024-02-08 13:31:17.501597	178.131.96.102	
14	0	1	1.00	1.00	2024-02-08 13:33:14.257349	178.131.96.102	
15	0	1	1.00	1.00	2024-02-08 13:33:18.886823	178.131.96.102	
16	0	1	1.00	1.00	2024-02-08 13:36:01.443373	178.131.96.102	
17	0	1	1.00	1.00	2024-02-08 13:36:59.219472	178.131.96.102	
18	0	1	1.00	1.00	2024-02-08 13:38:37.827654	178.131.96.102	
19	0	1	1.00	1.00	2024-02-08 13:40:58.750149	178.131.96.102	
20	0	1	1.00	1.00	2024-02-08 13:43:16.459763	178.131.96.102	
21	0	1	1.00	1.00	2024-02-08 13:52:29.441	178.131.96.102	
22	0	1	1.00	1.00	2024-02-08 13:53:40.773914	178.131.96.102	
23	0	1	1.00	1.00	2024-02-08 13:56:04.934572	178.131.96.102	
24	0	1	1.00	1.00	2024-02-08 13:58:39.325223	178.131.96.102	
25	0	1	1.00	1.00	2024-02-08 14:00:46.53934	178.131.96.102	
26	0	1	1.00	1.00	2024-02-08 14:06:00.213517	178.131.96.102	
27	0	1	1.00	1.00	2024-02-08 14:08:07.755712	178.131.96.102	
28	0	1	1.00	1.00	2024-02-08 14:10:15.269199	178.131.96.102	
29	0	1	1.00	1.00	2024-02-08 14:14:38.381572	178.131.96.102	
30	0	1	1.00	1.00	2024-02-08 14:17:27.607655	178.131.96.102	
31	0	3	0.00	-2.00	2024-02-08 14:18:54.290551	178.131.96.102	
32	0	1	1.00	1.00	2024-02-08 14:20:37.221001	178.131.96.102	
33	0	1	1.00	1.00	2024-02-08 14:28:27.709087	178.131.96.102	
34	0	1	1.00	1.00	2024-02-08 14:31:21.322747	178.131.96.102	
35	0	1	1.00	1.00	2024-02-08 14:34:33.59739	178.131.96.102	
36	0	1	1.00	1.00	2024-02-08 14:36:00.217949	178.131.96.102	
37	0	1	1.00	1.00	2024-02-08 14:39:11.269543	178.131.96.102	
38	0	1	1.00	1.00	2024-02-08 14:59:08.394367	178.131.96.102	
39	0	1	1.00	1.00	2024-02-08 15:01:22.520939	178.131.96.102	
40	0	1	1.00	1.00	2024-02-08 15:02:09.857903	178.131.96.102	
41	0	1	1.00	1.00	2024-02-08 15:06:44.825837	178.131.96.102	
42	0	1	1.00	1.00	2024-02-08 15:12:39.014923	178.131.96.102	
43	0	1	1.00	1.00	2024-02-08 15:14:19.311717	178.131.96.102	
44	0	1	1.00	1.00	2024-02-08 15:17:12.126991	178.131.96.102	
45	0	1	1.00	1.00	2024-02-08 15:20:53.029425	178.131.96.102	
46	0	1	1.00	1.00	2024-02-08 15:23:09.604866	178.131.96.102	
47	0	1	1.00	1.00	2024-02-08 15:25:30.451904	178.131.96.102	
48	0	1	1.00	1.00	2024-02-08 15:26:30.80363	178.131.96.102	
49	0	1	1.00	1.00	2024-02-08 15:38:54.174987	178.131.97.214	
50	0	1	1.00	1.00	2024-02-08 15:45:19.679872	178.131.97.214	
51	0	1	1.00	1.00	2024-02-08 15:48:18.314194	178.131.97.214	
52	0	1	1.00	1.00	2024-02-08 16:00:27.856036	178.131.97.214	
53	0	1	1.00	1.00	2024-02-08 16:04:56.818468	178.131.97.214	
54	0	1	1.00	1.00	2024-02-08 16:07:41.245813	178.131.97.214	
55	0	1	1.00	1.00	2024-02-08 16:09:29.467812	178.131.97.214	
56	0	1	1.00	1.00	2024-02-08 16:22:07.310526	178.131.97.214	
57	0	1	1.00	1.00	2024-02-08 16:25:33.953573	178.131.97.214	
58	0	1	1.00	1.00	2024-02-08 16:28:34.713695	178.131.97.214	
59	0	1	1.00	1.00	2024-02-08 16:33:07.714654	178.131.97.214	
60	0	1	1.00	1.00	2024-02-08 16:38:23.469719	178.131.97.214	
61	0	1	1.00	1.00	2024-02-08 16:43:00.945227	178.131.97.214	
62	0	1	1.00	1.00	2024-02-08 16:46:55.979783	178.131.97.214	
63	0	1	1.00	1.00	2024-02-08 16:59:07.681019	178.131.97.214	
64	0	1	1.00	1.00	2024-02-08 17:01:25.643002	178.131.97.214	
65	0	1	1.00	1.00	2024-02-08 17:03:09.643413	178.131.97.214	
66	0	1	1.00	1.00	2024-02-08 17:07:57.908943	178.131.97.214	
67	0	1	1.00	1.00	2024-02-08 17:09:01.012193	178.131.97.214	
68	0	1	1.00	1.00	2024-02-08 17:11:50.449276	178.131.97.214	
69	0	1	1.00	1.00	2024-02-08 17:15:18.932373	178.131.97.214	
70	0	1	1.00	1.00	2024-02-08 17:24:32.674502	178.131.97.214	
71	0	1	1.00	1.00	2024-02-08 17:31:38.10798	178.131.97.214	
72	0	1	1.00	1.00	2024-02-08 17:35:43.51823	178.131.97.214	
73	0	1	1.00	1.00	2024-02-08 17:38:05.231955	178.131.97.214	
74	0	1	1.00	1.00	2024-02-08 17:40:49.216478	178.131.97.214	
75	0	1	1.00	1.00	2024-02-08 17:44:11.819471	178.131.97.214	
76	0	1	1.00	1.00	2024-02-08 17:46:38.592854	178.131.97.214	
77	0	1	1.00	1.00	2024-02-08 17:51:23.196207	178.131.97.214	
78	0	1	1.00	1.00	2024-02-08 17:53:09.803565	178.131.97.214	
79	0	1	1.00	1.00	2024-02-08 18:08:50.794816	178.131.97.214	
80	0	1	1.00	1.00	2024-02-08 18:11:34.977502	178.131.97.214	
81	0	1	1.00	1.00	2024-02-08 18:13:05.500287	178.131.97.214	
82	0	1	1.00	1.00	2024-02-08 18:14:39.522826	178.131.97.214	
83	0	1	1.00	1.00	2024-02-08 18:16:57.869677	178.131.97.214	
84	0	1	1.00	1.00	2024-02-08 18:18:01.934431	178.131.97.214	
85	0	1	1.00	1.00	2024-02-08 18:20:08.588818	178.131.97.214	
86	0	1	1.00	1.00	2024-02-08 18:24:52.353689	178.131.97.214	
87	0	1	1.00	1.00	2024-02-08 18:27:45.67378	178.131.97.214	
88	0	1	1.00	1.00	2024-02-08 18:31:10.943736	178.131.97.214	
89	0	1	1.00	1.00	2024-02-08 18:33:43.123608	178.131.98.143	
90	0	1	1.00	1.00	2024-02-08 18:35:56.313145	178.131.98.143	
91	0	1	1.00	1.00	2024-02-08 18:37:48.500696	178.131.98.143	
92	0	1	1.00	1.00	2024-02-08 18:39:44.616953	178.131.98.143	
93	0	1	1.00	1.00	2024-02-08 18:43:41.923139	178.131.98.143	
94	0	1	1.00	1.00	2024-02-08 18:45:31.380583	178.131.98.143	
95	0	1	1.00	1.00	2024-02-08 18:47:05.273445	178.131.98.143	
96	0	1	1.00	1.00	2024-02-08 18:49:55.188845	178.131.98.143	
97	0	1	1.00	1.00	2024-02-08 18:57:08.136535	178.131.98.143	
98	0	1	1.00	1.00	2024-02-08 18:58:18.484352	178.131.98.143	
99	0	1	1.00	1.00	2024-02-08 19:02:34.409563	178.131.98.143	
100	0	1	1.00	1.00	2024-02-08 19:05:49.38461	178.131.98.143	
101	0	1	1.00	1.00	2024-02-09 02:41:30.250298	213.202.217.17	
102	0	1	1.00	1.00	2024-02-09 02:51:59.513377	213.202.217.17	
103	0	1	1.00	1.00	2024-02-09 04:42:26.400751	213.202.217.17	
104	0	1	1.00	1.00	2024-02-09 05:23:48.015332	213.202.217.17	
105	0	1	1.00	1.00	2024-02-09 05:31:52.64075	213.202.217.17	
106	0	1	1.00	1.00	2024-02-09 06:03:08.126403	2.147.34.16	
107	0	1	1.00	1.00	2024-02-09 06:05:05.968162	2.147.34.16	
108	0	1	1.00	1.00	2024-02-09 06:07:22.20394	2.147.34.16	
109	0	3	0.00	-1.00	2024-02-09 11:18:01.67178	213.202.217.17	
110	0	1	1.00	1.00	2024-02-09 11:18:25.778687	213.202.217.17	
111	0	1	1.00	1.00	2024-02-09 15:09:21.017792	54.38.213.185	
112	0	1	1.00	1.00	2024-02-09 15:21:18.209347	54.38.213.185	
113	0	1	1.00	1.00	2024-02-10 05:05:09.454029	2.147.240.221	
114	0	1	1.00	1.00	2024-02-10 05:24:40.025935	147.135.204.116	
115	0	1	1.00	1.00	2024-02-10 07:46:54.507898	185.118.14.24	
116	0	1	1.00	1.00	2024-02-10 09:24:13.0335	147.135.204.116	
117	0	1	1.00	1.00	2024-02-10 10:32:50.2415	147.135.204.116	
118	0	1	1.00	1.00	2024-02-10 11:52:17.13621	147.135.204.116	
119	0	1	1.00	1.00	2024-02-10 11:53:41.995389	185.118.14.24	
120	0	1	1.00	1.00	2024-02-10 11:55:08.912966	185.118.14.24	
121	0	3	0.00	-1.00	2024-02-11 05:09:16.447283	46.4.197.230	
122	0	3	0.00	-1.00	2024-02-11 05:19:56.705022	46.4.197.230	
123	0	1	1.00	1.00	2024-02-11 05:20:26.037277	46.4.197.230	
124	0	1	1.00	1.00	2024-02-11 08:00:32.519296	2.147.45.54	
125	0	3	0.00	-1.00	2024-02-11 09:11:47.826348	46.4.197.230	
126	0	1	1.00	1.00	2024-02-11 15:35:15.531548	178.131.99.25	
127	0	1	1.00	1.00	2024-02-11 18:06:16.993356	147.135.204.116	
128	0	1	1.00	1.00	2024-02-12 01:39:50.503975	213.202.217.17	
129	0	1	1.00	1.00	2024-02-12 01:42:06.881916	213.202.217.17	
130	0	1	1.00	1.00	2024-02-12 01:54:52.682225	213.202.217.17	
131	0	3	0.00	-1.00	2024-02-12 01:55:48.805846	213.202.217.17	
132	0	1	1.00	1.00	2024-02-12 01:56:19.835	213.202.217.17	
133	0	1	1.00	1.00	2024-02-12 02:00:32.93574	213.202.217.17	
134	0	1	1.00	1.00	2024-02-12 03:19:40.392797	147.135.204.116	
135	0	1	1.00	1.00	2024-02-12 03:49:54.853334	185.118.14.24	
136	0	1	1.00	1.00	2024-02-12 03:52:21.613128	185.118.14.24	
137	0	1	1.00	1.00	2024-02-12 03:57:08.077015	185.118.14.24	
138	0	1	1.00	1.00	2024-02-12 04:03:20.126794	185.118.14.24	
139	0	1	1.00	1.00	2024-02-12 05:09:25.760298	185.118.14.24	
140	0	3	0.00	-1.00	2024-02-12 05:10:04.110119	185.118.14.24	
141	0	1	1.00	10.00	2024-02-12 05:10:38.583048	185.118.14.24	
142	0	3	0.00	-1.00	2024-02-12 05:39:15.549089	147.135.204.116	
143	0	1	1.00	1.00	2024-02-12 05:39:30.63768	147.135.204.116	
144	0	1	1.00	1.00	2024-02-12 12:45:43.6846	2.147.60.217	
145	0	1	1.00	1.00	2024-02-12 12:55:31.500876	54.38.213.185	
146	0	1	1.00	1.00	2024-02-12 16:07:16.558792	151.80.243.74	
147	0	1	1.00	1.00	2024-02-12 16:33:40.806337	147.135.204.116	
148	0	1	1.00	1.00	2024-02-13 04:53:25.324289	185.118.14.24	
149	0	1	1.00	1.00	2024-02-13 13:33:20.004034	213.202.217.17	
150	0	1	1.00	1.00	2024-02-13 15:20:50.513089	54.38.213.185	
151	0	1	1.00	1.00	2024-02-13 15:47:43.212031	46.105.88.74	
152	0	1	1.00	1.00	2024-02-13 17:22:13.902337	135.125.147.107	
153	0	1	1.00	1.00	2024-02-13 17:27:16.736103	135.125.147.107	
154	0	1	1.00	1.00	2024-02-13 17:51:22.350785	135.125.147.107	
155	0	3	0.00	-1.00	2024-02-13 23:56:27.009946	2.147.155.86	
156	0	1	1.00	1.00	2024-02-13 23:57:36.502052	2.147.155.86	
157	0	1	1.00	1.00	2024-02-14 05:43:59.313749	135.125.147.107	
158	0	3	0.00	-1.00	2024-02-14 14:30:08.412932	2.147.203.183	
159	0	1	1.00	1.00	2024-02-14 14:30:21.648159	2.147.203.183	
160	0	1	1.00	1.00	2024-02-14 14:56:36.209591	213.202.217.17	
161	0	3	0.00	-1.00	2024-02-14 15:35:34.435932	2.147.203.183	
162	0	1	1.00	1.00	2024-02-14 16:27:13.377782	213.202.217.17	
163	0	1	1.00	1.00	2024-02-15 02:18:17.996582	213.202.217.17	
164	0	1	1.00	1.00	2024-02-15 04:22:39.967979	2.147.64.22	
165	0	1	1.00	1.00	2024-02-15 04:26:18.75731	2.147.64.22	
166	0	1	1.00	1.00	2024-02-15 10:42:23.456461	213.202.217.17	
167	0	3	0.00	-1.00	2024-02-15 11:10:52.192573	213.202.217.17	
168	0	3	0.00	-1.00	2024-02-15 12:55:41.739887	2.147.49.140	
169	0	1	1.00	1.00	2024-02-15 12:56:08.138195	2.147.49.140	
170	0	1	1.00	1.00	2024-02-15 16:33:56.712177	135.125.147.107	
171	0	1	1.00	1.00	2024-02-15 17:13:26.954406	213.202.217.17	
172	0	1	1.00	1.00	2024-02-16 03:49:26.731808	213.202.217.17	
173	0	1	1.00	1.00	2024-02-16 04:54:13.019616	2.147.181.157	
174	0	3	0.00	-1.00	2024-02-16 16:19:09.931577	89.248.170.134	
175	0	1	1.00	1.00	2024-02-16 16:19:35.623153	89.248.170.134	
176	0	3	0.00	-1.00	2024-02-16 16:20:47.504702	89.248.170.134	
177	0	1	1.00	1.00	2024-02-16 16:32:07.902948	2.147.181.157	
178	0	3	0.00	-1.00	2024-02-17 00:49:26.508639	2.147.181.157	
179	0	1	1.00	1.00	2024-02-17 00:49:42.466794	2.147.181.157	
180	0	1	1.00	1.00	2024-02-17 00:49:50.521201	2.147.181.157	
181	0	1	1.00	1.00	2024-02-17 00:49:55.563561	2.147.181.157	
182	0	1	1.00	1.00	2024-02-17 00:50:00.0375	2.147.181.157	
183	0	1	1.00	1.00	2024-02-17 04:13:16.480501	185.118.14.24	
184	0	1	1.00	1.00	2024-02-17 05:03:05.070799	213.202.217.17	
185	0	1	1.00	1.00	2024-02-17 07:30:40.579232	185.118.14.24	
186	0	1	1.00	1.00	2024-02-17 08:25:55.911269	185.118.14.24	
187	0	1	1.00	1.00	2024-02-17 08:33:51.61661	185.118.14.24	
188	0	1	1.00	1.00	2024-02-17 08:36:18.037202	185.118.14.24	
189	0	1	1.00	1.00	2024-02-17 08:36:54.797731	185.118.14.24	
190	0	1	1.00	1.00	2024-02-17 08:40:50.406759	185.118.14.24	
191	0	3	0.00	-1.00	2024-02-17 13:16:31.720003	54.38.213.182	
192	0	1	1.00	1.00	2024-02-17 13:16:46.580686	54.38.213.182	
193	0	1	1.00	1.00	2024-02-17 13:51:06.94231	54.38.213.182	
194	0	1	1.00	1.00	2024-02-17 14:08:07.235222	54.38.213.182	
195	0	1	1.00	1.00	2024-02-17 14:11:51.425393	54.38.213.182	
196	0	1	1.00	1.00	2024-02-18 07:15:14.617107	185.118.14.24	
197	0	3	0.00	-1.00	2024-02-18 07:54:07.213481	185.118.14.24	
198	0	1	1.00	1.00	2024-02-18 07:54:21.737729	185.118.14.24	
199	0	1	1.00	1.00	2024-02-18 08:53:17.756375	185.118.14.24	
200	0	1	1.00	1.00	2024-02-18 11:18:13.996031	51.89.215.28	
201	0	1	1.00	1.00	2024-02-18 14:12:39.139271	213.202.217.17	
202	0	1	1.00	1.00	2024-02-18 14:12:45.718192	213.202.217.17	
203	0	1	1.00	1.00	2024-02-18 14:24:08.873741	213.202.217.17	
204	0	1	1.00	1.00	2024-02-18 16:06:06.322465	213.202.217.17	
205	0	3	0.00	-1.00	2024-02-18 16:58:38.937787	46.4.197.230	
206	0	1	1.00	1.00	2024-02-18 16:58:53.635175	46.4.197.230	
207	0	1	1.00	1.00	2024-02-18 17:00:52.740738	46.4.197.230	
208	0	3	0.00	-1.00	2024-02-19 02:04:51.401291	213.202.217.17	
209	0	1	1.00	1.00	2024-02-19 02:05:06.006053	213.202.217.17	
210	0	3	0.00	-1.00	2024-02-19 04:42:53.444061	2.147.22.106	
211	0	1	1.00	1.00	2024-02-19 04:43:12.825648	2.147.22.106	
212	0	1	1.00	1.00	2024-02-19 04:46:23.112115	2.147.22.106	
213	0	1	1.00	1.00	2024-02-19 07:24:30.702266	185.118.14.24	
214	0	1	1.00	1.00	2024-02-19 08:17:00.453193	185.118.14.24	
215	0	1	1.00	1.00	2024-02-19 09:31:12.866335	2.147.64.248	
216	0	1	1.00	1.00	2024-02-19 14:05:18.033078	213.202.217.17	
217	0	1	1.00	1.00	2024-02-19 14:21:55.527013	213.202.217.17	
218	0	1	1.00	1.00	2024-02-19 15:10:43.417985	93.117.187.181	
219	0	1	1.00	1.00	2024-02-19 15:40:45.72095	93.117.186.242	
220	0	1	1.00	1.00	2024-02-19 15:43:10.344407	93.117.186.242	
221	0	1	1.00	1.00	2024-02-19 15:43:51.479777	93.117.186.242	
222	0	1	1.00	1.00	2024-02-19 15:56:39.107922	93.117.186.242	
223	0	1	1.00	1.00	2024-02-19 17:26:09.168813	213.202.217.17	
224	0	1	1.00	1.00	2024-02-20 02:17:31.685205	185.118.14.24	
225	0	1	1.00	10.00	2024-02-20 12:12:00.939968	46.4.197.230	
226	0	1	1.00	10.00	2024-02-20 12:15:44.124706	46.4.197.230	
227	0	1	1.00	10.00	2024-02-20 12:15:45.476432	46.4.197.230	
228	0	1	1.00	1.00	2024-02-20 13:46:58.334176	46.4.197.230	
229	0	1	1.00	1.00	2024-02-20 15:40:24.510284	46.4.197.230	
230	0	1	1.00	1.00	2024-02-20 16:18:44.569364	93.117.185.100	
231	0	3	0.00	-10.00	2024-02-21 08:17:01.069416	46.4.197.230	
232	0	3	0.00	-1.00	2024-02-21 08:17:20.200024	46.4.197.230	
233	0	3	0.00	-1.00	2024-02-21 08:17:42.543839	46.4.197.230	
234	0	3	0.00	-4.00	2024-02-21 08:20:07.860486	46.4.197.230	
235	0	3	0.00	-1.00	2024-02-21 15:18:20.65007	46.4.197.230	
236	0	1	1.00	1.00	2024-02-21 15:18:36.114396	46.4.197.230	
237	0	1	1.00	1.00	2024-02-21 16:26:12.03428	46.4.197.230	
238	0	1	1.00	1.00	2024-02-22 04:33:19.86013	2.147.25.169	
239	0	1	1.00	1.00	2024-02-22 07:47:59.453755	46.4.197.230	
240	0	1	1.00	1.00	2024-02-22 07:50:14.272811	46.4.197.230	
241	0	1	1.00	1.00	2024-02-22 10:35:29.059131	46.4.197.230	
245	0	3	0.00	-1.00	2024-02-23 04:39:58.809159	213.202.217.17	
247	0	3	0.00	-1.00	2024-02-23 04:41:27.052871	213.202.217.17	
248	0	1	1.00	1.00	2024-02-23 04:48:04.641016	213.202.217.17	
249	0	3	0.00	-1.00	2024-02-23 15:45:52.706138	2.147.13.72	
251	0	3	0.00	-1.00	2024-02-24 07:14:53.935843	213.202.217.17	
252	0	1	1.00	1.00	2024-02-24 07:15:05.524345	213.202.217.17	
253	0	1	1.00	1.00	2024-02-24 10:27:25.933415	213.202.217.17	
254	0	3	0.00	-1.00	2024-02-24 15:54:32.582822	2.147.6.20	
256	0	1	1.00	2.00	2024-02-25 04:53:07.005698	93.117.187.53	
257	0	3	0.00	-2.00	2024-02-25 04:56:22.909225	93.117.187.53	
259	0	3	0.00	-3.00	2024-02-25 04:57:48.499659	93.117.187.53	
260	0	3	0.00	-1.00	2024-02-25 04:58:14.136267	93.117.187.53	
262	0	1	1.00	1.00	2024-02-25 06:17:41.721105	2.147.160.27	
264	0	3	0.00	-1.00	2024-02-25 12:57:21.21789	213.202.217.17	
265	0	1	1.00	1.00	2024-02-25 12:58:31.423827	213.202.217.17	
270	0	1	1.00	1.00	2024-02-25 15:20:55.65005	213.202.217.17	
272	0	1	1.00	1.00	2024-02-25 15:23:52.915951	213.202.217.17	
274	0	1	1.00	1.00	2024-02-26 00:54:23.352068	93.117.187.30	
275	0	3	0.00	-1.00	2024-02-26 00:57:09.314327	213.202.217.17	
276	0	1	1.00	1.00	2024-02-26 00:57:22.935463	213.202.217.17	
277	0	3	0.00	-1.00	2024-02-26 00:58:37.93516	213.202.217.17	
278	0	1	1.00	1.00	2024-02-26 00:58:52.265105	213.202.217.17	
279	0	3	0.00	-1.00	2024-02-26 00:59:42.472765	213.202.217.17	
280	0	1	1.00	1.00	2024-02-26 00:59:59.202105	213.202.217.17	
281	0	3	0.00	-1.00	2024-02-26 04:01:25.79365	185.118.14.24	
283	0	1	1.00	1.00	2024-02-26 09:26:11.873396	2.147.252.3	
284	0	1	1.00	1.00	2024-02-26 09:36:49.329718	2.147.252.3	
286	0	3	0.00	-1.00	2024-02-26 13:29:06.22281	93.117.185.229	
287	0	1	1.00	1.00	2024-02-26 15:04:29.030657	213.202.217.17	
288	0	1	1.00	1.00	2024-02-27 13:25:56.857627	147.135.204.116	
290	0	3	0.00	-1.00	2024-02-28 06:52:43.815358	185.118.14.24	
291	0	1	1.00	1.00	2024-02-28 06:52:53.252106	185.118.14.24	
293	0	1	1.00	1.00	2024-02-28 16:23:23.939964	2.147.66.24	
294	0	1	1.00	10.00	2024-02-28 16:32:12.983881	2.147.66.24	
297	0	1	1.00	1.00	2024-02-29 04:01:13.512525	2.147.173.182	
299	0	1	1.00	1.00	2024-02-29 07:48:51.407859	2.147.173.182	
301	0	1	1.00	1.00	2024-02-29 07:54:20.601197	2.147.173.182	
302	0	1	1.00	1.00	2024-02-29 08:00:55.249679	2.147.173.182	
303	0	1	1.00	1.00	2024-02-29 13:21:05.629605	51.89.215.28	
304	0	1	1.00	1.00	2024-02-29 14:29:18.785154	46.4.197.247	
306	0	1	1.00	1.00	2024-03-01 01:40:05.406616	213.202.217.17	
309	0	3	0.00	-1.00	2024-03-01 08:25:25.46734	93.117.184.174	
313	0	3	0.00	-1.00	2024-03-01 09:13:53.705723	93.117.184.174	
314	0	1	1.00	1.00	2024-03-01 09:14:08.362988	93.117.184.174	
315	0	1	1.00	1.00	2024-03-01 13:42:21.029527	188.40.183.147	
316	0	1	1.00	1.00	2024-03-02 05:32:31.102492	37.98.107.87	
317	0	1	1.00	1.00	2024-03-02 05:33:59.756135	185.118.14.24	
319	0	1	1.00	1.00	2024-03-02 06:46:40.433233	2.147.164.97	
320	0	3	0.00	-1.00	2024-03-02 13:48:29.195537	54.38.99.223	
321	0	1	1.00	1.00	2024-03-02 13:48:46.784526	54.38.99.223	
324	0	3	0.00	-1.00	2024-03-02 15:39:14.286737	54.38.99.223	
325	0	1	1.00	1.00	2024-03-02 15:39:27.38323	54.38.99.223	
328	0	3	0.00	-1.00	2024-03-03 14:31:17.40403	188.40.183.147	
329	0	1	1.00	1.00	2024-03-03 14:31:44.362726	188.40.183.147	
330	0	3	0.00	-1.00	2024-03-04 04:32:03.907892	188.40.183.147	
333	0	1	1.00	10.00	2024-03-05 05:00:57.535553	188.40.183.147	
335	0	1	1.00	1.00	2024-03-05 08:40:06.142146	37.98.87.107	
337	0	1	1.00	1.00	2024-03-05 14:35:03.759314	188.40.183.147	
338	0	3	0.00	-1.00	2024-03-05 14:50:01.53093	188.40.183.147	
339	0	1	1.00	1.00	2024-03-05 14:50:16.305911	188.40.183.147	
340	0	3	0.00	-1.00	2024-03-05 15:32:25.40872	188.40.183.147	
341	0	1	1.00	1.00	2024-03-05 15:32:42.105301	188.40.183.147	
342	0	3	0.00	-1.00	2024-03-06 08:56:53.655578	188.40.183.147	
346	0	3	0.00	-1.00	2024-03-06 15:54:32.030429	2.147.239.132	
350	0	3	0.00	-1.00	2024-03-06 23:53:26.852622	37.98.84.118	
353	0	3	0.00	-1.00	2024-03-06 23:54:44.456553	37.98.84.118	
355	0	3	0.00	-1.00	2024-03-07 00:11:51.444216	89.248.170.134	
356	0	1	1.00	1.00	2024-03-07 00:12:04.122209	89.248.170.134	
359	0	1	1.00	1.00	2024-03-07 06:05:50.499192	2.147.239.132	
362	0	3	0.00	-1.00	2024-03-08 06:59:35.511323	51.68.236.94	
364	0	1	1.00	1.00	2024-03-08 14:59:41.102641	51.68.236.94	
365	0	1	1.00	1.00	2024-03-08 15:18:35.931753	51.68.236.94	
370	0	3	0.00	-1.00	2024-03-09 12:32:15.622869	93.174.89.27	
375	0	1	1.00	1.00	2024-03-10 06:46:26.929817	2.147.71.174	
379	0	1	1.00	1.00	2024-03-10 13:29:49.900097	2.147.71.174	
380	0	3	0.00	-1.00	2024-03-10 16:52:27.617464	37.98.86.143	
383	0	1	1.00	1.00	2024-03-10 17:20:31.668703	2.147.71.174	
384	0	3	0.00	-1.00	2024-03-10 18:02:20.167482	2.147.71.174	
385	0	1	1.00	1.00	2024-03-10 18:02:47.209079	2.147.71.174	
386	0	1	1.00	10.00	2024-03-10 18:05:12.704752	188.40.183.147	
388	0	3	0.00	-1.00	2024-03-11 15:18:19.125016	2.147.10.236	
390	0	1	1.00	1.00	2024-03-11 15:28:25.76632	188.40.183.147	
391	0	1	1.00	1.00	2024-03-12 01:02:53.99307	188.40.183.147	
393	0	1	1.00	1.00	2024-03-12 03:20:46.336617	188.40.183.147	
394	0	1	1.00	1.00	2024-03-12 05:37:55.618003	94.102.53.89	
395	0	1	1.00	1.00	2024-03-12 13:42:31.042079	213.202.217.17	
396	0	1	1.00	1.00	2024-03-12 13:52:17.807229	213.202.217.17	
398	0	1	1.00	1.00	2024-03-12 14:08:08.110124	213.202.217.17	
401	0	1	1.00	1.00	2024-03-13 13:42:02.017208	54.38.99.223	
403	0	1	1.00	1.00	2024-03-13 16:19:36.779179	178.131.146.67	
404	0	1	1.00	1.00	2024-03-13 16:35:44.526289	178.131.146.33	
407	0	1	1.00	1.00	2024-03-14 14:14:19.581121	46.4.197.230	
408	0	3	0.00	-1.00	2024-03-14 14:27:58.919255	46.4.197.230	
409	0	1	1.00	1.00	2024-03-14 14:28:27.701138	46.4.197.230	
411	0	3	0.00	-1.00	2024-03-14 19:05:43.473673	2.147.222.8	
413	0	1	1.00	1.00	2024-03-15 05:41:12.099052	2.147.222.8	
414	0	1	1.00	1.00	2024-03-15 06:23:10.365107	46.105.88.74	
417	0	3	0.00	-1.00	2024-03-15 16:00:55.923048	178.131.144.98	
418	0	1	1.00	1.00	2024-03-15 16:01:31.498116	178.131.144.98	
419	0	1	1.00	1.00	2024-03-15 16:24:34.072754	2.147.127.108	
420	0	3	0.00	-1.00	2024-03-16 13:08:58.134423	54.38.99.223	
422	0	1	1.00	1.00	2024-03-16 13:11:18.021137	54.38.99.223	
424	0	1	1.00	1.00	2024-03-16 15:14:37.601633	178.131.146.43	
425	0	1	1.00	1.00	2024-03-16 15:17:06.350084	178.131.146.43	
426	0	3	0.00	-1.00	2024-03-16 16:31:08.113607	178.131.145.95	
428	0	1	1.00	1.00	2024-03-17 10:34:56.719979	2.147.245.196	
429	0	1	1.00	1.00	2024-03-17 13:36:05.707956	2.147.245.196	
432	0	1	1.00	1.00	2024-03-17 16:05:00.911528	178.131.145.130	
433	0	1	1.00	1.00	2024-03-17 16:23:14.33474	178.131.145.130	
434	0	1	1.00	1.00	2024-03-17 16:25:32.291984	178.131.145.130	
435	0	1	1.00	1.00	2024-03-17 17:09:59.224768	2.147.3.129	
437	0	3	0.00	-1.00	2024-03-18 05:19:01.204839	54.38.99.223	
438	0	1	1.00	1.00	2024-03-18 05:19:56.299288	54.38.99.223	
439	0	3	0.00	-1.00	2024-03-18 05:32:08.219923	54.38.99.223	
444	0	1	1.00	1.00	2024-03-18 17:03:39.162335	54.38.99.223	
445	0	1	1.00	1.00	2024-03-19 05:03:49.244695	2.147.19.94	
447	0	1	1.00	1.00	2024-03-19 12:38:08.80833	2.147.197.3	
449	0	1	1.00	1.00	2024-03-19 13:26:58.713703	54.38.99.223	
450	0	3	0.00	-1.00	2024-03-19 13:28:31.719951	54.38.99.223	
242	0	3	0.00	-1.00	2024-02-23 02:51:31.231026	213.202.217.17	
243	0	1	1.00	1.00	2024-02-23 02:51:44.437322	213.202.217.17	
244	0	1	1.00	1.00	2024-02-23 03:10:43.960777	213.202.217.17	
246	0	1	1.00	1.00	2024-02-23 04:40:14.241468	213.202.217.17	
250	0	1	1.00	1.00	2024-02-23 15:46:10.216662	2.147.13.72	
255	0	1	1.00	1.00	2024-02-24 15:54:57.938705	2.147.6.20	
258	0	3	0.00	-7.00	2024-02-25 04:57:06.818905	93.117.187.53	
261	0	3	0.00	-1.00	2024-02-25 06:17:30.707999	2.147.160.27	
263	0	1	1.00	1.00	2024-02-25 12:05:35.894948	213.202.217.17	
266	0	1	1.00	1.00	2024-02-25 13:51:14.030708	213.202.217.17	
267	0	3	0.00	-1.00	2024-02-25 14:22:04.842017	213.202.217.17	
268	0	1	1.00	1.00	2024-02-25 14:22:21.38498	213.202.217.17	
269	0	1	1.00	1.00	2024-02-25 14:33:15.029855	213.202.217.17	
271	0	3	0.00	-1.00	2024-02-25 15:23:32.936742	213.202.217.17	
273	0	3	0.00	-1.00	2024-02-26 00:54:07.045467	93.117.187.30	
282	0	1	1.00	1.00	2024-02-26 05:03:51.564189	185.118.14.24	
285	0	1	1.00	1.00	2024-02-26 13:18:49.148396	93.117.185.229	
289	0	1	1.00	1.00	2024-02-27 13:57:22.075902	2.147.127.26	
292	0	1	1.00	1.00	2024-02-28 07:41:06.275061	89.248.170.134	
295	0	3	0.00	-1.00	2024-02-29 03:58:49.584416	2.147.173.182	
296	0	1	1.00	1.00	2024-02-29 03:58:59.698787	2.147.173.182	
298	0	3	0.00	-1.00	2024-02-29 07:10:01.278022	2.147.173.182	
300	0	3	0.00	-1.00	2024-02-29 07:54:11.192526	2.147.173.182	
305	0	3	0.00	-1.00	2024-03-01 01:39:51.417531	213.202.217.17	
307	0	3	0.00	-1.00	2024-03-01 02:36:31.017801	213.202.217.17	
308	0	1	1.00	1.00	2024-03-01 02:37:02.420437	213.202.217.17	
310	0	1	1.00	1.00	2024-03-01 08:25:41.545372	93.117.184.174	
311	0	3	0.00	-1.00	2024-03-01 09:12:37.212019	93.117.184.174	
312	0	1	1.00	1.00	2024-03-01 09:12:50.070792	93.117.184.174	
318	0	3	0.00	-1.00	2024-03-02 06:46:27.703204	2.147.164.97	E
322	0	1	1.00	1.00	2024-03-02 15:16:20.637222	54.38.99.223	
323	0	1	1.00	1.00	2024-03-02 15:34:24.761574	54.38.99.223	
326	0	3	0.00	-1.00	2024-03-03 02:38:13.398889	2.147.153.246	
327	0	1	1.00	1.00	2024-03-03 02:38:29.471585	2.147.153.246	
331	0	1	1.00	1.00	2024-03-04 04:32:17.81503	188.40.183.147	
332	0	1	1.00	1.00	2024-03-04 14:34:51.143077	188.40.183.147	
334	0	3	0.00	-1.00	2024-03-05 08:39:45.306302	37.98.87.107	
336	0	1	1.00	1.00	2024-03-05 12:41:56.43579	147.135.204.116	
343	0	1	1.00	1.00	2024-03-06 08:57:14.547105	188.40.183.147	
344	0	1	1.00	1.00	2024-03-06 10:57:25.438606	188.40.183.147	
345	0	1	1.00	1.00	2024-03-06 14:02:15.121769	188.40.183.147	
347	0	1	1.00	1.00	2024-03-06 15:54:44.9081	2.147.239.132	
348	0	3	0.00	-1.00	2024-03-06 15:55:01.105611	2.147.239.132	
349	0	1	1.00	1.00	2024-03-06 15:55:16.495993	2.147.239.132	
351	0	1	1.00	1.00	2024-03-06 23:53:40.38729	37.98.84.118	
352	0	1	1.00	1.00	2024-03-06 23:54:12.356643	37.98.84.118	
354	0	1	1.00	1.00	2024-03-06 23:55:19.732691	37.98.84.118	
357	0	1	1.00	1.00	2024-03-07 03:35:44.379637	188.40.183.147	
358	0	1	1.00	1.00	2024-03-07 03:37:08.911645	188.40.183.147	
360	0	3	0.00	-1.00	2024-03-08 02:37:30.767652	2.147.67.17	
361	0	1	1.00	1.00	2024-03-08 02:38:30.534633	2.147.67.17	
363	0	1	1.00	1.00	2024-03-08 06:59:47.820932	51.68.236.94	
366	0	3	0.00	-1.00	2024-03-08 23:50:50.372808	37.98.87.232	
367	0	1	1.00	1.00	2024-03-09 03:40:33.490566	2.147.234.223	
368	0	3	0.00	-1.00	2024-03-09 03:42:40.190966	2.147.234.223	
369	0	1	1.00	1.00	2024-03-09 03:42:54.804493	2.147.234.223	
371	0	1	1.00	1.00	2024-03-09 12:32:34.503039	93.174.89.27	
372	0	1	1.00	1.00	2024-03-09 15:09:39.049045	188.40.183.147	
373	0	3	0.00	-1.00	2024-03-10 03:00:20.49148	2.147.71.174	
374	0	1	1.00	1.00	2024-03-10 03:00:38.277781	2.147.71.174	
376	0	3	0.00	-1.00	2024-03-10 13:26:34.327461	2.147.71.174	
377	0	1	1.00	1.00	2024-03-10 13:28:14.529517	2.147.71.174	
378	0	3	0.00	-1.00	2024-03-10 13:29:35.426108	2.147.71.174	
381	0	1	1.00	1.00	2024-03-10 17:01:01.067054	37.98.86.143	
382	0	1	1.00	1.00	2024-03-10 17:20:31.220807	2.147.71.174	
387	0	1	1.00	10.00	2024-03-10 18:09:50.871667	188.40.183.147	
389	0	1	1.00	1.00	2024-03-11 15:18:32.690718	2.147.10.236	
392	0	1	1.00	1.00	2024-03-12 01:02:59.352974	188.40.183.147	
397	0	3	0.00	-1.00	2024-03-12 14:07:39.017719	213.202.217.17	
399	0	3	0.00	-1.00	2024-03-12 16:46:50.884313	2.147.13.130	
400	0	1	1.00	1.00	2024-03-12 16:47:06.598462	2.147.13.130	
402	0	1	1.00	1.00	2024-03-13 14:41:22.634767	89.248.170.134	
405	0	1	1.00	1.00	2024-03-13 16:49:21.08036	46.4.197.230	
406	0	1	1.00	1.00	2024-03-13 16:51:06.840234	46.4.197.230	
410	0	1	1.00	1.00	2024-03-14 14:41:13.351149	46.4.197.230	
412	0	1	1.00	1.00	2024-03-14 19:06:10.954127	2.147.222.8	
415	0	3	0.00	-1.00	2024-03-15 08:24:48.998867	46.105.88.74	
416	0	1	1.00	1.00	2024-03-15 08:25:06.329371	46.105.88.74	
421	0	1	1.00	1.00	2024-03-16 13:09:11.027331	54.38.99.223	
423	0	3	0.00	-1.00	2024-03-16 15:06:41.176646	178.131.146.43	
427	0	1	1.00	1.00	2024-03-16 16:31:20.353758	178.131.145.95	
430	0	1	1.00	1.00	2024-03-17 13:36:34.928339	2.147.245.196	
431	0	3	0.00	-1.00	2024-03-17 15:16:32.238188	178.131.145.130	
436	0	1	1.00	1.00	2024-03-17 17:10:07.443731	2.147.3.129	
440	0	1	1.00	1.00	2024-03-18 06:26:51.643607	54.38.99.223	
441	0	3	0.00	-1.00	2024-03-18 16:54:58.812024	54.38.99.223	
442	0	1	1.00	1.00	2024-03-18 16:55:14.533163	54.38.99.223	
443	0	3	0.00	-1.00	2024-03-18 17:03:23.201236	54.38.99.223	
446	0	3	0.00	-1.00	2024-03-19 12:37:38.621259	2.147.197.3	
448	0	3	0.00	-1.00	2024-03-19 13:26:06.627905	54.38.99.223	
451	0	1	1.00	1.00	2024-03-19 13:28:52.634064	54.38.99.223	
452	0	1	1.00	1.00	2024-03-19 13:28:53.715318	54.38.99.223	
453	0	3	0.00	-1.00	2024-03-19 13:29:28.003989	54.38.99.223	
454	0	1	1.00	1.00	2024-03-19 13:30:22.786649	54.38.99.223	
455	0	1	1.00	1.00	2024-03-19 15:15:38.199182	54.38.99.223	
456	0	1	1.00	1.00	2024-03-22 13:33:40.044426	54.38.99.223	
457	0	3	0.00	-1.00	2024-03-22 13:34:41.014895	54.38.99.223	
458	0	1	1.00	1.00	2024-03-22 13:34:59.835774	54.38.99.223	
459	0	3	0.00	-1.00	2024-03-23 09:31:12.536966	46.4.197.230	
460	0	1	1.00	1.00	2024-03-23 09:31:31.763565	46.4.197.230	
461	0	3	0.00	-1.00	2024-03-23 09:42:27.846	46.4.197.230	
462	0	1	1.00	1.00	2024-03-23 09:42:38.762101	46.4.197.230	
463	0	1	1.00	1.00	2024-03-24 10:47:22.997643	2.147.12.105	
464	0	1	1.00	1.00	2024-03-24 10:47:23.200898	2.147.12.105	
465	0	1	1.00	1.00	2024-03-25 05:06:25.06298	54.38.99.223	
466	0	3	0.00	-1.00	2024-03-25 06:05:36.221675	54.38.99.223	
467	0	1	1.00	1.00	2024-03-25 06:05:51.800033	54.38.99.223	
468	0	1	1.00	1.00	2024-03-26 04:37:51.178187	62.102.134.107	
469	0	1	1.00	1.00	2024-03-27 04:00:59.436791	62.102.135.85	
470	0	1	1.00	1.00	2024-03-27 04:17:48.959583	147.135.204.116	
471	0	1	1.00	1.00	2024-03-27 04:18:19.927976	147.135.204.116	
472	0	1	1.00	1.00	2024-03-28 03:51:29.010287	62.102.133.136	
473	0	3	0.00	-1.00	2024-03-28 13:55:37.504807	147.135.204.116	
474	0	1	1.00	1.00	2024-03-28 19:04:57.656197	46.4.197.230	
475	0	1	1.00	1.00	2024-03-29 06:50:30.091866	2.147.205.210	
476	0	1	1.00	1.00	2024-03-29 09:08:43.745081	46.4.197.230	
477	0	3	0.00	-1.00	2024-03-29 14:21:42.930784	46.4.197.230	
478	0	1	1.00	1.00	2024-03-30 15:10:39.404419	46.4.197.230	
479	0	3	0.00	-1.00	2024-03-30 16:12:03.496337	46.4.197.230	
480	0	1	1.00	1.00	2024-03-31 04:05:47.59491	62.102.133.206	
481	0	3	0.00	-1.00	2024-03-31 12:15:35.398202	5.117.156.128	
482	0	1	1.00	1.00	2024-03-31 12:15:53.332324	5.117.156.128	
483	0	3	0.00	-1.00	2024-03-31 16:28:41.39872	89.198.3.177	
484	0	1	1.00	1.00	2024-03-31 16:49:20.122651	2.147.221.173	
485	0	1	1.00	1.00	2024-03-31 16:49:38.17245	89.198.116.89	
486	0	3	0.00	-1.00	2024-04-01 16:04:03.20274	2.147.172.114	
487	0	1	1.00	1.00	2024-04-01 16:05:13.152237	2.147.172.114	
488	0	1	1.00	1.00	2024-04-02 04:38:48.612309	185.118.14.24	
489	0	1	1.00	1.00	2024-04-02 07:19:00.828746	89.248.170.134	
490	0	1	1.00	1.00	2024-04-02 16:43:26.073768	93.174.89.27	
491	0	1	1.00	1.00	2024-04-02 16:45:16.92598	93.174.89.27	
492	0	1	1.00	1.00	2024-04-03 04:54:10.738851	185.118.14.24	
493	0	3	0.00	-1.00	2024-04-03 04:54:21.085769	185.118.14.24	
494	0	1	1.00	1.00	2024-04-03 17:56:30.892787	62.102.135.18	
495	0	1	1.00	1.00	2024-04-04 02:48:14.295831	185.118.14.24	
496	0	1	1.00	1.00	2024-04-04 07:42:06.294876	54.38.99.223	
497	0	1	1.00	1.00	2024-04-04 08:01:22.584124	54.38.99.223	
498	0	1	1.00	1.00	2024-04-04 09:42:04.248402	2.147.146.75	
499	0	1	1.00	1.00	2024-04-05 04:26:17.819118	62.102.135.180	
500	0	3	0.00	-1.00	2024-04-05 10:04:45.324579	2.147.237.58	
501	0	1	1.00	1.00	2024-04-05 10:04:57.36128	2.147.237.58	
502	0	3	0.00	-1.00	2024-04-05 13:45:50.326971	157.90.139.153	
503	0	1	1.00	1.00	2024-04-05 16:13:40.537794	2.147.140.97	
504	0	1	1.00	1.00	2024-04-05 16:14:12.236169	2.147.140.97	
505	0	1	1.00	1.00	2024-04-06 17:06:11.890976	147.135.204.116	
506	0	1	1.00	1.00	2024-04-07 15:14:39.346483	2.147.14.9	
507	0	1	1.00	1.00	2024-04-08 16:23:06.641348	2.147.197.166	
508	0	1	1.00	1.00	2024-04-08 17:34:12.523864	46.4.197.230	
509	0	1	1.00	1.00	2024-04-09 02:07:55.383622	147.135.204.116	
510	0	1	1.00	1.00	2024-04-09 06:34:31.818438	147.135.204.116	
511	0	1	10.00	100.00	2024-04-09 06:57:00.029299	147.135.204.116	
512	0	3	0.00	-70.00	2024-04-09 07:00:05.45046	178.131.152.176	
513	0	3	0.00	-31.00	2024-04-09 07:00:27.384559	178.131.152.176	
514	0	1	10.00	100.00	2024-04-09 07:00:53.625043	178.131.152.176	
515	0	1	1.00	1.00	2024-04-09 12:42:10.101029	2.147.208.238	
516	0	1	1.00	1.00	2024-04-10 11:01:23.42178	51.195.248.144	
517	0	1	1.00	1.00	2024-04-11 11:31:48.807046	89.248.170.134	
518	0	1	1.00	1.00	2024-04-11 16:10:37.218422	51.195.248.144	
519	0	1	1.00	1.00	2024-04-11 16:13:14.925558	178.131.144.219	
520	0	1	1.00	1.00	2024-04-12 14:39:45.721084	2.147.15.26	
521	0	1	1.00	1.00	2024-04-13 16:28:03.139897	54.38.99.223	
522	0	1	1.00	1.00	2024-04-14 02:18:19.477014	46.4.197.230	
523	0	3	0.00	-1.00	2024-04-14 02:18:38.230065	46.4.197.230	
524	0	1	1.00	1.00	2024-04-14 02:18:54.603106	46.4.197.230	
525	0	1	1.00	1.00	2024-04-14 06:14:36.488609	178.131.155.136	
526	0	1	1.00	1.00	2024-04-14 13:40:48.116792	93.117.180.113	
527	0	1	1.00	1.00	2024-04-14 14:40:38.402361	46.4.197.230	
528	0	1	1.00	1.00	2024-04-14 14:54:33.223839	46.4.197.230	
529	0	1	1.00	1.00	2024-04-15 13:20:03.724124	46.4.197.230	
530	0	1	1.00	1.00	2024-04-15 13:20:08.780559	46.4.197.230	
531	0	1	1.00	1.00	2024-04-15 13:22:55.130303	46.4.197.230	
532	0	1	1.00	1.00	2024-04-15 13:22:55.515901	46.4.197.230	
533	0	1	1.00	1.00	2024-04-15 16:19:40.347876	93.117.182.5	
534	0	1	1.00	1.00	2024-04-15 16:39:42.958322	93.117.181.191	
535	0	1	1.00	1.00	2024-04-16 13:22:10.492902	54.38.99.223	
536	0	1	1.00	1.00	2024-04-17 13:36:25.376367	178.131.128.49	
537	0	1	1.00	1.00	2024-04-17 17:10:51.901291	188.40.183.147	
538	0	1	1.00	1.00	2024-04-18 08:32:17.573216	2.147.207.149	
539	0	1	1.00	1.00	2024-04-18 13:45:50.499774	5.217.116.152	
540	0	1	1.00	1.00	2024-04-18 19:50:13.045101	178.131.129.197	
541	0	1	1.00	1.00	2024-04-19 07:42:53.800596	188.40.183.147	
542	0	1	1.00	1.00	2024-04-19 08:03:40.373298	188.40.183.147	
543	0	1	1.00	1.00	2024-04-20 16:59:52.177614	188.40.183.147	
544	0	1	1.00	1.00	2024-04-21 14:01:47.316077	89.248.170.134	
545	0	1	1.00	1.00	2024-04-21 15:45:56.736063	89.248.170.134	
546	0	3	0.00	-1.00	2024-04-21 15:46:18.694933	89.248.170.134	
547	0	1	1.00	1.00	2024-04-21 15:46:40.675241	89.248.170.134	
548	0	1	1.00	1.00	2024-04-21 16:11:14.451339	89.248.170.134	
549	0	1	1.00	1.00	2024-04-21 16:12:52.536052	89.248.170.134	
550	0	3	0.00	-1.00	2024-04-22 04:50:44.716683	2.147.118.8	
551	0	1	1.00	1.00	2024-04-22 04:51:39.792328	2.147.118.8	
552	0	3	0.00	-1.00	2024-04-23 05:03:45.338561	89.248.170.134	
553	0	1	1.00	1.00	2024-04-23 05:07:13.279648	89.248.170.134	
554	0	1	1.00	1.00	2024-04-24 05:38:31.953369	2.147.212.56	
555	0	1	1.00	1.00	2024-04-24 05:38:39.208176	2.147.212.56	
556	0	1	1.00	1.00	2024-04-24 16:46:38.232362	89.248.170.134	
557	0	1	1.00	1.00	2024-04-24 16:46:40.169206	89.248.170.134	
558	0	1	1.00	1.00	2024-04-25 06:38:13.020286	89.248.170.134	
559	0	3	0.00	-1.00	2024-04-25 14:16:12.204848	2.147.224.250	
560	0	1	1.00	1.00	2024-04-26 07:56:34.975717	2.147.128.233	
561	0	1	10.00	100.00	2024-04-26 11:21:47.084987	137.74.64.231	
562	0	1	1.00	1.00	2024-04-26 12:14:20.830347	137.74.64.231	
563	0	1	1.00	1.00	2024-04-27 05:49:44.635441	46.4.197.230	
564	0	3	0.00	-1.00	2024-04-27 16:14:07.169622	178.131.161.247	
565	0	1	1.00	1.00	2024-04-28 01:04:46.611648	178.131.163.78	
566	0	1	1.00	1.00	2024-04-28 14:21:55.697691	147.135.204.116	
567	0	1	1.00	1.00	2024-04-28 14:22:06.016681	147.135.204.116	
568	0	1	1.00	1.00	2024-04-28 14:25:36.105633	147.135.204.116	
569	0	1	1.00	1.00	2024-04-28 15:48:19.740941	147.135.204.116	
570	0	1	1.00	1.00	2024-04-29 04:23:33.693948	5.201.191.28	
571	0	1	1.00	1.00	2024-04-29 06:29:42.874429	2.147.248.171	
572	0	1	1.00	1.00	2024-04-30 03:28:49.466591	5.201.191.28	
573	0	1	1.00	1.00	2024-04-30 07:59:40.886052	2.147.68.14	
574	0	1	1.00	1.00	2024-04-30 14:17:16.456045	188.40.183.147	
575	0	1	10.00	100.00	2024-04-30 14:17:29.468115	188.40.183.147	
576	0	1	1.00	1.00	2024-05-01 00:49:06.225561	178.131.162.195	
577	0	1	1.00	1.00	2024-05-01 14:27:35.799164	89.248.170.134	
578	0	1	1.00	1.00	2024-05-02 09:12:09.66008	54.38.99.223	
579	0	1	1.00	1.00	2024-05-03 13:09:50.49619	188.40.183.147	
580	0	3	0.00	-1.00	2024-05-05 15:19:53.171083	178.131.161.219	
581	0	1	1.00	1.00	2024-05-05 15:20:04.913062	178.131.161.219	
582	0	1	1.00	1.00	2024-05-05 15:40:47.344853	178.131.161.219	
583	0	1	1.00	1.00	2024-05-06 15:30:33.247072	2.147.142.27	
584	0	1	1.00	1.00	2024-05-08 07:39:01.979045	54.38.99.223	
585	0	1	1.00	1.00	2024-05-08 15:20:58.46898	178.131.160.66	
586	0	3	0.00	-10.00	2024-05-08 16:08:13.185067	54.38.99.223	
587	0	1	1.00	1.00	2024-05-08 16:08:41.963839	54.38.99.223	
588	0	1	1.00	1.00	2024-05-09 05:17:39.810573	5.201.191.28	
589	0	1	1.00	10.00	2024-05-11 12:54:25.862361	2.147.126.200	
590	0	1	1.00	1.00	2024-05-11 13:02:55.306002	2.147.126.200	
591	0	1	1.00	1.00	2024-05-13 15:39:41.913433	93.117.186.254	
592	0	1	1.00	1.00	2024-05-13 17:02:42.942628	46.4.197.230	
593	0	1	1.00	1.00	2024-05-13 17:07:36.671514	46.4.197.230	
594	0	1	1.00	1.00	2024-05-14 14:08:50.866259	188.40.183.147	
595	0	1	1.00	1.00	2024-05-14 16:28:25.669461	93.117.184.51	
596	0	1	1.00	1.00	2024-05-15 16:25:53.870628	188.40.183.147	
597	0	1	1.00	1.00	2024-05-17 15:27:07.614163	46.4.197.247	
598	0	1	1.00	1.00	2024-05-17 15:27:08.741778	46.4.197.247	
599	0	3	0.00	-1.00	2024-05-18 13:33:01.957047	62.102.134.203	
600	0	1	1.00	1.00	2024-05-18 13:33:19.059646	62.102.134.203	
601	0	1	1.00	1.00	2024-05-19 12:50:59.381759	62.102.134.26	
602	0	1	1.00	1.00	2024-05-19 14:21:57.559899	62.102.132.34	
603	0	1	1.00	1.00	2024-05-19 15:18:50.776592	188.40.183.147	
604	0	1	1.00	1.00	2024-05-20 03:54:47.72057	5.201.191.28	
605	0	1	1.00	10.00	2024-05-20 05:44:09.850926	188.40.183.147	
606	0	3	0.00	-1.00	2024-05-20 12:35:42.863242	2.147.146.109	
607	0	1	1.00	1.00	2024-05-21 12:11:29.387713	5.201.191.28	
608	0	3	0.00	-1.00	2024-05-21 12:12:28.069514	5.201.191.28	
609	0	1	1.00	1.00	2024-05-21 15:54:12.592719	2.147.233.252	
610	0	3	0.00	-1.00	2024-05-24 03:29:19.050409	2.147.36.94	
611	0	3	0.00	-1.00	2024-05-24 15:57:57.183413	54.38.99.223	
612	0	1	1.00	1.00	2024-05-24 15:58:23.66142	54.38.99.223	
613	0	1	1.00	1.00	2024-05-26 06:40:48.247527	2.147.174.163	
614	0	3	0.00	-1.00	2024-05-26 14:22:46.787866	54.38.99.223	
615	0	1	1.00	1.00	2024-05-26 14:23:08.777793	54.38.99.223	
616	0	1	1.00	10.00	2024-05-26 17:23:06.447219	54.38.99.223	
617	0	1	1.00	1.00	2024-05-26 17:28:55.894104	54.38.99.223	
618	0	1	1.00	1.00	2024-05-26 17:28:57.088945	54.38.99.223	
619	0	1	1.00	1.00	2024-05-27 10:19:50.70976	5.201.191.28	
620	0	1	1.00	1.00	2024-05-27 16:32:25.545891	54.38.99.223	
621	0	1	1.00	1.00	2024-05-27 16:42:39.117526	54.38.99.223	
622	0	1	1.00	1.00	2024-05-27 16:43:51.806987	54.38.99.223	
623	0	3	0.00	-1.00	2024-05-29 01:26:20.067886	54.38.99.223	
624	0	1	1.00	1.00	2024-05-29 01:50:53.866818	2.147.76.249	
625	0	1	1.00	1.00	2024-05-29 05:51:33.245409	2.147.76.249	
\.


--
-- Name: credit_change_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('credit_change_id', 625, true);


--
-- Data for Name: credit_change_userid; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY credit_change_userid (credit_change_id, user_id) FROM stdin;
1	1
2	2
3	3
4	4
5	5
6	6
7	7
8	8
9	9
10	10
11	11
12	12
13	13
14	14
15	15
16	16
17	17
18	18
19	19
20	20
21	21
22	22
23	23
24	24
25	25
26	26
27	27
28	28
29	29
30	30
31	11
31	14
32	31
33	32
34	33
35	34
36	35
37	36
38	37
39	38
40	39
41	40
42	41
43	42
44	43
45	44
46	45
47	46
48	47
49	48
50	49
51	50
52	51
53	52
54	53
55	54
56	55
57	56
58	57
59	58
60	59
61	60
62	61
63	62
64	63
65	64
66	65
67	66
68	67
69	68
70	69
71	70
72	71
73	72
74	73
75	74
76	75
77	76
78	77
79	78
80	79
81	80
82	81
83	82
84	83
85	84
86	85
87	86
88	87
89	88
90	89
91	90
92	91
93	92
94	93
95	94
96	95
97	96
98	97
99	98
100	99
101	100
102	101
103	102
104	103
105	104
106	105
107	106
108	107
109	95
110	108
111	109
112	110
113	111
114	112
115	113
116	114
117	115
118	116
119	117
120	118
121	78
122	110
123	119
124	120
125	18
126	121
127	122
128	123
129	124
130	125
131	125
132	126
133	127
134	128
135	129
136	130
137	131
138	132
139	133
140	133
141	134
141	135
141	136
141	137
141	138
141	139
141	140
141	141
141	142
141	143
142	98
143	145
144	146
145	147
146	148
147	149
148	150
149	151
150	152
151	153
152	154
153	155
154	156
155	32
156	157
157	158
158	35
159	159
160	160
161	60
162	161
163	162
164	163
165	164
166	165
167	165
168	159
169	166
170	167
171	168
172	169
173	170
174	48
175	171
176	94
178	85
179	173
182	176
183	177
187	181
191	155
195	188
196	189
197	12
204	196
205	42
210	37
211	200
213	202
214	203
215	204
219	208
225	214
225	215
225	216
225	217
225	218
225	219
225	220
225	221
225	222
225	223
229	247
230	248
231	225
231	226
231	227
231	228
231	229
231	230
231	231
231	232
231	233
231	234
233	117
236	249
238	252
239	253
242	86
245	81
249	13
251	211
252	261
253	262
254	41
256	264
256	265
257	264
257	265
264	99
265	269
272	274
274	275
276	276
279	16
280	278
281	23
283	280
286	56
287	283
288	284
290	79
291	286
294	289
294	290
294	291
294	292
294	293
294	294
294	295
294	296
294	297
294	298
295	28
297	301
307	73
309	71
316	313
317	314
319	315
320	10
321	316
324	26
328	51
329	321
330	199
333	324
333	325
333	326
333	327
333	328
333	329
333	330
333	331
333	332
333	333
340	8
342	27
346	109
350	21
353	22
356	348
359	351
362	4
370	148
375	361
380	25
383	366
386	368
386	369
386	370
386	371
386	372
386	373
386	374
386	375
386	376
386	377
387	379
387	380
387	381
387	382
387	383
387	384
387	385
387	386
387	387
387	388
388	196
394	395
395	396
396	397
398	398
401	400
404	403
407	406
408	69
409	407
413	410
414	411
417	156
420	194
422	416
425	418
426	166
428	420
429	421
432	423
434	425
435	426
437	206
438	428
439	172
445	432
447	433
449	434
450	88
453	163
456	439
459	256
461	267
462	442
463	443
464	444
465	445
466	100
468	447
470	449
473	451
475	453
478	455
479	253
480	457
486	246
488	462
489	463
490	464
491	465
492	466
177	172
180	174
184	178
186	180
189	183
190	184
198	190
200	192
202	194
206	197
208	80
209	199
212	201
217	206
224	213
226	225
226	226
226	227
226	228
226	229
226	230
226	231
226	232
226	233
226	234
228	246
232	66
234	169
234	173
234	174
234	175
237	250
240	254
241	255
246	258
250	260
255	263
258	217
258	218
258	219
258	220
258	221
258	222
258	223
261	102
263	268
266	270
267	29
268	271
269	272
271	129
273	19
282	279
285	282
289	285
292	287
296	300
298	55
300	82
305	149
308	308
310	309
311	53
312	310
318	64
322	317
323	318
326	57
327	320
331	322
332	323
334	205
336	336
343	340
344	341
345	342
347	343
348	343
349	344
351	345
352	346
354	347
357	349
358	350
360	38
361	352
363	353
366	273
367	356
368	131
369	357
371	358
372	359
373	9
374	360
376	192
377	362
378	2
381	364
382	365
389	390
392	393
397	34
399	186
400	399
402	401
405	404
406	405
410	408
412	409
415	43
416	412
421	415
423	416
427	419
430	422
431	182
436	427
440	429
441	249
442	430
443	138
446	49
448	58
451	435
454	437
455	438
457	439
458	440
460	441
467	446
469	448
471	450
474	452
476	454
481	308
483	424
484	459
485	460
487	461
493	466
495	468
496	469
497	470
499	472
501	473
502	178
505	476
506	477
507	478
509	480
510	481
512	485
512	486
512	487
512	488
512	489
512	490
512	491
514	493
514	494
514	495
514	496
514	497
514	498
514	499
514	500
514	501
514	502
516	505
517	506
518	507
519	508
520	509
521	510
524	512
525	513
528	516
529	517
532	520
534	522
535	523
536	524
538	526
539	527
181	175
185	179
188	182
192	185
193	186
194	187
199	191
201	193
203	195
207	198
216	205
218	207
220	209
221	210
222	211
223	212
227	235
227	236
227	237
227	238
227	239
227	240
227	241
227	242
227	243
227	244
235	15
243	256
244	257
247	191
248	259
259	214
259	215
259	216
260	193
262	267
270	273
275	20
277	17
278	277
284	281
293	288
299	302
301	303
302	304
303	305
304	306
306	307
313	54
314	311
315	312
325	319
335	335
337	337
338	106
339	338
341	339
355	72
364	354
365	355
379	363
384	140
385	367
390	391
391	392
393	394
403	402
411	152
418	413
419	414
424	417
433	424
444	431
452	436
472	451
477	454
482	458
494	467
498	471
500	347
503	474
504	475
508	479
511	482
511	483
511	484
511	485
511	486
511	487
511	488
511	489
511	490
511	491
513	474
513	482
513	483
513	484
515	504
522	511
523	511
526	514
527	515
530	518
531	519
533	521
537	525
540	528
541	529
542	530
543	531
544	532
545	533
546	533
547	534
548	535
549	536
550	434
551	537
552	395
553	538
554	539
555	540
556	541
557	542
558	543
559	529
560	544
561	545
561	546
561	547
561	548
561	549
561	550
561	551
561	552
561	553
561	554
562	556
563	557
564	432
565	558
566	559
567	560
568	561
569	562
570	563
571	564
572	565
573	566
574	567
575	568
575	569
575	570
575	571
575	572
575	573
575	574
575	575
575	576
575	577
576	579
577	580
578	581
579	582
580	387
581	583
582	584
583	585
584	586
585	587
586	497
587	588
588	589
589	590
589	591
589	592
589	593
589	594
589	595
589	596
589	597
589	598
589	599
590	601
591	602
592	603
593	604
594	605
595	606
596	607
597	608
598	609
599	534
600	610
601	611
602	612
603	613
604	614
605	615
605	616
605	617
605	618
605	619
605	620
605	621
605	622
605	623
605	624
606	614
607	626
608	626
609	627
610	609
611	583
612	628
613	629
614	536
615	630
616	631
616	632
616	633
616	634
616	635
616	636
616	637
616	638
616	639
616	640
617	643
618	644
619	645
620	646
621	647
622	648
623	398
624	649
625	650
\.


--
-- Data for Name: defs; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY defs (name, value, type) FROM stdin;
BW_IPTABLES_COMMAND	S'iptables'\np0\n.	\N
BW_TC_COMMAND	S'tc'\np0\n.	\N
CHECK_ONLINE_INTERVAL	I60\n.	\N
CHECK_ONLINE_MAX_FAILS	I2\n.	\N
FASTDIAL_PREFIX	S''\np0\n.	\N
IAS_ENABLED	I0\n.	\N
IBS_SERVER_IP	S'127.0.0.1'\np0\n.	\N
IBS_SERVER_PORT	I1235\n.	\N
KILL_USERS_ON_SHUTDOWN	I1\n.	\N
KILL_USERS_SHUTDOWN_WAIT_TIME	I20\n.	\N
MAX_USER_POOL_SIZE	I10000\n.	\N
RADIUS_SERVER_ACCT_PORT	I1813\n.	\N
RADIUS_SERVER_AUTH_PORT	I1812\n.	\N
RADIUS_SERVER_BIND_IP	(lp0\nS'0.0.0.0'\np1\na.	\N
RADIUS_SERVER_CLEANUP_TIME	I20\n.	\N
RADIUS_SERVER_ENABLED	I1\n.	\N
REALTIME_BW_SNAPSHOT_HOURS	I5\n.	\N
REALTIME_BW_SNAPSHOT_INTERVAL	I15\n.	\N
REALTIME_ONLINES_SNAPSHOT_HOURS	I5\n.	\N
REALTIME_ONLINES_SNAPSHOT_INTERVAL	I15\n.	\N
SNAPSHOT_BW_INTERVAL	I60\n.	\N
SNAPSHOT_ONLINES_INTERVAL	I300\n.	\N
TRUSTED_CLIENTS	(lp0\nS'127.0.0.1'\np1\na.	\N
USER_AUDIT_LOG	I1\n.	\N
WEB_ANALYZER_PASSWORD	S'web_analyzer_password'\np0\n.	\N
\.


--
-- Data for Name: group_attrs; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY group_attrs (group_id, attr_name, attr_value) FROM stdin;
1	rel_exp_date	2592000
1	multi_login	2
1	traffic_periodic_accounting_daily	30
1	traffic_periodic_accounting_daily_limit	10485760000
1	normal_charge	1
2	rel_exp_date	2592000
2	multi_login	2
2	traffic_periodic_accounting_daily	30
2	traffic_periodic_accounting_daily_limit	20971520000
3	rel_exp_date	2592000
3	traffic_periodic_accounting_daily	30
3	traffic_periodic_accounting_daily_limit	36700160000
3	normal_charge	1
3	multi_login	2
4	normal_charge	1
4	rel_exp_date	2592000
4	multi_login	2
4	traffic_periodic_accounting_daily	30
4	traffic_periodic_accounting_daily_limit	52428800000
5	normal_charge	1
5	rel_exp_date	2592000
5	multi_login	2
5	traffic_periodic_accounting_daily	30
5	traffic_periodic_accounting_daily_limit	73400320000
6	normal_charge	1
6	rel_exp_date	2592000
6	multi_login	2
6	traffic_periodic_accounting_daily	30
6	traffic_periodic_accounting_daily_limit	104857600000
14	rel_exp_date	7776000
7	rel_exp_date	5184000
7	multi_login	2
7	traffic_periodic_accounting_daily	60
7	traffic_periodic_accounting_daily_limit	73400320000
7	normal_charge	1
8	normal_charge	1
8	rel_exp_date	7776000
8	multi_login	2
8	traffic_periodic_accounting_daily	90
8	traffic_periodic_accounting_daily_limit	157286400000
9	normal_charge	1
9	rel_exp_date	7776000
9	multi_login	2
9	traffic_periodic_accounting_daily	90
9	traffic_periodic_accounting_daily_limit	262144000000
10	normal_charge	1
10	rel_exp_date	15552000
10	multi_login	2
10	traffic_periodic_accounting_daily	180
10	traffic_periodic_accounting_daily_limit	314572800000
11	normal_charge	1
11	rel_exp_date	15552000
11	multi_login	2
11	traffic_periodic_accounting_daily	180
11	traffic_periodic_accounting_daily_limit	471859200000
12	normal_charge	1
12	rel_exp_date	31104000
12	multi_login	2
12	traffic_periodic_accounting_daily	365
12	traffic_periodic_accounting_daily_limit	629145600000
13	normal_charge	1
13	rel_exp_date	31536000
13	multi_login	2
13	traffic_periodic_accounting_daily	365
13	traffic_periodic_accounting_daily_limit	838860800000
2	normal_charge	1
14	traffic_periodic_accounting_daily	90
14	traffic_periodic_accounting_daily_limit	104857600000
14	multi_login	1
14	normal_charge	1
\.


--
-- Data for Name: groups; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY groups (group_id, group_name, owner_id, comment) FROM stdin;
1	1-Month-10G	0	
2	1-Month-20G	0	
14	3-month-100-G-bama	0	
3	1-Month-35G	0	
4	1-Month-50G	0	
5	1-Month-70G	0	
6	1-Month-100G	0	
7	2-Month-70G	0	
8	3-Month-150G	0	
9	3-Month-250G	0	
10	6-Month-300G	0	
11	6-Month-450G	0	
12	12-Month-600G	0	
13	12-Month-800G	0	
\.


--
-- Name: groups_group_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('groups_group_id_seq', 14, true);


--
-- Data for Name: ias_event; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ias_event (event_id, event_type, event_date, actor, amount, destinations, comment) FROM stdin;
\.


--
-- Name: ias_event_event_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('ias_event_event_id', 1, false);


--
-- Data for Name: ias_event_extended; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ias_event_extended (event_id, name, value) FROM stdin;
\.


--
-- Data for Name: ibs_states; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ibs_states (name, value) FROM stdin;
AUTO_CLEAN_CONNECTION_LOG	0
AUTO_CLEAN_CREDIT_CHANGE	0
AUTO_CLEAN_USER_AUDIT_LOG	0
AUTO_CLEAN_SNAPSHOTS	0
AUTO_CLEAN_WEB_ANALYZER_LOG	1209600
LOWLOAD_JOBS	1716969666
MIDNIGHT_JOBS	1716955265
\.


--
-- Data for Name: internet_bw_snapshot; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY internet_bw_snapshot (snp_date, user_id, in_rate, out_rate) FROM stdin;
\.


--
-- Data for Name: internet_charge_rules; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY internet_charge_rules (charge_id, charge_rule_id, start_time, end_time, time_limit, ras_id, cpm, cpk, assumed_kps, bandwidth_limit_kbytes, bw_transmit_leaf_id, bw_receive_leaf_id) FROM stdin;
1	1	00:00:00	23:59:59	\N	\N	0.00	0.00	8000000	800000000	\N	\N
\.


--
-- Data for Name: internet_onlines_snapshot; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY internet_onlines_snapshot (snp_date, ras_id, value) FROM stdin;
\.


--
-- Data for Name: ippool; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ippool (ippool_id, ippool_name, ippool_comment) FROM stdin;
\.


--
-- Name: ippool_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('ippool_id_seq', 1, false);


--
-- Data for Name: ippool_ips; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ippool_ips (ippool_id, ip) FROM stdin;
\.


--
-- Data for Name: normal_users; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY normal_users (user_id, normal_username, normal_password) FROM stdin;
1	aria	8520
390	peji	2022
3	behnam2	9340
358	torkamandi	3830
279	noor	6785
6	afi	7007
7	maral	7700
103	roghayeh	2641
5	hesari	9009
340	mostafa103	3003
361	peyghambari	6754
321	madah	7422
200	sadri	5804
261	parisa	9595
252	anderson	4545
280	mashaal1	1121
281	vahideh	0602
132	chtalaee	1230
284	kazemipc	1230
286	saljooghi	1230
351	majid	1010
353	behnam4	4414
289	bama2020	7763
24	seyfi	6371
391	soltan	2922
322	sajad	1847
104	sahar57	5757
105	msharif1	4431
355	babak	1230
301	mostafa104	4080
290	bama2021	5183
30	mostafa	1020
31	mostafa100	1001
158	goldoost	2230
33	jafari07	9407
400	tkeyhan	6363
441	sheyda	2672
36	farhad13	5012
258	sheyda2	6668
357	gorjian3	1230
39	sania	2022
40	mehdi	8080
291	bama2022	1354
201	fatemeh40	0640
415	zomorod	9620
44	saber	8308
45	yaser	5566
46	marjan	9990
47	jalal	7705
177	askari	3365
444	mvo1	1121
50	amin45	3645
323	rahimi11	1212
52	mohammad90	9090
313	mostafa105	1005
315	nikdel4	4474
111	dastanpoor	1230
292	bama2023	6164
324	bama2030	2575
445	nazemian	6996
59	sadr	4704
164	sina	4055
61	ashoori3	3303
62	dashti	3191
63	melika70	7007
325	bama2031	8266
65	arast3	3000
67	arast	4236
68	kiana	2343
410	ashkan	2128
70	mirkazemi	5356
319	keyhan5	5500
359	c106	2200
326	bama2032	2563
74	setareh14	1414
75	samira2	6098
76	jamali	1230
77	navid	5759
134	bama2000	1891
305	shshakeri	2849
645	mirzayi	7614
262	rahimi10	1021
344	elnaz	1983
83	esfandiari	7525
84	soheyl	7770
476	arianpc	1230
293	bama2024	5896
87	akbari	8740
447	sheyda3	3391
89	m37	7770
90	m35	5005
91	m32	9527
92	melisa	1891
93	danesh	9247
179	farzan1	3303
119	mahroo	8278
96	negar11	6660
97	negar12	7770
367	bama2006	8261
107	mahsa96	3696
150	banisadr	4242
120	aliasghar	8819
112	reza	3330
294	bama2025	5678
448	msm20	2021
101	rezaei	0548
108	cheraghi	6155
394	jalalizadeh	2020
135	bama2001	7436
113	ati	1230
540	mehrabi	4617
114	c103	1230
115	javadi	8541
121	mcb	1230
122	farhadi1000	1000
116	daftar10	1230
118	daftar	1230
123	hadadi	1230
124	rtp	1230
136	bama2002	5284
126	khhosseini	1230
127	khhosseini2	1230
128	sabzineh	1230
295	bama2026	5595
130	daftartehran	1230
419	barati	3535
137	bama2003	6752
647	fatemeh1	5252
139	bama2005	7684
524	talkhabloo	5531
141	bama2007	7621
142	bama2008	2266
143	bama2009	7832
145	hamidreza	9017
146	msm48	4800
147	ahatami2d	3330
421	afsane	9990
437	m40	4005
151	fjafari	2016
452	leila24	5024
153	hosniyeh	0010
154	maleki2	7252
204	hamidr	7770
542	samira3	3303
157	rad	1338
170	rahimi	5258
160	sheyda77	1377
161	maleki	5992
162	fkarimi	1643
171	bagheri	2560
167	shirani	9006
168	mahla	5605
180	bargh	9560
188	saghayi2	1231
306	nekoonampc	1230
307	yusefi	5758
181	elna2	9091
183	farzan2	3030
185	aryo1	1133
189	boss	1230
263	parastoo	6369
422	arash	9991
195	sepideh	1260
396	hatami2	1230
176	kami	3884
197	tofighi	1475
202	daftarforoosh	1230
207	zalipc	1230
210	karbasi3	3309
282	parsa	6464
212	nazanin2	9498
285	saryazdi	8949
287	saghar	3769
288	mylove	8520
300	mostafa102	7000
303	nazanin	1090
461	neishaboori	2222
309	navid39	9039
311	sarikhan2	1230
312	zahra	2728
314	mostafa106	7770
235	bama2010	7197
236	bama2011	3538
237	bama2012	5138
238	bama2013	3181
239	bama2014	1836
240	bama2015	6768
241	bama2016	7436
242	bama2017	9923
243	bama2018	4747
244	bama2019	1747
248	negin1	0404
433	danial	9259
457	hadadi2	5056
255	fariba	8777
259	vafa	7778
260	msm72	7078
269	aali	7156
272	alipoor	9673
360	solmaz	1370
274	sasan2	0909
275	msm78	3505
276	msm37	3748
277	msm35	3536
278	msm36	6055
316	msm80	7600
317	amin66	4266
318	nima	6862
320	najar	7707
327	bama2033	6824
328	bama2034	6584
329	bama2035	9396
330	bama2036	4992
331	bama2037	9844
332	bama2038	1611
333	bama2039	1952
335	elmira	2090
337	rose	1230
338	c105	1005
339	arsa	1980
341	aghakhani2	1230
342	salimian57	1657
345	ghafari10	1010
477	omid1	6581
348	farnaz	3000
350	mostafa108	8811
352	erfan	8589
354	beheshti	8343
362	setayesh	4005
363	morteza	1624
364	golnaz	0496
379	bama2050	5576
380	bama2051	3283
381	bama2052	6138
382	bama2053	4837
383	bama2054	5754
384	bama2055	1868
385	bama2056	2596
386	bama2057	2696
611	javdani	5241
388	bama2059	4932
393	meysam	7398
650	melika	2171
399	mandana	3030
401	talkhabloo1	0853
403	niusha	7770
404	farzin1	1144
405	farzin2	1155
406	minoo	5053
407	tahmineh	4849
408	navayi	3219
411	mostofi1	4454
423	sahar1	7099
417	farzaneh	1314
425	jalalizadeh3	6060
427	namazian	5245
428	hanieh2	2235
430	msm26	2026
431	bama2004	7618
538	nhasibi2	7171
440	mahshid2	1230
442	aghasemi	7343
446	seyed	1600
450	farnaz2	1230
453	mtaheri	1448
455	sanjabi10	1010
458	leyla	6850
462	mostafa109	1009
464	esi	8312
467	bameri	7816
469	asemi	6959
471	mahshid	2010
472	nabikhani	1403
475	bagheri2	2929
478	saba	7729
480	reyhaneh	2442
481	msm86	6676
505	asal2	9000
506	parisa2	2001
508	armand	1013
509	mehdipoor	1121
510	raeesi	5185
513	akbari2	2220
516	msm60	6009
520	leila25	2525
521	naser15	1230
523	amirk	1230
420	daftar11	1230
525	barkhordari	1230
526	zohreh	3311
527	soheyl2	2222
528	bama2070	1111
544	salimian	7846
532	ghazal	9096
613	m41	4140
535	maleki1	9090
537	mohammadi66	6066
543	imani2	3862
556	alipoor2	2202
557	ebi	1230
560	ghasemi	7093
563	kahari	1230
565	ansari	1230
566	mina	0909
568	bama2081	4496
569	bama2082	1961
570	bama2083	9711
571	bama2084	8859
572	bama2085	4125
573	bama2086	7738
574	bama2087	4154
429	milad	3725
184	fa8	8811
402	skeyhan	6262
187	navab	0739
190	kami2	4422
397	sedighi	2010
198	shaghayegh	1376
336	radan	3545
356	saharh	8080
208	karbasi1	1121
209	karbasi2	9972
213	maziyarpc	1230
463	jalalizadeh10	6091
247	asal	9000
250	zand	8881
254	behrooz	2770
460	jalalizadeh2	3030
257	shahin2	4455
465	noora	1718
268	hatami	1701
270	ataheri	2761
271	mostafa10	2010
283	mona	6989
296	bama2027	9836
297	bama2028	8834
298	bama2029	9463
304	maroof	9200
310	sarikhan1	1121
366	yazdan	5566
349	mostafa107	5560
368	bama2040	9321
369	bama2041	6891
370	bama2042	8588
371	bama2043	5424
372	bama2044	1942
373	bama2045	7951
374	bama2046	1828
375	bama2047	7466
376	bama2048	2959
377	bama2049	5192
409	saragol	7097
412	mostofi	1230
413	maleki3	3343
414	imani	4741
418	padideh	3331
468	shahi	1230
436	m38	8880
438	poneh	1077
470	salmani	7770
473	ghafari20	2030
479	aghasemi2	2202
493	bama2060	9347
494	bama2061	8597
495	bama2062	8352
496	bama2063	3985
589	habibi4	4441
498	bama2065	7182
499	bama2066	9888
500	bama2067	5262
501	bama2068	4731
502	bama2069	6925
504	bameri2	2220
512	msm24	2425
514	heliya	7981
515	maziyar	5646
522	rezakermani	1230
530	sanjabi20	1230
646	ghadimi	7893
545	bama2071	8821
546	bama2072	4958
547	bama2073	2246
548	bama2074	4492
549	bama2075	8496
550	bama2076	5999
551	bama2077	4597
552	bama2078	2644
553	bama2079	6541
554	bama2080	8898
558	alvani	7893
561	mohammad91	3535
562	batool	0606
564	zhestmezon	1121
575	bama2088	6425
576	bama2089	9539
577	bama2090	4712
579	nazanin10	3502
580	hidokht	6018
581	bama2091	6000
582	mostafa110	1001
629	makki1	4857
584	khavari	7505
585	fereshteh	1087
586	alipoor3	4445
587	akbar6	1090
588	bama2064	4918
590	bama2092	2822
591	bama2093	3614
592	bama2094	5775
593	bama2095	7592
594	bama2096	5967
595	bama2097	3559
596	bama2098	8363
597	bama2099	7756
598	bama2100	4636
599	bama2101	2271
601	maral2	2222
602	shekufeh	4440
603	najafi	4321
604	harandi	1090
605	mirzaei	2525
606	hossein	2045
628	bama2058	5745
610	habibi1	3911
607	ayousefi2	1230
612	roodaki	1440
627	aliasadi	3953
615	bama2102	4732
616	bama2103	2994
617	bama2104	1628
618	bama2105	5733
619	bama2106	5685
620	bama2107	8226
621	bama2108	9819
622	bama2109	7351
623	bama2110	5615
624	bama2111	2768
203	ab2	1230
630	habibi2	9292
531	moein	5900
648	fatemeh2	2992
649	tdmsm	1234
631	bama2112	9126
632	bama2113	1538
633	bama2114	4926
634	bama2115	1118
635	bama2116	1629
636	bama2117	9653
637	bama2118	2491
638	bama2119	5664
639	bama2120	5991
640	bama2121	1945
644	elham1	1122
\.


--
-- Data for Name: persistent_lan_users; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY persistent_lan_users (user_id, persistent_lan_mac, persistent_lan_ip, persistent_lan_ras_id) FROM stdin;
\.


--
-- Data for Name: ras; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ras (ras_id, ras_description, ras_ip, ras_type, radius_secret, active, comment) FROM stdin;
1	169	78.39.57.169	Mikrotik	one3	t	
2	172	78.39.57.172	Mikrotik	Progmaster	t	
3	173	78.39.57.173	Mikrotik	Progmaster	t	
4	174	78.39.57.174	Mikrotik	Progmaster	t	
5	78.39.57.175	78.39.57.175	Mikrotik	Progmaster	t	
6	163	78.39.57.163	Mikrotik	Progmaster	t	
7	21	95.38.155.21	Mikrotik	One3	t	
8	9	95.38.155.9	Mikrotik	one3	t	
9	78.39.57.165	78.39.57.165	Mikrotik	Progmaster	t	
\.


--
-- Data for Name: ras_attrs; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ras_attrs (ras_id, attr_name, attr_value) FROM stdin;
9	mikrotik_ssh_password	Progmaster
9	mikrotik_ssh_username	IBSng
\.


--
-- Name: ras_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('ras_id_seq', 9, true);


--
-- Data for Name: ras_ippools; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ras_ippools (serial, ras_id, ippool_id) FROM stdin;
\.


--
-- Name: ras_ippools_serial_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('ras_ippools_serial_seq', 1, false);


--
-- Data for Name: ras_ports; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY ras_ports (ras_id, port_name, phone, type, comment) FROM stdin;
\.


--
-- Data for Name: tariff_prefix_list; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY tariff_prefix_list (tariff_id, prefix_id, prefix_code, prefix_name, cpm, free_seconds, min_duration, round_to, min_chargable_duration) FROM stdin;
\.


--
-- Name: tariff_prefix_list_tariff_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('tariff_prefix_list_tariff_id_seq', 1, false);


--
-- Data for Name: user_attrs; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY user_attrs (user_id, attr_name, attr_value) FROM stdin;
475	first_login	1714384635
269	first_login	1716657476
1	first_login	1707412073
209	traffic_periodic_accounting_daily_reset	1718773200
3	abs_exp_date	1707932834
341	abs_exp_date	1717257478
587	abs_exp_date	1726255285
329	traffic_periodic_accounting_daily_reset	1717477200
116	first_login	1715421794
75	traffic_periodic_accounting_daily	72
112	multi_login	12
360	traffic_periodic_accounting_daily_reset	1712635200
393	first_login	1715458060
257	first_login	1716488129
342	traffic_periodic_accounting_daily_reset	1714885200
93	first_login	1711539605
367	first_login	1713759435
255	first_login	1711305440
359	traffic_periodic_accounting_daily_reset	1717819200
114	abs_exp_date	1711463074
521	traffic_periodic_accounting_daily_reset	1715745600
5	traffic_periodic_accounting_daily_reset	1720929600
5	first_login	1713211001
7	abs_exp_date	1708712169
183	lock	2/3/2024
396	traffic_periodic_accounting_daily_usage	10742041
204	traffic_periodic_accounting_daily_reset	1718686800
124	traffic_periodic_accounting_daily_usage	431059012
327	traffic_periodic_accounting_daily_reset	1714798800
7	traffic_periodic_accounting_daily_reset	1709960400
561	first_login	1716927951
333	traffic_periodic_accounting_daily_reset	1715058000
33	traffic_periodic_accounting_daily_reset	1720497600
362	traffic_periodic_accounting_daily_reset	1717819200
314	first_login	1716905927
33	first_login	1712790337
462	first_login	1716718973
116	traffic_periodic_accounting_daily	90
107	abs_exp_date	1708686491
139	first_login	1710859541
103	first_login	1715843614
114	traffic_periodic_accounting_daily	45
602	abs_exp_date	1717184544
317	abs_exp_date	1740860275
252	first_login	1714424065
7	first_login	1707416812
181	first_login	1715970813
283	first_login	1716804615
431	first_login	1710797061
300	first_login	1716893726
312	abs_exp_date	1717872172
122	abs_exp_date	1708470405
458	first_login	1714507732
647	traffic_periodic_accounting_daily_reset	1732420800
62	traffic_periodic_accounting_daily	80
411	abs_exp_date	1717496860
303	traffic_periodic_accounting_daily_reset	1716958800
402	first_login	1715850432
158	traffic_periodic_accounting_daily_reset	1723438800
198	first_login	1715882595
316	first_login	1714886241
321	first_login	1714805375
96	abs_exp_date	1708214283
97	abs_exp_date	1708214347
272	first_login	1711488726
190	first_login	1716908663
30	abs_exp_date	1709320687
313	traffic_periodic_accounting_daily_reset	1717131600
420	first_login	1714472351
101	traffic_periodic_accounting_daily_reset	1710046800
329	first_login	1712355320
521	first_login	1713212456
87	first_login	1711976441
345	first_login	1715074020
1	traffic_periodic_accounting_daily_reset	1741496400
151	first_login	1707915143
414	abs_exp_date	1712953557
481	traffic_periodic_accounting_daily_reset	1717819200
544	abs_exp_date	1721217452
201	traffic_periodic_accounting_daily_reset	1722052800
558	first_login	1715198376
154	traffic_periodic_accounting_daily_reset	1721019600
36	abs_exp_date	1708890035
263	first_login	1708809284
528	first_login	1715545581
372	traffic_periodic_accounting_daily_reset	1715486400
31	abs_exp_date	1708802586
171	traffic_periodic_accounting_daily	30
6	first_login	1711565234
289	traffic_periodic_accounting_daily_reset	1714366800
303	first_login	1711817047
132	multi_login	2
321	traffic_periodic_accounting_daily_reset	1717218000
36	traffic_periodic_accounting_daily_reset	1709960400
36	first_login	1707422269
352	first_login	1715159039
30	traffic_periodic_accounting_daily_reset	1709960400
30	first_login	1707420322
361	first_login	1715274570
119	first_login	1715428771
356	first_login	1715244430
356	traffic_periodic_accounting_daily_reset	1717736400
399	first_login	1715232190
118	first_login	1715432297
400	first_login	1715804046
40	abs_exp_date	1738181269
40	traffic_periodic_accounting_daily	356
40	traffic_periodic_accounting_daily_limit	734003200000
40	traffic_periodic_accounting_daily_reset	1738126800
40	first_login	1707423456
44	abs_exp_date	1737750135
45	abs_exp_date	1737750245
45	traffic_periodic_accounting_daily	351
45	traffic_periodic_accounting_daily_limit	796917760000
373	traffic_periodic_accounting_daily_usage	10275
407	traffic_periodic_accounting_daily_reset	1718164800
436	multi_login	1
200	first_login	1715919115
276	traffic_periodic_accounting_daily_reset	1719291600
62	traffic_periodic_accounting_daily_limit	146800640000
471	abs_exp_date	1719495774
292	traffic_periodic_accounting_daily_reset	1714453200
330	traffic_periodic_accounting_daily_reset	1714885200
269	traffic_periodic_accounting_daily_reset	1719205200
460	abs_exp_date	1713387088
612	traffic_periodic_accounting_daily_reset	1718683200
177	traffic_periodic_accounting_daily_reset	1710738000
292	first_login	1709306371
74	abs_exp_date	1708641908
115	abs_exp_date	1709652792
50	traffic_periodic_accounting_daily_reset	1725512400
75	traffic_periodic_accounting_daily_limit	104857600000
115	traffic_periodic_accounting_daily_reset	1710133200
540	traffic_periodic_accounting_daily_usage	697379
278	traffic_periodic_accounting_daily_reset	1719291600
295	first_login	1709311318
513	first_login	1716832556
50	first_login	1707433603
101	first_login	1707469211
62	traffic_periodic_accounting_daily_reset	1721192400
65	abs_exp_date	1710886125
209	first_login	1716207478
116	traffic_periodic_accounting_daily_limit	41943040000
348	first_login	1715024797
304	traffic_periodic_accounting_daily_reset	1711774800
261	first_login	1711393388
565	traffic_periodic_accounting_daily	365
311	traffic_periodic_accounting_daily	34
542	abs_exp_date	1729111653
412	traffic_periodic_accounting_daily_reset	1726027200
61	traffic_periodic_accounting_daily_reset	1709960400
61	first_login	1707429709
313	first_login	1714921211
461	first_login	1715080527
506	traffic_periodic_accounting_daily_reset	1744344000
168	first_login	1712324798
89	traffic_periodic_accounting_daily	87
89	traffic_periodic_accounting_daily_limit	62914560000
380	first_login	1714936821
276	first_login	1714976433
44	traffic_periodic_accounting_daily_reset	1738904400
44	first_login	1707435303
97	traffic_periodic_accounting_daily_reset	1710046800
114	traffic_periodic_accounting_daily_limit	52428800000
77	multi_login	2
279	first_login	1716876982
97	first_login	1707462098
360	first_login	1710057115
428	first_login	1715938658
46	traffic_periodic_accounting_daily_reset	1739077200
190	traffic_periodic_accounting_daily_reset	1718600400
210	first_login	1716208778
371	traffic_periodic_accounting_daily_reset	1715486400
74	traffic_periodic_accounting_daily_reset	1710046800
290	traffic_periodic_accounting_daily_reset	1714366800
113	traffic_periodic_accounting_daily_reset	1720501200
375	first_login	1714325445
91	traffic_periodic_accounting_daily_reset	1711774800
91	first_login	1707456626
74	first_login	1707460637
260	first_login	1716410069
470	traffic_periodic_accounting_daily_reset	1717387200
464	first_login	1715262248
412	first_login	1710517883
176	first_login	1710877296
271	first_login	1716222425
384	traffic_periodic_accounting_daily_reset	1717646400
146	abs_exp_date	1708969618
47	traffic_periodic_accounting_daily_reset	1738990800
476	abs_exp_date	1731445624
177	first_login	1708161647
47	first_login	1707462646
361	traffic_periodic_accounting_daily_reset	1717819200
362	first_login	1712259464
550	traffic_periodic_accounting_daily_reset	1719547200
607	traffic_periodic_accounting_daily	90
145	first_login	1715534927
108	first_login	1714750282
524	abs_exp_date	1719855421
495	traffic_periodic_accounting_daily_reset	1718164800
479	traffic_periodic_accounting_daily_reset	1717732800
132	traffic_periodic_accounting_daily_reset	1718082000
116	traffic_periodic_accounting_daily_reset	1717909200
423	first_login	1715971997
45	traffic_periodic_accounting_daily_reset	1737694800
45	first_login	1707435340
248	first_login	1715196310
393	traffic_periodic_accounting_daily_reset	1717992000
512	first_login	1715682420
75	traffic_periodic_accounting_daily_reset	1713675600
75	first_login	1707455546
150	abs_exp_date	1718963632
401	first_login	1715595085
65	traffic_periodic_accounting_daily_reset	1712552400
65	first_login	1707442508
254	first_login	1716321308
311	traffic_periodic_accounting_daily_limit	52428800000
77	traffic_periodic_accounting_daily_reset	1723006800
77	first_login	1707465320
46	abs_exp_date	1738095970
47	abs_exp_date	1738096019
50	abs_exp_date	1725569339
24	first_login	1715196263
59	traffic_periodic_accounting_daily_reset	1720328400
52	traffic_periodic_accounting_daily	72
52	traffic_periodic_accounting_daily_limit	125829120000
263	traffic_periodic_accounting_daily_reset	1713934800
179	traffic_periodic_accounting_daily_reset	1721793600
146	traffic_periodic_accounting_daily_reset	1710392400
319	first_login	1714595802
551	traffic_periodic_accounting_daily_reset	1716955200
306	first_login	1714673912
359	first_login	1712933270
63	abs_exp_date	1709157720
564	traffic_periodic_accounting_daily_reset	1722225600
52	first_login	1713724494
61	abs_exp_date	1709416406
63	traffic_periodic_accounting_daily_reset	1710046800
271	traffic_periodic_accounting_daily_reset	1719205200
355	traffic_periodic_accounting_daily_reset	1717650000
458	traffic_periodic_accounting_daily_reset	1717041600
283	traffic_periodic_accounting_daily_reset	1724475600
520	traffic_periodic_accounting_daily_reset	1720929600
508	traffic_periodic_accounting_daily_reset	1718164800
481	first_login	1715285079
179	first_login	1714053415
280	first_login	1716458461
153	first_login	1714729737
111	abs_exp_date	1709287536
121	first_login	1716977329
287	first_login	1714639171
430	first_login	1716137919
500	traffic_periodic_accounting_daily_reset	1718596800
268	first_login	1712666686
198	traffic_periodic_accounting_daily_reset	1723784400
573	traffic_periodic_accounting_daily_reset	1717560000
70	abs_exp_date	1713047555
67	traffic_periodic_accounting_daily	100
67	traffic_periodic_accounting_daily_limit	157286400000
118	traffic_periodic_accounting_daily	90
93	traffic_periodic_accounting_daily_reset	1720328400
644	traffic_periodic_accounting_daily_reset	1719288000
171	traffic_periodic_accounting_daily_limit	52428800000
108	traffic_periodic_accounting_daily_reset	1723006800
337	traffic_periodic_accounting_daily_usage	2936443009
160	traffic_periodic_accounting_daily_reset	1710565200
75	abs_exp_date	1713653270
493	traffic_periodic_accounting_daily_reset	1718596800
364	traffic_periodic_accounting_daily_reset	1717819200
212	abs_exp_date	1710714809
437	first_login	1710871548
92	traffic_periodic_accounting_daily_reset	1710046800
92	first_login	1707456236
170	traffic_periodic_accounting_daily_reset	1723611600
358	traffic_periodic_accounting_daily_reset	1717736400
305	traffic_periodic_accounting_daily_reset	1724734800
83	abs_exp_date	1709162325
147	abs_exp_date	1739296566
243	traffic_periodic_accounting_daily_reset	1714107600
315	first_login	1714678178
83	traffic_periodic_accounting_daily_reset	1709960400
83	first_login	1707434619
105	first_login	1712063470
311	traffic_periodic_accounting_daily_reset	1718082000
286	first_login	1714329254
368	traffic_periodic_accounting_daily_reset	1712808000
468	traffic_periodic_accounting_daily_reset	1719979200
468	first_login	1712213416
335	traffic_periodic_accounting_daily_reset	1717390800
59	first_login	1710885896
162	traffic_periodic_accounting_daily_reset	1715749200
164	multi_login	1
311	first_login	1715606902
91	traffic_periodic_accounting_daily	50
91	traffic_periodic_accounting_daily_limit	62914560000
277	first_login	1714937189
355	first_login	1716660089
409	first_login	1715688480
300	traffic_periodic_accounting_daily_reset	1719550800
135	traffic_periodic_accounting_daily_reset	1710565200
564	first_login	1714495727
429	first_login	1715980299
322	first_login	1714750920
63	first_login	1707470428
87	abs_exp_date	1728646670
357	first_login	1712649883
336	traffic_periodic_accounting_daily_reset	1717390800
573	first_login	1715015123
427	abs_exp_date	1716585036
506	first_login	1712857072
107	traffic_periodic_accounting_daily_reset	1710046800
270	first_login	1716719922
111	traffic_periodic_accounting_daily_reset	1710306000
304	first_login	1709214579
431	traffic_periodic_accounting_daily_reset	1715918400
516	traffic_periodic_accounting_daily_reset	1718337600
167	traffic_periodic_accounting_daily_reset	1723525200
330	first_login	1709747694
508	first_login	1716140737
407	first_login	1710450871
446	traffic_periodic_accounting_daily_reset	1719115200
446	first_login	1711361415
103	traffic_periodic_accounting_daily	66
103	traffic_periodic_accounting_daily_limit	104857600000
134	first_login	1715886900
275	first_login	1716400954
563	traffic_periodic_accounting_daily_reset	1722139200
213	traffic_periodic_accounting_daily_reset	1723957200
268	traffic_periodic_accounting_daily_reset	1720242000
586	traffic_periodic_accounting_daily_reset	1722916800
505	traffic_periodic_accounting_daily_reset	1720497600
260	traffic_periodic_accounting_daily_reset	1719032400
70	first_login	1707449561
188	first_login	1713438855
128	first_login	1712046443
242	traffic_periodic_accounting_daily_reset	1719291600
161	traffic_periodic_accounting_daily_reset	1720933200
87	traffic_periodic_accounting_daily	67
50	traffic_periodic_accounting_daily	210
50	traffic_periodic_accounting_daily_limit	471859200000
87	traffic_periodic_accounting_daily_limit	104857600000
113	first_login	1713776145
421	traffic_periodic_accounting_daily_reset	1742356800
427	traffic_periodic_accounting_daily_reset	1717214400
203	traffic_periodic_accounting_daily_reset	1723870800
146	first_login	1707807005
465	traffic_periodic_accounting_daily_reset	1717214400
250	first_login	1708574860
345	traffic_periodic_accounting_daily_reset	1717563600
90	traffic_periodic_accounting_daily_reset	1722657600
52	traffic_periodic_accounting_daily_reset	1719810000
201	first_login	1714338209
91	abs_exp_date	1711755638
92	abs_exp_date	1708818250
629	traffic_periodic_accounting_daily_reset	1721880000
470	first_login	1712232496
183	abs_exp_date	1714052265
413	traffic_periodic_accounting_daily_reset	1718251200
316	traffic_periodic_accounting_daily_reset	1717131600
501	traffic_periodic_accounting_daily_reset	1716696000
556	traffic_periodic_accounting_daily_reset	1719288000
586	first_login	1715206374
523	first_login	1714852520
188	traffic_periodic_accounting_daily_reset	1718514000
455	traffic_periodic_accounting_daily_reset	1719547200
147	traffic_periodic_accounting_daily_reset	1739250000
180	traffic_periodic_accounting_daily_reset	1716008400
68	abs_exp_date	1709331378
77	abs_exp_date	1719356068
243	first_login	1708938972
240	traffic_periodic_accounting_daily_reset	1711429200
516	first_login	1715771181
143	traffic_periodic_accounting_daily_reset	1713589200
46	first_login	1707582057
465	first_login	1715287007
364	first_login	1715261913
118	traffic_periodic_accounting_daily_limit	41943040000
340	traffic_periodic_accounting_daily_reset	1717477200
644	first_login	1716759619
241	traffic_periodic_accounting_daily_reset	1712120400
135	first_login	1708014387
96	traffic_periodic_accounting_daily_reset	1710046800
143	first_login	1708438918
472	first_login	1714987169
437	traffic_periodic_accounting_daily_reset	1721188800
250	traffic_periodic_accounting_daily_reset	1713675600
70	traffic_periodic_accounting_daily_reset	1717736400
96	first_login	1707462073
121	traffic_periodic_accounting_daily_reset	1717995600
621	traffic_periodic_accounting_daily_reset	1719201600
104	abs_exp_date	1708684353
74	traffic_periodic_accounting_daily_usage	1957289651
258	first_login	1714389573
323	traffic_periodic_accounting_daily_reset	1725339600
107	first_login	1707477259
438	traffic_periodic_accounting_daily_reset	1742356800
305	first_login	1709232970
212	traffic_periodic_accounting_daily_reset	1710997200
368	first_login	1710235170
645	traffic_periodic_accounting_daily_reset	1724558400
239	first_login	1712663170
524	traffic_periodic_accounting_daily_reset	1719806400
68	traffic_periodic_accounting_daily_reset	1710046800
68	first_login	1707472148
5	multi_login	1
463	traffic_periodic_accounting_daily_reset	1717214400
101	abs_exp_date	1709020365
540	traffic_periodic_accounting_daily_reset	1716523200
170	first_login	1708102792
137	first_login	1708163430
111	first_login	1707720199
376	traffic_periodic_accounting_daily_reset	1717300800
467	first_login	1714912817
342	first_login	1709758935
342	abs_exp_date	1714676571
411	traffic_periodic_accounting_daily_reset	1718424000
357	traffic_periodic_accounting_daily_reset	1722920400
438	first_login	1710876651
520	first_login	1713206508
104	traffic_periodic_accounting_daily_reset	1710046800
104	first_login	1707477678
162	first_login	1707984006
157	traffic_periodic_accounting_daily_reset	1723352400
115	first_login	1707581566
6	traffic_periodic_accounting_daily_reset	1720328400
344	traffic_periodic_accounting_daily_reset	1717477200
358	first_login	1710009302
448	first_login	1714840322
202	first_login	1714998646
337	traffic_periodic_accounting_daily_reset	1712206800
310	first_login	1714583057
461	traffic_periodic_accounting_daily_reset	1717128000
422	traffic_periodic_accounting_daily_reset	1742443200
328	first_login	1712247612
296	traffic_periodic_accounting_daily_reset	1711861200
291	first_login	1709222408
441	first_login	1716416803
427	first_login	1711398937
504	first_login	1715346830
552	traffic_periodic_accounting_daily_reset	1717041600
281	first_login	1716832429
184	abs_exp_date	1709991786
581	multi_login	4
114	traffic_periodic_accounting_daily_usage	227521730
351	traffic_periodic_accounting_daily_reset	1718942400
318	first_login	1716669152
379	traffic_periodic_accounting_daily_reset	1717387200
288	traffic_periodic_accounting_daily_reset	1740632400
285	traffic_periodic_accounting_daily_reset	1714194000
375	traffic_periodic_accounting_daily_reset	1721966400
90	first_login	1714934696
298	traffic_periodic_accounting_daily_reset	1714712400
123	traffic_periodic_accounting_daily_usage	341744145
584	traffic_periodic_accounting_daily_reset	1717473600
128	traffic_periodic_accounting_daily_reset	1721361600
593	traffic_periodic_accounting_daily_reset	1718337600
168	traffic_periodic_accounting_daily_reset	1721365200
212	first_login	1708431697
584	first_login	1714938790
561	traffic_periodic_accounting_daily_reset	1719460800
119	traffic_periodic_accounting_daily_reset	1717995600
257	traffic_periodic_accounting_daily_reset	1724216400
236	first_login	1708449995
89	first_login	1715125014
112	traffic_periodic_accounting_daily_reset	1723093200
318	traffic_periodic_accounting_daily_reset	1717131600
147	first_login	1707764157
366	traffic_periodic_accounting_daily_reset	1717905600
312	traffic_periodic_accounting_daily_reset	1718514000
593	first_login	1715789560
291	traffic_periodic_accounting_daily_reset	1714366800
84	first_login	1715465578
236	traffic_periodic_accounting_daily_reset	1718773200
101	traffic_periodic_accounting_daily_usage	6487602521
244	traffic_periodic_accounting_daily_reset	1714194000
207	traffic_periodic_accounting_daily_reset	1718686800
160	first_login	1707981208
596	first_login	1716032434
363	traffic_periodic_accounting_daily_reset	1717819200
111	traffic_periodic_accounting_daily_usage	677042178
307	first_login	1716834383
284	traffic_periodic_accounting_daily_reset	1711602000
114	traffic_periodic_accounting_daily_reset	1711429200
114	first_login	1707575453
540	first_login	1713953136
505	first_login	1712766984
297	first_login	1709395354
297	traffic_periodic_accounting_daily_reset	1714539600
566	traffic_periodic_accounting_daily_reset	1717041600
213	first_login	1708426299
645	first_login	1716820364
238	first_login	1708793811
89	traffic_periodic_accounting_daily_reset	1722574800
241	first_login	1709546164
568	traffic_periodic_accounting_daily_reset	1717300800
618	traffic_periodic_accounting_daily_reset	1718942400
124	traffic_periodic_accounting_daily_reset	1710306000
366	first_login	1710199362
463	first_login	1712066173
515	traffic_periodic_accounting_daily_reset	1718251200
126	traffic_periodic_accounting_daily	37
126	traffic_periodic_accounting_daily_limit	52428800000
532	first_login	1716148231
411	first_login	1710666151
419	first_login	1716062028
208	first_login	1716197349
414	traffic_periodic_accounting_daily_reset	1713067200
207	first_login	1711791891
239	traffic_periodic_accounting_daily_reset	1716526800
524	first_login	1713387444
127	abs_exp_date	1720689770
157	first_login	1707886707
581	first_login	1714659176
127	traffic_periodic_accounting_daily_reset	1720929600
127	traffic_periodic_accounting_daily	99
394	first_login	1716488663
377	first_login	1712168814
124	first_login	1707720473
377	traffic_periodic_accounting_daily_reset	1717300800
376	first_login	1712140666
328	traffic_periodic_accounting_daily_reset	1717390800
118	traffic_periodic_accounting_daily_reset	1723093200
180	first_login	1708240476
123	traffic_periodic_accounting_daily_reset	1710306000
123	first_login	1707720416
200	traffic_periodic_accounting_daily_reset	1718686800
326	traffic_periodic_accounting_daily_reset	1714798800
136	traffic_periodic_accounting_daily_reset	1713243600
337	first_login	1709667423
406	traffic_periodic_accounting_daily_reset	1720584000
61	traffic_periodic_accounting_daily_usage	28999110191
312	first_login	1710013504
612	first_login	1716143264
289	first_login	1709214953
619	traffic_periodic_accounting_daily_reset	1719115200
574	traffic_periodic_accounting_daily_reset	1717646400
31	traffic_periodic_accounting_daily_reset	1710306000
31	first_login	1707774327
379	first_login	1712223716
415	first_login	1710609332
307	traffic_periodic_accounting_daily_reset	1717045200
613	traffic_periodic_accounting_daily_reset	1723867200
574	first_login	1715098153
262	traffic_periodic_accounting_daily_reset	1724302800
262	first_login	1708789530
288	first_login	1709155429
404	traffic_periodic_accounting_daily_reset	1718078400
603	traffic_periodic_accounting_daily_reset	1718251200
502	traffic_periodic_accounting_daily_reset	1716696000
161	first_login	1712137782
408	traffic_periodic_accounting_daily_reset	1720756800
646	abs_exp_date	1717101180
447	first_login	1716756869
244	first_login	1709052542
327	first_login	1709656735
445	traffic_periodic_accounting_daily_reset	1719115200
120	traffic_periodic_accounting_daily_reset	1717995600
67	traffic_periodic_accounting_daily_reset	1724648400
414	first_login	1710542558
422	first_login	1710956970
150	traffic_periodic_accounting_daily	129
150	traffic_periodic_accounting_daily_limit	209715200000
501	first_login	1714126551
427	traffic_periodic_accounting_daily	68
405	traffic_periodic_accounting_daily_reset	1718251200
325	traffic_periodic_accounting_daily_reset	1712379600
298	first_login	1709560642
323	first_login	1709829798
420	traffic_periodic_accounting_daily_reset	1718424000
613	first_login	1716146628
339	traffic_periodic_accounting_daily_reset	1714798800
441	traffic_periodic_accounting_daily_reset	1718942400
274	traffic_periodic_accounting_daily_reset	1719205200
296	first_login	1709316206
204	traffic_periodic_accounting_daily_usage	1688592850
427	traffic_periodic_accounting_daily_limit	125829120000
83	traffic_periodic_accounting_daily_usage	1124876044
261	traffic_periodic_accounting_daily_reset	1716526800
421	first_login	1710868339
417	traffic_periodic_accounting_daily_reset	1713153600
351	first_login	1711192599
558	traffic_periodic_accounting_daily_reset	1716868800
532	traffic_periodic_accounting_daily_reset	1718856000
320	first_login	1714595935
326	first_login	1709655913
455	first_login	1711826481
542	traffic_periodic_accounting_daily_reset	1729569600
363	first_login	1710091832
457	traffic_periodic_accounting_daily_reset	1714536000
452	traffic_periodic_accounting_daily_reset	1714190400
462	traffic_periodic_accounting_daily_reset	1717214400
96	traffic_periodic_accounting_daily_usage	12811387262
560	traffic_periodic_accounting_daily_reset	1716868800
385	traffic_periodic_accounting_daily_reset	1715054400
154	first_login	1712215745
324	first_login	1709650693
339	first_login	1709696799
36	traffic_periodic_accounting_daily_usage	1069191602
333	first_login	1709925157
127	traffic_periodic_accounting_daily_limit	104857600000
344	first_login	1709759325
162	abs_exp_date	1715325551
374	traffic_periodic_accounting_daily_reset	1718596800
440	traffic_periodic_accounting_daily_reset	1721880000
324	traffic_periodic_accounting_daily_reset	1714798800
560	first_login	1714360305
535	traffic_periodic_accounting_daily_reset	1718856000
282	traffic_periodic_accounting_daily_reset	1724475600
285	first_login	1709060470
399	traffic_periodic_accounting_daily_reset	1718078400
184	traffic_periodic_accounting_daily	21
184	traffic_periodic_accounting_daily_limit	36700160000
97	traffic_periodic_accounting_daily_usage	8662477538
317	traffic_periodic_accounting_daily_reset	1740891600
317	first_login	1709410726
141	traffic_periodic_accounting_daily_reset	1710910800
167	first_login	1708033480
141	first_login	1708341352
248	traffic_periodic_accounting_daily	78
136	first_login	1708103198
183	traffic_periodic_accounting_daily	68
183	traffic_periodic_accounting_daily_limit	125829120000
145	traffic_periodic_accounting_daily_reset	1723266000
530	traffic_periodic_accounting_daily_reset	1729051200
621	first_login	1716658135
405	first_login	1710500722
374	first_login	1710858473
185	traffic_periodic_accounting_daily_reset	1713330000
414	traffic_periodic_accounting_daily_usage	864536428
499	traffic_periodic_accounting_daily_reset	1715918400
92	traffic_periodic_accounting_daily_usage	9503176081
383	traffic_periodic_accounting_daily_reset	1715054400
183	traffic_periodic_accounting_daily_reset	1714021200
183	first_login	1708202733
423	traffic_periodic_accounting_daily_reset	1718510400
619	first_login	1716560111
417	first_login	1710617192
350	traffic_periodic_accounting_daily_reset	1717736400
515	first_login	1713124458
195	traffic_periodic_accounting_daily_reset	1719979200
460	traffic_periodic_accounting_daily_reset	1714536000
618	first_login	1716402545
279	traffic_periodic_accounting_daily_reset	1719291600
403	traffic_periodic_accounting_daily_reset	1741838400
445	first_login	1711358784
240	first_login	1708874239
480	first_login	1715629557
605	traffic_periodic_accounting_daily_reset	1718251200
563	first_login	1714379032
287	traffic_periodic_accounting_daily_reset	1719464400
452	first_login	1711668424
460	first_login	1711952915
68	traffic_periodic_accounting_daily_usage	3272672839
195	first_login	1712216252
371	first_login	1710347925
7	traffic_periodic_accounting_daily_usage	1372795915
293	first_login	1709308287
286	traffic_periodic_accounting_daily_reset	1716872400
185	first_login	1708199029
105	traffic_periodic_accounting_daily_reset	1720414800
406	first_login	1710502391
568	first_login	1714746102
457	first_login	1711972228
258	traffic_periodic_accounting_daily_reset	1719032400
476	traffic_periodic_accounting_daily	220
243	traffic_periodic_accounting_daily_usage	28986708
396	traffic_periodic_accounting_daily_reset	1712808000
331	traffic_periodic_accounting_daily_reset	1714971600
594	traffic_periodic_accounting_daily_reset	1718510400
160	traffic_periodic_accounting_daily_usage	1654358653
31	traffic_periodic_accounting_daily_usage	781054723
373	traffic_periodic_accounting_daily_reset	1713326400
296	traffic_periodic_accounting_daily_usage	0
597	traffic_periodic_accounting_daily_reset	1718596800
467	traffic_periodic_accounting_daily_reset	1717387200
187	traffic_periodic_accounting_daily_reset	1723698000
450	first_login	1715529261
396	first_login	1710267434
181	traffic_periodic_accounting_daily_reset	1723698000
320	traffic_periodic_accounting_daily_reset	1717218000
197	traffic_periodic_accounting_daily_reset	1723784400
197	first_login	1708293674
352	traffic_periodic_accounting_daily_reset	1717650000
527	first_login	1716178227
189	traffic_periodic_accounting_daily_reset	1723784400
189	first_login	1708258550
550	first_login	1714398013
433	traffic_periodic_accounting_daily_reset	1718596800
571	traffic_periodic_accounting_daily_reset	1718856000
433	first_login	1710867028
127	first_login	1712397549
385	first_login	1712503247
177	traffic_periodic_accounting_daily_usage	2081622275
547	traffic_periodic_accounting_daily_reset	1716696000
509	first_login	1715583252
325	first_login	1709828744
104	traffic_periodic_accounting_daily_usage	10306103962
404	first_login	1710363698
499	first_login	1713369182
272	traffic_periodic_accounting_daily_reset	1721797200
293	traffic_periodic_accounting_daily_reset	1714453200
473	traffic_periodic_accounting_daily_reset	1717473600
383	first_login	1712494003
571	first_login	1716306304
440	first_login	1711541097
176	traffic_periodic_accounting_daily_reset	1721106000
310	traffic_periodic_accounting_daily_reset	1717045200
388	traffic_periodic_accounting_daily_reset	1717732800
425	traffic_periodic_accounting_daily_reset	1714449600
572	traffic_periodic_accounting_daily_reset	1717560000
504	traffic_periodic_accounting_daily_reset	1717819200
535	first_login	1713732956
367	traffic_periodic_accounting_daily_reset	1720497600
409	traffic_periodic_accounting_daily_reset	1718164800
531	first_login	1716487611
284	first_login	1709059343
362	abs_exp_date	1715197309
628	traffic_periodic_accounting_daily_reset	1719115200
146	traffic_periodic_accounting_daily_usage	19893395
298	traffic_periodic_accounting_daily_usage	478422
185	traffic_periodic_accounting_daily_usage	25054097
597	first_login	1716059897
530	first_login	1713528237
494	traffic_periodic_accounting_daily_reset	1715400000
590	traffic_periodic_accounting_daily_reset	1718164800
531	traffic_periodic_accounting_daily_reset	1718769600
126	first_login	1712055622
332	traffic_periodic_accounting_daily_reset	1715745600
601	traffic_periodic_accounting_daily_reset	1717992000
126	traffic_periodic_accounting_daily_reset	1717304400
62	first_login	1714384192
120	first_login	1715688509
557	traffic_periodic_accounting_daily_reset	1729742400
136	traffic_periodic_accounting_daily_usage	201781
391	traffic_periodic_accounting_daily_reset	1717905600
386	traffic_periodic_accounting_daily_reset	1715140800
382	traffic_periodic_accounting_daily_reset	1716004800
75	traffic_periodic_accounting_daily_usage	7286849481
442	traffic_periodic_accounting_daily_reset	1718942400
290	traffic_periodic_accounting_daily_usage	17290166
187	first_login	1716359887
542	first_login	1714029905
544	traffic_periodic_accounting_daily_reset	1721880000
413	first_login	1716076753
275	traffic_periodic_accounting_daily_reset	1719291600
469	traffic_periodic_accounting_daily_reset	1719979200
235	first_login	1708449780
590	first_login	1715609455
164	first_login	1716909515
496	traffic_periodic_accounting_daily_reset	1715659200
478	traffic_periodic_accounting_daily_reset	1717732800
440	traffic_periodic_accounting_daily_usage	259460691
137	traffic_periodic_accounting_daily_reset	1713330000
471	traffic_periodic_accounting_daily_reset	1719979200
457	traffic_periodic_accounting_daily_usage	465194689
107	traffic_periodic_accounting_daily_usage	35265876502
84	traffic_periodic_accounting_daily_reset	1717905600
572	first_login	1715008811
623	traffic_periodic_accounting_daily_reset	1719288000
633	traffic_periodic_accounting_daily_usage	102708992
237	traffic_periodic_accounting_daily_usage	1025780676
403	first_login	1710365529
594	first_login	1715963448
204	first_login	1713705513
259	traffic_periodic_accounting_daily_reset	1711256400
259	first_login	1708685994
240	traffic_periodic_accounting_daily_usage	1497340104
628	first_login	1716602236
524	traffic_periodic_accounting_daily	75
406	abs_exp_date	1720548903
422	traffic_periodic_accounting_daily_usage	367833940
475	traffic_periodic_accounting_daily_reset	1717473600
210	traffic_periodic_accounting_daily_reset	1718946000
277	traffic_periodic_accounting_daily_reset	1719291600
543	traffic_periodic_accounting_daily_reset	1716609600
615	traffic_periodic_accounting_daily_reset	1718769600
235	traffic_periodic_accounting_daily_reset	1713589200
521	traffic_periodic_accounting_daily_usage	26083116
248	traffic_periodic_accounting_daily_limit	136314880000
588	traffic_periodic_accounting_daily_reset	1717819200
472	traffic_periodic_accounting_daily_reset	1717560000
65	traffic_periodic_accounting_daily_usage	6933353454
24	traffic_periodic_accounting_daily_reset	1722920400
588	first_login	1715237843
76	first_login	1715244578
576	traffic_periodic_accounting_daily_reset	1717732800
601	first_login	1715447413
576	first_login	1715191894
526	traffic_periodic_accounting_daily_reset	1718596800
615	first_login	1716225348
538	traffic_periodic_accounting_daily_reset	1729396800
30	traffic_periodic_accounting_daily_usage	2579579020
538	first_login	1713863352
70	traffic_periodic_accounting_daily_usage	162815247
338	traffic_periodic_accounting_daily_reset	1712206800
338	first_login	1709668464
425	first_login	1711912261
115	traffic_periodic_accounting_daily_usage	3404614733
151	traffic_periodic_accounting_daily_reset	1718254800
130	traffic_periodic_accounting_daily_reset	1718082000
130	first_login	1713003417
312	traffic_periodic_accounting_daily_limit	157286400000
237	traffic_periodic_accounting_daily_reset	1711170000
237	first_login	1708628398
331	first_login	1709825033
238	traffic_periodic_accounting_daily_usage	2146655
292	traffic_periodic_accounting_daily_usage	24062188
309	traffic_periodic_accounting_daily_reset	1717045200
309	first_login	1709300644
183	traffic_periodic_accounting_daily_usage	2616839178
63	traffic_periodic_accounting_daily_usage	3200459179
184	lock	2/3/2024
284	traffic_periodic_accounting_daily_usage	1350885420
322	traffic_periodic_accounting_daily_reset	1717304400
569	traffic_periodic_accounting_daily_reset	1717387200
436	traffic_periodic_accounting_daily_reset	1724212800
290	first_login	1709216314
569	first_login	1714828734
235	traffic_periodic_accounting_daily_usage	20942309
354	traffic_periodic_accounting_daily_reset	1717650000
595	traffic_periodic_accounting_daily_reset	1718510400
477	traffic_periodic_accounting_daily_reset	1717646400
548	traffic_periodic_accounting_daily_reset	1719460800
319	traffic_periodic_accounting_daily_reset	1717218000
556	first_login	1714149149
112	first_login	1714394822
394	traffic_periodic_accounting_daily_reset	1718424000
548	first_login	1714319595
602	traffic_periodic_accounting_daily_reset	1718251200
306	traffic_periodic_accounting_daily_reset	1716958800
143	traffic_periodic_accounting_daily_usage	685533
526	first_login	1716065024
390	traffic_periodic_accounting_daily_reset	1717905600
285	traffic_periodic_accounting_daily_usage	246294467
551	first_login	1714398827
171	traffic_periodic_accounting_daily_reset	1718427600
589	traffic_periodic_accounting_daily_reset	1717819200
327	traffic_periodic_accounting_daily_usage	11685795
575	traffic_periodic_accounting_daily_reset	1717646400
592	traffic_periodic_accounting_daily_reset	1718251200
602	first_login	1715669936
599	traffic_periodic_accounting_daily_reset	1718683200
335	first_login	1715666505
261	traffic_periodic_accounting_daily_usage	1035143705
397	traffic_periodic_accounting_daily_reset	1716264000
524	traffic_periodic_accounting_daily_limit	136314880000
263	traffic_periodic_accounting_daily_usage	1399286485
647	first_login	1716894569
329	traffic_periodic_accounting_daily_usage	57511498
509	traffic_periodic_accounting_daily_reset	1718078400
397	first_login	1713725715
544	first_login	1714132863
553	traffic_periodic_accounting_daily_reset	1717128000
545	traffic_periodic_accounting_daily_reset	1717387200
289	traffic_periodic_accounting_daily_usage	63726954
495	first_login	1713020388
552	first_login	1714492916
585	traffic_periodic_accounting_daily_reset	1717560000
242	first_login	1714323429
134	traffic_periodic_accounting_daily_reset	1718082000
547	first_login	1714159090
372	first_login	1710350996
603	first_login	1715699901
577	traffic_periodic_accounting_daily_reset	1717905600
301	first_login	1714659095
382	first_login	1713456674
353	traffic_periodic_accounting_daily_reset	1717650000
312	traffic_periodic_accounting_daily	99
384	traffic_periodic_accounting_daily_usage	178146137
255	traffic_periodic_accounting_daily_reset	1716354000
248	traffic_periodic_accounting_daily_reset	1721883600
331	traffic_periodic_accounting_daily_usage	172603104
476	traffic_periodic_accounting_daily_limit	314572800000
338	traffic_periodic_accounting_daily_usage	1523003211
164	traffic_periodic_accounting_daily_reset	1718341200
402	traffic_periodic_accounting_daily_reset	1718078400
141	traffic_periodic_accounting_daily_usage	766116919
478	first_login	1712608829
494	first_login	1712855757
592	first_login	1715713944
522	first_login	1716120712
622	traffic_periodic_accounting_daily_reset	1719201600
336	first_login	1716912100
565	traffic_periodic_accounting_daily_limit	367001600000
46	multi_login	1
460	traffic_periodic_accounting_daily_usage	8768589622
579	traffic_periodic_accounting_daily_reset	1717128000
415	traffic_periodic_accounting_daily_usage	93901799
259	traffic_periodic_accounting_daily_usage	2661828120
330	traffic_periodic_accounting_daily_usage	52604410
153	traffic_periodic_accounting_daily_reset	1718254800
546	traffic_periodic_accounting_daily_reset	1717473600
250	traffic_periodic_accounting_daily_usage	163384661
496	first_login	1713136276
469	traffic_periodic_accounting_daily_usage	50053777
244	traffic_periodic_accounting_daily_usage	50505376
384	first_login	1712501453
372	traffic_periodic_accounting_daily_usage	1967109
479	first_login	1712612916
373	first_login	1710789602
87	traffic_periodic_accounting_daily_reset	1719032400
238	traffic_periodic_accounting_daily_reset	1713934800
332	first_login	1710597241
577	first_login	1715349061
349	traffic_periodic_accounting_daily_reset	1717736400
633	traffic_periodic_accounting_daily_reset	1719460800
549	first_login	1714321501
447	traffic_periodic_accounting_daily_reset	1719288000
180	traffic_periodic_accounting_daily_usage	2547394541
599	first_login	1716138528
553	first_login	1714555825
171	first_login	1715832050
527	traffic_periodic_accounting_daily_reset	1718596800
566	first_login	1714480932
595	first_login	1715964900
291	traffic_periodic_accounting_daily_usage	144958254
607	traffic_periodic_accounting_daily_limit	31457280000
90	multi_login	1
304	traffic_periodic_accounting_daily_usage	3858411132
39	traffic_periodic_accounting_daily_reset	1717736400
587	traffic_periodic_accounting_daily_reset	1731124800
471	first_login	1712238905
142	traffic_periodic_accounting_daily_reset	1723870800
370	traffic_periodic_accounting_daily_usage	7560767
370	traffic_periodic_accounting_daily_reset	1712808000
575	first_login	1715100822
294	traffic_periodic_accounting_daily_reset	1711861200
294	first_login	1709308505
294	traffic_periodic_accounting_daily_usage	682766567
369	traffic_periodic_accounting_daily_reset	1712808000
369	first_login	1710238141
370	first_login	1710253763
135	traffic_periodic_accounting_daily_usage	1215494907
341	traffic_periodic_accounting_daily_reset	1717477200
341	first_login	1709740800
579	first_login	1714541437
328	traffic_periodic_accounting_daily_usage	208264104
281	traffic_periodic_accounting_daily_reset	1724475600
350	first_login	1715757870
545	first_login	1714843956
401	traffic_periodic_accounting_daily_reset	1720670400
388	first_login	1712594438
591	traffic_periodic_accounting_daily_reset	1718251200
301	traffic_periodic_accounting_daily_reset	1717131600
498	traffic_periodic_accounting_daily_reset	1718424000
549	traffic_periodic_accounting_daily_reset	1719460800
631	traffic_periodic_accounting_daily_reset	1719374400
493	first_login	1713433738
213	traffic_periodic_accounting_daily_usage	5941785458
565	traffic_periodic_accounting_daily_reset	1745985600
368	traffic_periodic_accounting_daily_usage	1626604331
315	traffic_periodic_accounting_daily_reset	1717131600
557	first_login	1714211677
274	first_login	1716732517
419	traffic_periodic_accounting_daily_reset	1718337600
436	first_login	1714934608
620	traffic_periodic_accounting_daily_reset	1719288000
431	traffic_periodic_accounting_daily_usage	85176503
477	first_login	1715454639
629	first_login	1716721423
582	traffic_periodic_accounting_daily_reset	1717300800
390	first_login	1715396824
630	traffic_periodic_accounting_daily_reset	1719374400
360	traffic_periodic_accounting_daily_usage	10216711475
616	traffic_periodic_accounting_daily_reset	1718769600
589	first_login	1715254968
377	traffic_periodic_accounting_daily_usage	210960541
406	traffic_periodic_accounting_daily	117
562	traffic_periodic_accounting_daily_reset	1722312000
369	traffic_periodic_accounting_daily_usage	5644907812
408	first_login	1715667377
295	traffic_periodic_accounting_daily_usage	151620945
581	traffic_periodic_accounting_daily_reset	1717214400
374	traffic_periodic_accounting_daily_usage	25599899107
254	traffic_periodic_accounting_daily_reset	1718946000
202	traffic_periodic_accounting_daily_reset	1718686800
622	first_login	1716661705
543	first_login	1714042965
151	traffic_periodic_accounting_daily_usage	264726581
406	traffic_periodic_accounting_daily_limit	209715200000
325	traffic_periodic_accounting_daily_usage	329277689
546	first_login	1714926564
580	traffic_periodic_accounting_daily_reset	1746072000
326	traffic_periodic_accounting_daily_usage	21379536
417	traffic_periodic_accounting_daily_usage	631138611
39	first_login	1715145662
324	traffic_periodic_accounting_daily_usage	33262763
585	first_login	1715053595
137	traffic_periodic_accounting_daily_usage	55203512
332	traffic_periodic_accounting_daily_usage	8512855
410	traffic_periodic_accounting_daily_reset	1742011200
410	first_login	1710502747
212	traffic_periodic_accounting_daily_usage	52695709255
91	traffic_periodic_accounting_daily_usage	50184159462
453	abs_exp_date	1711796674
293	traffic_periodic_accounting_daily_usage	98379402
500	traffic_periodic_accounting_daily_usage	237836868
203	traffic_periodic_accounting_daily_usage	17443299
359	traffic_periodic_accounting_daily_usage	1634508883
448	traffic_periodic_accounting_daily_reset	1721880000
502	first_login	1714140229
633	first_login	1716887241
350	traffic_periodic_accounting_daily_usage	2170786111
45	traffic_periodic_accounting_daily_usage	130049768509
438	traffic_periodic_accounting_daily_usage	15788026353
452	abs_exp_date	1712703958
311	traffic_periodic_accounting_daily_usage	3317268096
587	first_login	1715586228
577	traffic_periodic_accounting_daily_usage	507222120
162	traffic_periodic_accounting_daily_usage	5204613094
241	traffic_periodic_accounting_daily_usage	2480638972
563	traffic_periodic_accounting_daily_usage	11272655724
628	traffic_periodic_accounting_daily_usage	6669681792
386	first_login	1712589625
300	traffic_periodic_accounting_daily_usage	34499094
494	traffic_periodic_accounting_daily_usage	13378252568
105	traffic_periodic_accounting_daily_usage	18937568635
547	traffic_periodic_accounting_daily_usage	1478775296
464	traffic_periodic_accounting_daily_reset	1719806400
354	first_login	1715084774
590	traffic_periodic_accounting_daily_usage	1233426759
67	first_login	1716139201
498	traffic_periodic_accounting_daily_usage	539772968
380	traffic_periodic_accounting_daily_reset	1717473600
650	traffic_periodic_accounting_daily_reset	1724731200
624	traffic_periodic_accounting_daily_usage	305939814
118	traffic_periodic_accounting_daily_usage	304138040
379	traffic_periodic_accounting_daily_usage	12585586
603	multi_login	4
636	traffic_periodic_accounting_daily_usage	186939552
562	first_login	1714585185
412	traffic_periodic_accounting_daily_usage	2370697977
573	traffic_periodic_accounting_daily_usage	2382913385
605	first_login	1715712640
616	first_login	1716207654
121	traffic_periodic_accounting_daily_usage	448585331
339	traffic_periodic_accounting_daily_usage	194196527
276	traffic_periodic_accounting_daily_usage	97488028
523	traffic_periodic_accounting_daily_reset	1718424000
572	traffic_periodic_accounting_daily_usage	1147372751
208	traffic_periodic_accounting_daily_reset	1718686800
582	first_login	1714767884
190	traffic_periodic_accounting_daily_usage	7038098565
280	traffic_periodic_accounting_daily_reset	1719291600
560	traffic_periodic_accounting_daily_usage	7999712589
450	traffic_periodic_accounting_daily_reset	1719288000
598	traffic_periodic_accounting_daily_usage	2324545088
381	traffic_periodic_accounting_daily_usage	23833435221
469	first_login	1712233175
258	traffic_periodic_accounting_daily_usage	775925834
333	traffic_periodic_accounting_daily_usage	18810761
239	traffic_periodic_accounting_daily_usage	249460092
629	traffic_periodic_accounting_daily_usage	170821466
498	first_login	1713290801
589	traffic_periodic_accounting_daily_usage	36869714967
314	traffic_periodic_accounting_daily_reset	1717131600
453	traffic_periodic_accounting_daily_reset	1714276800
453	first_login	1711727689
620	first_login	1716735983
591	first_login	1715674997
87	traffic_periodic_accounting_daily_usage	51137820957
353	first_login	1715147944
522	traffic_periodic_accounting_daily_reset	1718337600
198	traffic_periodic_accounting_daily_usage	2519573300
458	traffic_periodic_accounting_daily_usage	26249664791
301	traffic_periodic_accounting_daily_usage	953066316
430	traffic_periodic_accounting_daily_usage	1264080307
542	traffic_periodic_accounting_daily_usage	33356462555
355	traffic_periodic_accounting_daily_usage	638213948
557	traffic_periodic_accounting_daily_usage	11833323202
295	traffic_periodic_accounting_daily_reset	1714453200
623	first_login	1716721878
203	first_login	1716726736
158	first_login	1715705122
453	traffic_periodic_accounting_daily_usage	43684779
610	traffic_periodic_accounting_daily_reset	1718596800
610	first_login	1716053740
537	traffic_periodic_accounting_daily_reset	1729310400
630	first_login	1716789672
565	first_login	1714462163
425	traffic_periodic_accounting_daily_usage	3969476559
510	traffic_periodic_accounting_daily_reset	1728532800
297	traffic_periodic_accounting_daily_usage	112286798
275	traffic_periodic_accounting_daily_usage	105427054
385	traffic_periodic_accounting_daily_usage	9512553805
349	traffic_periodic_accounting_daily_usage	1299538356
502	traffic_periodic_accounting_daily_usage	114128016
375	traffic_periodic_accounting_daily_usage	94640456
179	traffic_periodic_accounting_daily_usage	2942127039
427	traffic_periodic_accounting_daily_usage	19448545579
512	traffic_periodic_accounting_daily_reset	1718251200
46	traffic_periodic_accounting_daily_usage	198009830515
480	traffic_periodic_accounting_daily_reset	1717819200
595	traffic_periodic_accounting_daily_usage	1700287895
50	traffic_periodic_accounting_daily_usage	8649656252
650	first_login	1716976599
202	traffic_periodic_accounting_daily_usage	1847787636
495	traffic_periodic_accounting_daily_usage	85269466
617	traffic_periodic_accounting_daily_usage	6930681530
254	traffic_periodic_accounting_daily_usage	819994114
366	traffic_periodic_accounting_daily_usage	89781338560
388	traffic_periodic_accounting_daily_usage	436100203
584	traffic_periodic_accounting_daily_usage	21145971678
552	traffic_periodic_accounting_daily_usage	2352629159
309	traffic_periodic_accounting_daily_usage	12978240966
381	traffic_periodic_accounting_daily_reset	1715054400
381	first_login	1712512489
646	traffic_periodic_accounting_daily_reset	1719460800
607	traffic_periodic_accounting_daily_reset	1723521600
646	first_login	1716926485
505	traffic_periodic_accounting_daily_usage	1324922456
592	traffic_periodic_accounting_daily_usage	674262803
437	traffic_periodic_accounting_daily_usage	604646680
631	first_login	1716831711
516	traffic_periodic_accounting_daily_usage	712132755
514	traffic_periodic_accounting_daily_reset	1718251200
530	traffic_periodic_accounting_daily_usage	4890518230
407	traffic_periodic_accounting_daily_usage	4110317171
279	traffic_periodic_accounting_daily_usage	5585092603
549	traffic_periodic_accounting_daily_usage	14452516
278	traffic_periodic_accounting_daily_usage	230021514
510	traffic_periodic_accounting_daily_usage	24289628307
413	traffic_periodic_accounting_daily_usage	1668155825
429	traffic_periodic_accounting_daily_reset	1718510400
39	traffic_periodic_accounting_daily_usage	20039842484
473	traffic_periodic_accounting_daily_usage	21310848491
553	traffic_periodic_accounting_daily_usage	15905609194
410	traffic_periodic_accounting_daily_usage	19019854737
128	traffic_periodic_accounting_daily_usage	1278071491
597	traffic_periodic_accounting_daily_usage	8146980188
623	traffic_periodic_accounting_daily_usage	3178364317
470	traffic_periodic_accounting_daily_usage	49374722
400	traffic_periodic_accounting_daily_reset	1718078400
342	traffic_periodic_accounting_daily_usage	33641933521
164	traffic_periodic_accounting_daily_usage	817868698
526	traffic_periodic_accounting_daily_usage	9120819052
371	traffic_periodic_accounting_daily_usage	159420890
475	traffic_periodic_accounting_daily_usage	5295127157
606	traffic_periodic_accounting_daily_reset	1723435200
496	traffic_periodic_accounting_daily_usage	37139489999
606	first_login	1715719060
367	traffic_periodic_accounting_daily_usage	41953130
544	traffic_periodic_accounting_daily_usage	1065400565
537	first_login	1713776771
599	traffic_periodic_accounting_daily_usage	492996952
393	traffic_periodic_accounting_daily_usage	11260658167
617	traffic_periodic_accounting_daily_reset	1718769600
545	traffic_periodic_accounting_daily_usage	19291667775
47	traffic_periodic_accounting_daily_usage	136211791517
607	traffic_periodic_accounting_daily_usage	1897870155
380	traffic_periodic_accounting_daily_usage	206567094
452	traffic_periodic_accounting_daily_usage	610454875
624	traffic_periodic_accounting_daily_reset	1719288000
624	first_login	1716742367
461	traffic_periodic_accounting_daily_usage	4660124072
619	traffic_periodic_accounting_daily_usage	3913231225
415	traffic_periodic_accounting_daily_reset	1715745600
480	traffic_periodic_accounting_daily_usage	2513099888
134	traffic_periodic_accounting_daily_usage	15713393803
76	traffic_periodic_accounting_daily_usage	48716166168
362	traffic_periodic_accounting_daily_usage	748939975
622	traffic_periodic_accounting_daily_usage	247860825
383	traffic_periodic_accounting_daily_usage	22781019502
510	first_login	1713040402
139	traffic_periodic_accounting_daily_usage	519092667
348	traffic_periodic_accounting_daily_reset	1717563600
103	traffic_periodic_accounting_daily_reset	1718859600
142	first_login	1713328249
636	traffic_periodic_accounting_daily_reset	1719460800
322	traffic_periodic_accounting_daily_usage	15647702680
648	traffic_periodic_accounting_daily_reset	1732420800
354	traffic_periodic_accounting_daily_usage	4682289626
419	traffic_periodic_accounting_daily_usage	3347510638
634	traffic_periodic_accounting_daily_usage	89475976
605	traffic_periodic_accounting_daily_usage	1719605166
274	traffic_periodic_accounting_daily_usage	1245891044
303	traffic_periodic_accounting_daily_usage	207482960
522	traffic_periodic_accounting_daily_usage	139160056
127	traffic_periodic_accounting_daily_usage	524556595
195	traffic_periodic_accounting_daily_usage	11005975444
84	traffic_periodic_accounting_daily_usage	2067880150
621	traffic_periodic_accounting_daily_usage	775065487
145	traffic_periodic_accounting_daily_usage	1243943650
550	traffic_periodic_accounting_daily_usage	27998065
421	traffic_periodic_accounting_daily_usage	4783294052
24	traffic_periodic_accounting_daily_usage	15023330531
316	traffic_periodic_accounting_daily_usage	1370693273
428	traffic_periodic_accounting_daily_usage	3941750231
132	first_login	1716814615
481	traffic_periodic_accounting_daily_usage	591163394
317	traffic_periodic_accounting_daily_usage	36038248091
527	traffic_periodic_accounting_daily_usage	16971815529
508	traffic_periodic_accounting_daily_usage	661757962
400	traffic_periodic_accounting_daily_usage	3007335197
116	traffic_periodic_accounting_daily_usage	4106262901
357	traffic_periodic_accounting_daily_usage	118667038
465	traffic_periodic_accounting_daily_usage	12245638179
270	traffic_periodic_accounting_daily_reset	1719205200
277	traffic_periodic_accounting_daily_usage	177618253
187	traffic_periodic_accounting_daily_usage	1501708379
585	traffic_periodic_accounting_daily_usage	989547852
167	traffic_periodic_accounting_daily_usage	373443162
286	traffic_periodic_accounting_daily_usage	1017356476
569	traffic_periodic_accounting_daily_usage	1278842125
139	traffic_periodic_accounting_daily_reset	1716008400
455	traffic_periodic_accounting_daily_usage	9505094100
236	traffic_periodic_accounting_daily_usage	14622638571
473	first_login	1714971873
252	traffic_periodic_accounting_daily_reset	1718946000
598	traffic_periodic_accounting_daily_reset	1718769600
598	first_login	1716194130
386	traffic_periodic_accounting_daily_usage	27629745705
89	traffic_periodic_accounting_daily_usage	45750201057
429	traffic_periodic_accounting_daily_usage	5879555732
551	traffic_periodic_accounting_daily_usage	4281565359
607	first_login	1715804786
132	traffic_periodic_accounting_daily_usage	2608938468
479	traffic_periodic_accounting_daily_usage	303679457
611	traffic_periodic_accounting_daily_usage	6940595358
90	traffic_periodic_accounting_daily_usage	12697808657
197	traffic_periodic_accounting_daily_usage	22405066042
126	traffic_periodic_accounting_daily_usage	867206873
524	traffic_periodic_accounting_daily_usage	4373662485
189	traffic_periodic_accounting_daily_usage	22597414665
500	first_login	1713510659
446	traffic_periodic_accounting_daily_usage	2538392608
523	traffic_periodic_accounting_daily_usage	2575992438
33	traffic_periodic_accounting_daily_usage	6268351102
336	traffic_periodic_accounting_daily_usage	14003443379
561	traffic_periodic_accounting_daily_usage	522572799
568	traffic_periodic_accounting_daily_usage	3374626210
464	traffic_periodic_accounting_daily_usage	11484467075
617	first_login	1716226633
548	traffic_periodic_accounting_daily_usage	7879578
341	traffic_periodic_accounting_daily_usage	29671868945
120	traffic_periodic_accounting_daily_usage	2402290892
581	traffic_periodic_accounting_daily_usage	13485763961
556	traffic_periodic_accounting_daily_usage	99365113
546	traffic_periodic_accounting_daily_usage	771176099
430	traffic_periodic_accounting_daily_reset	1718596800
554	traffic_periodic_accounting_daily_reset	1717214400
554	first_login	1714674195
255	traffic_periodic_accounting_daily_usage	144538818
340	first_login	1715023676
382	traffic_periodic_accounting_daily_usage	11129216798
580	first_login	1714588502
463	traffic_periodic_accounting_daily_usage	65480946
618	traffic_periodic_accounting_daily_usage	890697568
636	first_login	1716915354
319	traffic_periodic_accounting_daily_usage	16020064710
408	traffic_periodic_accounting_daily_usage	2320403654
478	traffic_periodic_accounting_daily_usage	367390408
321	traffic_periodic_accounting_daily_usage	6404850875
648	first_login	1716929156
467	traffic_periodic_accounting_daily_usage	10577841026
436	traffic_periodic_accounting_daily_usage	7652687127
278	first_login	1716914330
499	traffic_periodic_accounting_daily_usage	212491413
271	traffic_periodic_accounting_daily_usage	485527851
630	traffic_periodic_accounting_daily_usage	324703342
501	traffic_periodic_accounting_daily_usage	36751383523
445	traffic_periodic_accounting_daily_usage	2243940619
647	traffic_periodic_accounting_daily_usage	1592667682
157	traffic_periodic_accounting_daily_usage	122655604077
576	traffic_periodic_accounting_daily_usage	287256425
361	traffic_periodic_accounting_daily_usage	19834407384
376	traffic_periodic_accounting_daily_usage	90403392
52	traffic_periodic_accounting_daily_usage	1266064470
596	traffic_periodic_accounting_daily_usage	1946051087
613	traffic_periodic_accounting_daily_usage	1168374715
472	traffic_periodic_accounting_daily_usage	1144295337
399	traffic_periodic_accounting_daily_usage	4934560426
468	traffic_periodic_accounting_daily_usage	3176860248
260	traffic_periodic_accounting_daily_usage	824422115
531	traffic_periodic_accounting_daily_usage	5735793490
565	traffic_periodic_accounting_daily_usage	7668812254
335	traffic_periodic_accounting_daily_usage	5981599212
543	traffic_periodic_accounting_daily_usage	1256975837
313	traffic_periodic_accounting_daily_usage	17365574313
448	traffic_periodic_accounting_daily_usage	125120577
390	traffic_periodic_accounting_daily_usage	10194879498
420	traffic_periodic_accounting_daily_usage	670715833
441	traffic_periodic_accounting_daily_usage	7356104482
504	traffic_periodic_accounting_daily_usage	3651092266
580	traffic_periodic_accounting_daily_usage	9455036010
320	traffic_periodic_accounting_daily_usage	7238925930
112	traffic_periodic_accounting_daily_usage	4180768514
593	traffic_periodic_accounting_daily_usage	405249820
644	traffic_periodic_accounting_daily_usage	448272572
537	traffic_periodic_accounting_daily_usage	83593697482
348	traffic_periodic_accounting_daily_usage	23761294841
562	traffic_periodic_accounting_daily_usage	22113897633
436	traffic_periodic_accounting_daily	90
436	traffic_periodic_accounting_daily_limit	104857600000
345	traffic_periodic_accounting_daily_usage	15020257210
515	traffic_periodic_accounting_daily_usage	58874993747
130	traffic_periodic_accounting_daily_usage	2372882072
627	traffic_periodic_accounting_daily_reset	1718856000
627	first_login	1716323910
405	traffic_periodic_accounting_daily_usage	22613150750
340	traffic_periodic_accounting_daily_usage	651607832
287	traffic_periodic_accounting_daily_usage	778305763
585	abs_exp_date	1717183881
108	traffic_periodic_accounting_daily_usage	4196288515
210	traffic_periodic_accounting_daily_usage	1329479442
351	traffic_periodic_accounting_daily_usage	78730498806
620	traffic_periodic_accounting_daily_usage	64684826
646	traffic_periodic_accounting_daily_usage	1358273471
397	traffic_periodic_accounting_daily_usage	7451258474
554	traffic_periodic_accounting_daily_usage	10020004012
154	traffic_periodic_accounting_daily_usage	10920897253
411	traffic_periodic_accounting_daily_usage	6375682423
5	traffic_periodic_accounting_daily_usage	46962861598
471	traffic_periodic_accounting_daily_usage	10820018893
200	traffic_periodic_accounting_daily_usage	4856200771
606	traffic_periodic_accounting_daily_usage	9291060567
594	traffic_periodic_accounting_daily_usage	16891394129
344	traffic_periodic_accounting_daily_usage	96684005875
76	traffic_periodic_accounting_daily_reset	1722920400
282	first_login	1716221893
513	traffic_periodic_accounting_daily_usage	1975565737
242	traffic_periodic_accounting_daily_usage	224441244
40	traffic_periodic_accounting_daily_usage	86332427468
513	traffic_periodic_accounting_daily_reset	1718251200
428	traffic_periodic_accounting_daily_reset	1718510400
596	traffic_periodic_accounting_daily_reset	1718596800
586	traffic_periodic_accounting_daily_usage	14216203305
59	traffic_periodic_accounting_daily_usage	8513922287
610	traffic_periodic_accounting_daily_usage	23950451439
535	traffic_periodic_accounting_daily_usage	562477402
558	traffic_periodic_accounting_daily_usage	12745915278
153	traffic_periodic_accounting_daily_usage	3930345276
575	traffic_periodic_accounting_daily_usage	1472502434
209	traffic_periodic_accounting_daily_usage	1808746055
363	traffic_periodic_accounting_daily_usage	103722039958
281	traffic_periodic_accounting_daily_usage	422112338
403	traffic_periodic_accounting_daily_usage	98851959454
391	first_login	1715193795
603	traffic_periodic_accounting_daily_usage	15894531491
323	traffic_periodic_accounting_daily_usage	9144625174
44	traffic_periodic_accounting_daily_usage	112807017149
353	traffic_periodic_accounting_daily_usage	5261446794
493	traffic_periodic_accounting_daily_usage	123622782
591	traffic_periodic_accounting_daily_usage	776953102
514	first_login	1715714587
512	traffic_periodic_accounting_daily_usage	2589654969
566	traffic_periodic_accounting_daily_usage	2124402096
394	traffic_periodic_accounting_daily_usage	2933423285
262	traffic_periodic_accounting_daily_usage	5108264845
77	traffic_periodic_accounting_daily_usage	159940724865
611	traffic_periodic_accounting_daily_reset	1718683200
611	first_login	1716139465
268	traffic_periodic_accounting_daily_usage	8954189309
307	traffic_periodic_accounting_daily_usage	14000035863
113	traffic_periodic_accounting_daily_usage	411732357
450	traffic_periodic_accounting_daily_usage	1978497545
315	traffic_periodic_accounting_daily_usage	35262337376
602	traffic_periodic_accounting_daily_usage	13817335846
401	traffic_periodic_accounting_daily_usage	15622397438
288	traffic_periodic_accounting_daily_usage	38456014006
312	traffic_periodic_accounting_daily_usage	7682910412
170	traffic_periodic_accounting_daily_usage	115889099422
433	traffic_periodic_accounting_daily_usage	81020998186
158	traffic_periodic_accounting_daily_usage	2285365646
391	traffic_periodic_accounting_daily_usage	21900839763
314	traffic_periodic_accounting_daily_usage	16433569633
588	traffic_periodic_accounting_daily_usage	16072503104
514	traffic_periodic_accounting_daily_usage	2667604620
423	traffic_periodic_accounting_daily_usage	4629135033
528	traffic_periodic_accounting_daily_usage	2133972393
528	traffic_periodic_accounting_daily_reset	1718769600
571	traffic_periodic_accounting_daily_usage	5667729500
587	traffic_periodic_accounting_daily_usage	13370430044
349	first_login	1716007644
103	traffic_periodic_accounting_daily_usage	10104028116
181	traffic_periodic_accounting_daily_usage	2082506528
208	traffic_periodic_accounting_daily_usage	16223431964
171	traffic_periodic_accounting_daily_usage	11656997599
579	traffic_periodic_accounting_daily_usage	14361746889
601	traffic_periodic_accounting_daily_usage	3772441970
352	traffic_periodic_accounting_daily_usage	10573669473
207	traffic_periodic_accounting_daily_usage	441156676
506	traffic_periodic_accounting_daily_usage	74317614031
252	traffic_periodic_accounting_daily_usage	2684217238
634	traffic_periodic_accounting_daily_reset	1719460800
634	first_login	1716888764
627	traffic_periodic_accounting_daily_usage	949753511
574	traffic_periodic_accounting_daily_usage	560467777
248	traffic_periodic_accounting_daily_usage	3940412392
442	first_login	1716487953
305	traffic_periodic_accounting_daily_usage	419847404
306	traffic_periodic_accounting_daily_usage	30746413728
404	traffic_periodic_accounting_daily_usage	22270268937
616	traffic_periodic_accounting_daily_usage	794251963
272	traffic_periodic_accounting_daily_usage	21300264459
119	traffic_periodic_accounting_daily_usage	23634428296
176	traffic_periodic_accounting_daily_usage	21338838205
520	traffic_periodic_accounting_daily_usage	14632660613
282	traffic_periodic_accounting_daily_usage	706701233
402	traffic_periodic_accounting_daily_usage	3798137002
6	traffic_periodic_accounting_daily_usage	45626291991
409	traffic_periodic_accounting_daily_usage	25594108132
269	traffic_periodic_accounting_daily_usage	1097391792
582	traffic_periodic_accounting_daily_usage	2766623140
280	traffic_periodic_accounting_daily_usage	469906908
142	traffic_periodic_accounting_daily_usage	2480329612
310	traffic_periodic_accounting_daily_usage	21957682142
442	traffic_periodic_accounting_daily_usage	3808675823
650	traffic_periodic_accounting_daily_usage	269684380
358	traffic_periodic_accounting_daily_usage	6173111139
270	traffic_periodic_accounting_daily_usage	592465369
318	traffic_periodic_accounting_daily_usage	80851094840
509	traffic_periodic_accounting_daily_usage	3812649798
1	traffic_periodic_accounting_daily_usage	18156129215
477	traffic_periodic_accounting_daily_usage	2871745092
538	traffic_periodic_accounting_daily_usage	23412251139
447	traffic_periodic_accounting_daily_usage	364578728
188	traffic_periodic_accounting_daily_usage	20377511560
648	traffic_periodic_accounting_daily_usage	2362497
62	traffic_periodic_accounting_daily_usage	9055359149
201	traffic_periodic_accounting_daily_usage	8726017004
406	traffic_periodic_accounting_daily_usage	15469404803
564	traffic_periodic_accounting_daily_usage	14102033472
631	traffic_periodic_accounting_daily_usage	2033829570
612	traffic_periodic_accounting_daily_usage	8028217461
67	traffic_periodic_accounting_daily_usage	2404666573
615	traffic_periodic_accounting_daily_usage	912771922
356	traffic_periodic_accounting_daily_usage	5124970693
283	traffic_periodic_accounting_daily_usage	2384183110
635	traffic_periodic_accounting_daily_reset	1719460800
635	first_login	1716915516
635	traffic_periodic_accounting_daily_usage	0
532	traffic_periodic_accounting_daily_usage	6273129437
161	traffic_periodic_accounting_daily_usage	6187553001
168	traffic_periodic_accounting_daily_usage	10992401369
147	traffic_periodic_accounting_daily_usage	10347725876
364	traffic_periodic_accounting_daily_usage	919041356
93	traffic_periodic_accounting_daily_usage	4346118919
257	traffic_periodic_accounting_daily_usage	580190942
462	traffic_periodic_accounting_daily_usage	10591924999
645	traffic_periodic_accounting_daily_usage	161407786
\.


--
-- Data for Name: user_audit_log; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY user_audit_log (user_audit_log, admin_id, is_user, object_id, attr_name, old_value, new_value, change_time) FROM stdin;
1	0	f	1	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:05:44.221064
2	0	f	1	multi_login	_NOVALUE_	2	2024-02-08 12:05:56.668326
3	0	f	1	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:06:21.812401
4	0	f	1	traffic_periodic_accounting_daily_limit	_NOVALUE_	10000M	2024-02-08 12:06:21.812401
5	0	f	1	normal_charge	_NOVALUE_	Normal	2024-02-08 12:06:37.002056
6	0	t	1	normal_username	_NOVALUE_	aria	2024-02-08 12:07:35.260865
7	0	f	2	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:09:07.701929
8	0	f	2	multi_login	_NOVALUE_	2	2024-02-08 12:09:22.495793
9	0	f	2	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:09:53.686635
10	0	f	2	traffic_periodic_accounting_daily_limit	_NOVALUE_	20000M	2024-02-08 12:09:53.686635
11	0	f	2	normal_charge	_NOVALUE_	Normal	2024-02-08 12:10:10.399724
12	0	f	3	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:11:05.779445
13	0	f	3	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:11:20.783558
14	0	f	3	traffic_periodic_accounting_daily_limit	_NOVALUE_	35000M	2024-02-08 12:11:20.783558
15	0	f	3	normal_charge	_NOVALUE_	Normal	2024-02-08 12:11:35.296876
16	0	f	3	multi_login	_NOVALUE_	2	2024-02-08 12:12:11.930217
17	0	f	4	normal_charge	_NOVALUE_	Normal	2024-02-08 12:13:46.612804
18	0	f	4	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:14:02.410224
19	0	f	4	multi_login	_NOVALUE_	2	2024-02-08 12:14:15.370713
20	0	f	4	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:16:22.351707
21	0	f	4	traffic_periodic_accounting_daily_limit	_NOVALUE_	50000M	2024-02-08 12:16:22.351707
22	0	f	5	normal_charge	_NOVALUE_	Normal	2024-02-08 12:17:31.315305
23	0	f	5	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:17:50.908198
24	0	f	5	multi_login	_NOVALUE_	2	2024-02-08 12:18:08.044049
25	0	f	5	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:18:23.630936
26	0	f	5	traffic_periodic_accounting_daily_limit	_NOVALUE_	70000M	2024-02-08 12:18:23.630936
27	0	f	6	normal_charge	_NOVALUE_	Normal	2024-02-08 12:28:15.406395
28	0	f	6	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:28:29.284549
29	0	f	6	multi_login	_NOVALUE_	2	2024-02-08 12:28:42.273846
30	0	f	6	traffic_periodic_accounting_daily	_NOVALUE_	30	2024-02-08 12:30:08.016886
31	0	f	6	traffic_periodic_accounting_daily_limit	_NOVALUE_	100000M	2024-02-08 12:30:08.016886
32	0	f	7	rel_exp_date	_NOVALUE_	1 Months	2024-02-08 12:31:12.295015
33	0	f	7	rel_exp_date	1 Months	2 Months	2024-02-08 12:31:21.53047
34	0	f	7	multi_login	_NOVALUE_	2	2024-02-08 12:31:33.660333
35	0	f	7	traffic_periodic_accounting_daily	_NOVALUE_	60	2024-02-08 12:31:52.020739
36	0	f	7	traffic_periodic_accounting_daily_limit	_NOVALUE_	70000M	2024-02-08 12:31:52.020739
37	0	f	7	normal_charge	_NOVALUE_	Normal	2024-02-08 12:32:03.800452
38	0	f	8	normal_charge	_NOVALUE_	Normal	2024-02-08 12:32:26.452592
39	0	f	8	rel_exp_date	_NOVALUE_	3 Months	2024-02-08 12:32:41.424304
40	0	f	8	multi_login	_NOVALUE_	2	2024-02-08 12:32:52.834326
41	0	f	8	traffic_periodic_accounting_daily	_NOVALUE_	90	2024-02-08 12:33:11.761735
42	0	f	8	traffic_periodic_accounting_daily_limit	_NOVALUE_	150000M	2024-02-08 12:33:11.761735
43	0	f	9	normal_charge	_NOVALUE_	Normal	2024-02-08 12:34:15.775568
44	0	f	9	rel_exp_date	_NOVALUE_	3 Months	2024-02-08 12:34:31.19912
45	0	f	9	multi_login	_NOVALUE_	2	2024-02-08 12:34:42.620719
46	0	f	9	traffic_periodic_accounting_daily	_NOVALUE_	90	2024-02-08 12:34:58.311481
47	0	f	9	traffic_periodic_accounting_daily_limit	_NOVALUE_	250000M	2024-02-08 12:34:58.311481
48	0	f	10	normal_charge	_NOVALUE_	Normal	2024-02-08 12:35:29.33204
49	0	f	10	rel_exp_date	_NOVALUE_	6 Months	2024-02-08 12:35:45.988807
50	0	f	10	multi_login	_NOVALUE_	2	2024-02-08 12:35:57.853354
51	0	f	10	traffic_periodic_accounting_daily	_NOVALUE_	180	2024-02-08 12:36:13.600589
52	0	f	10	traffic_periodic_accounting_daily_limit	_NOVALUE_	300000M	2024-02-08 12:36:13.600589
53	0	f	11	normal_charge	_NOVALUE_	Normal	2024-02-08 12:36:54.432154
54	0	f	11	rel_exp_date	_NOVALUE_	6 Months	2024-02-08 12:37:05.724619
55	0	f	11	multi_login	_NOVALUE_	2	2024-02-08 12:37:19.365477
56	0	f	11	traffic_periodic_accounting_daily	_NOVALUE_	180	2024-02-08 12:37:34.182758
57	0	f	11	traffic_periodic_accounting_daily_limit	_NOVALUE_	450000M	2024-02-08 12:37:34.182758
58	0	f	12	normal_charge	_NOVALUE_	Normal	2024-02-08 12:38:33.115078
59	0	f	12	rel_exp_date	_NOVALUE_	12 Months	2024-02-08 12:38:51.069041
60	0	f	12	multi_login	_NOVALUE_	2	2024-02-08 12:39:02.3147
61	0	f	12	traffic_periodic_accounting_daily	_NOVALUE_	365	2024-02-08 12:39:17.214023
62	0	f	12	traffic_periodic_accounting_daily_limit	_NOVALUE_	600000M	2024-02-08 12:39:17.214023
63	0	f	13	normal_charge	_NOVALUE_	Normal	2024-02-08 12:39:51.990447
64	0	f	13	rel_exp_date	_NOVALUE_	365 Days	2024-02-08 12:40:21.819589
65	0	f	13	multi_login	_NOVALUE_	2	2024-02-08 12:40:40.338981
66	0	f	13	traffic_periodic_accounting_daily	_NOVALUE_	365	2024-02-08 12:41:02.24745
67	0	f	13	traffic_periodic_accounting_daily_limit	_NOVALUE_	800000M	2024-02-08 12:41:02.24745
669	0	t	390	normal_username	_NOVALUE_	peji	2024-03-11 15:23:37.530976
670	0	t	391	normal_username	_NOVALUE_	soltan	2024-03-11 15:28:39.395494
70	0	t	3	normal_username	_NOVALUE_	behnam2	2024-02-08 12:47:02.794409
71	0	t	3	abs_exp_date	_NOVALUE_	2024-02-14 12:47	2024-02-08 12:47:14.895839
72	0	t	4	normal_username	_NOVALUE_	behnam4	2024-02-08 12:50:20.952542
73	0	t	5	normal_username	_NOVALUE_	hesari	2024-02-08 13:00:48.971956
74	0	t	5	abs_exp_date	_NOVALUE_	2024-02-15 13:01	2024-02-08 13:01:04.435044
75	0	t	6	normal_username	_NOVALUE_	afi	2024-02-08 13:05:58.259133
76	0	t	6	abs_exp_date	_NOVALUE_	2024-02-08 13:45	2024-02-08 13:06:08.032185
77	0	t	5	abs_exp_date	2024-02-15 13:01	2024-04-15 14:13	2024-02-08 13:13:11.181177
78	0	t	5	group	1-Month-20G	3-Month-150G	2024-02-08 13:13:29.567487
79	0	t	5	traffic_periodic_accounting_daily	90	67	2024-02-08 13:13:53.582873
80	0	t	5	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-02-08 13:13:53.582873
81	0	t	7	normal_username	_NOVALUE_	maral	2024-02-08 13:15:53.380334
82	0	t	7	abs_exp_date	_NOVALUE_	2024-02-23 13:16	2024-02-08 13:16:09.035863
598	0	t	321	normal_username	_NOVALUE_	madah	2024-03-03 14:31:58.269637
460	0	t	200	normal_username	_NOVALUE_	sadri	2024-02-19 04:45:02.553421
90	0	t	13	normal_username	_NOVALUE_	msm72	2024-02-08 13:31:51.545202
95	0	t	16	abs_exp_date	_NOVALUE_	2024-02-22 13:36	2024-02-08 13:36:28.021132
545	0	t	279	normal_username	_NOVALUE_	noor	2024-02-26 05:04:01.339519
105	0	t	21	abs_exp_date	_NOVALUE_	2024-03-05 13:52	2024-02-08 13:52:59.557775
108	0	t	23	normal_username	_NOVALUE_	noor	2024-02-08 13:56:32.168688
546	0	t	280	normal_username	_NOVALUE_	mashaal1	2024-02-26 09:26:22.769733
294	0	t	103	normal_username	_NOVALUE_	roghayeh	2024-02-09 05:24:10.805804
295	0	t	103	abs_exp_date	_NOVALUE_	2024-04-15 06:24	2024-02-09 05:24:26.702268
299	0	t	104	abs_exp_date	_NOVALUE_	2024-02-23 05:32	2024-02-09 05:32:33.455976
616	0	t	340	normal_username	_NOVALUE_	mostafa103	2024-03-06 08:57:38.450701
308	0	t	109	normal_username	_NOVALUE_	elnaz	2024-02-09 15:09:38.173297
312	0	t	111	normal_username	_NOVALUE_	dastanpoor	2024-02-10 05:05:22.032044
321	0	t	6	abs_exp_date	2024-02-08 13:45	2024-03-19 09:04	2024-02-10 08:04:54.463771
327	0	t	115	abs_exp_date	_NOVALUE_	2024-03-05 10:33	2024-02-10 10:33:12.934462
328	0	t	116	normal_username	_NOVALUE_	daftar10	2024-02-10 11:52:29.960883
332	0	t	118	normal_username	_NOVALUE_	daftar	2024-02-10 11:55:17.946923
335	0	t	119	normal_username	_NOVALUE_	mahroo	2024-02-11 05:20:49.663832
336	0	t	120	normal_username	_NOVALUE_	aliasghar	2024-02-11 08:00:58.120126
339	0	t	122	normal_username	_NOVALUE_	farhadi1000	2024-02-11 18:06:27.657885
345	0	t	126	abs_exp_date	_NOVALUE_	2024-03-20 02:56	2024-02-12 01:56:49.690664
348	0	t	127	normal_username	_NOVALUE_	khhosseini2	2024-02-12 02:00:53.378853
349	0	t	127	traffic_periodic_accounting_daily	60	37	2024-02-12 02:03:09.378987
350	0	t	127	traffic_periodic_accounting_daily_limit	70000M	25000M	2024-02-12 02:03:09.378987
357	0	t	130	normal_username	_NOVALUE_	daftartehran	2024-02-12 03:53:21.132833
358	0	t	130	group	3-Month-150G	2-Month-70G	2024-02-12 03:53:40.778041
359	0	t	131	normal_username	_NOVALUE_	gorjian3	2024-02-12 03:57:34.604875
361	0	t	132	normal_username	_NOVALUE_	chtalaee	2024-02-12 04:03:50.984524
374	0	t	146	normal_username	_NOVALUE_	msm48	2024-02-12 12:46:37.268122
375	0	t	146	abs_exp_date	_NOVALUE_	2024-02-26 12:46	2024-02-12 12:46:58.149203
378	0	t	148	normal_username	_NOVALUE_	torkamandi	2024-02-12 16:07:37.993086
379	0	t	148	abs_exp_date	_NOVALUE_	2024-03-09 16:08	2024-02-12 16:08:31.029851
382	0	t	150	normal_username	_NOVALUE_	banisadr	2024-02-13 04:53:42.016061
383	0	t	150	abs_exp_date	_NOVALUE_	2024-06-21 05:53	2024-02-13 04:53:52.15244
384	0	t	150	traffic_periodic_accounting_daily	180	129	2024-02-13 04:54:07.029638
385	0	t	150	traffic_periodic_accounting_daily_limit	300000M	200000M	2024-02-13 04:54:07.029638
386	0	t	151	normal_username	_NOVALUE_	fjafari	2024-02-13 13:34:58.254128
704	0	t	410	normal_username	_NOVALUE_	ashkan	2024-03-15 05:41:25.34235
392	0	t	155	normal_username	_NOVALUE_	aryo1	2024-02-13 17:27:29.082817
712	0	t	415	normal_username	_NOVALUE_	zomorod	2024-03-16 13:09:24.958905
716	0	t	419	normal_username	_NOVALUE_	barati	2024-03-16 16:32:13.938136
398	0	t	158	normal_username	_NOVALUE_	goldoost	2024-02-14 05:44:14.440589
748	0	t	208	first_login	2024-02-19 15:58	_NOVALUE_	2024-03-20 04:33:20.192654
407	0	t	164	multi_login	2	1	2024-02-15 05:19:06.062278
754	0	t	254	first_login	2024-02-22 07:59	_NOVALUE_	2024-03-22 11:47:08.249655
414	0	t	170	normal_username	_NOVALUE_	rahimi	2024-02-16 04:55:44.359455
415	0	t	171	normal_username	_NOVALUE_	bagheri	2024-02-16 16:20:03.048773
733	0	t	200	first_login	2024-02-19 04:45	_NOVALUE_	2024-03-19 05:03:08.000712
418	0	t	177	normal_username	_NOVALUE_	askari	2024-02-17 04:15:53.851813
419	0	t	178	normal_username	_NOVALUE_	shooshtari	2024-02-17 05:03:19.592473
420	0	t	178	abs_exp_date	_NOVALUE_	2024-03-15 06:03	2024-02-17 05:03:43.388668
422	0	t	179	abs_exp_date	_NOVALUE_	2024-04-25 08:32	2024-02-17 07:32:04.076236
427	0	t	182	normal_username	_NOVALUE_	sahar1	2024-02-17 08:36:31.886454
432	0	t	184	normal_username	_NOVALUE_	fa8	2024-02-17 08:41:22.326108
433	0	t	184	abs_exp_date	_NOVALUE_	2024-03-09 08:43	2024-02-17 08:43:06.189463
690	0	t	400	normal_username	_NOVALUE_	tkeyhan	2024-03-13 13:42:36.270549
440	0	t	187	normal_username	_NOVALUE_	navab	2024-02-17 14:08:27.559598
442	0	t	189	normal_username	_NOVALUE_	boss	2024-02-18 07:15:29.464861
449	0	t	195	normal_username	_NOVALUE_	sepideh	2024-02-18 14:24:24.280047
450	0	t	195	abs_exp_date	_NOVALUE_	2024-04-03 15:24	2024-02-18 14:24:38.322384
451	0	t	195	traffic_periodic_accounting_daily	60	45	2024-02-18 14:24:58.567875
452	0	t	195	traffic_periodic_accounting_daily_limit	70000M	60000M	2024-02-18 14:24:58.567875
674	0	t	395	normal_username	_NOVALUE_	nhasibi2	2024-03-12 05:42:25.127418
455	0	t	197	normal_username	_NOVALUE_	tofighi	2024-02-18 16:59:23.96424
461	0	t	201	normal_username	_NOVALUE_	fatemeh40	2024-02-19 04:46:51.863664
463	0	t	201	traffic_periodic_accounting_daily	90	70	2024-02-19 04:47:22.901725
464	0	t	201	traffic_periodic_accounting_daily_limit	150000M	90000M	2024-02-19 04:47:22.901725
466	0	t	203	normal_username	_NOVALUE_	abolfazl2	2024-02-19 08:17:11.426915
467	0	t	204	normal_username	_NOVALUE_	hamidr	2024-02-19 09:31:21.687021
738	0	t	436	normal_username	_NOVALUE_	m38	2024-03-19 13:29:07.416691
474	0	t	207	normal_username	_NOVALUE_	zalipc	2024-02-19 15:14:40.765087
477	0	t	210	normal_username	_NOVALUE_	karbasi3	2024-02-19 15:44:05.269955
478	0	t	211	normal_username	_NOVALUE_	parisa	2024-02-19 15:56:51.027643
480	0	t	212	normal_username	_NOVALUE_	nazanin2	2024-02-19 17:30:04.71564
481	0	t	212	abs_exp_date	_NOVALUE_	2024-03-17 18:33	2024-02-19 17:33:29.965699
547	0	t	281	normal_username	_NOVALUE_	vahideh	2024-02-26 09:37:02.950676
549	0	t	282	abs_exp_date	_NOVALUE_	2024-05-19 14:19	2024-02-26 13:19:38.493843
551	0	t	284	normal_username	_NOVALUE_	kazemipc	2024-02-27 13:26:18.745533
486	0	t	217	normal_username	_NOVALUE_	bama14	2024-02-20 12:12:55.928717
487	0	t	218	normal_username	_NOVALUE_	bama15	2024-02-20 12:12:55.928717
617	0	t	341	normal_username	_NOVALUE_	aghakhani2	2024-03-06 10:57:41.794156
641	0	t	361	normal_username	_NOVALUE_	peyghambari	2024-03-10 06:46:56.124827
91	0	t	13	abs_exp_date	_NOVALUE_	2024-02-25 13:32	2024-02-08 13:32:07.383816
92	0	t	15	normal_username	_NOVALUE_	msm26	2024-02-08 13:33:34.342071
94	0	t	16	normal_username	_NOVALUE_	msm36	2024-02-08 13:36:15.383602
548	0	t	282	normal_username	_NOVALUE_	parsa	2024-02-26 13:19:21.280774
99	0	t	18	abs_exp_date	_NOVALUE_	2024-02-28 13:39	2024-02-08 13:39:38.459314
102	0	t	20	normal_username	_NOVALUE_	msm37	2024-02-08 13:43:35.667836
106	0	t	22	normal_username	_NOVALUE_	ghafari20	2024-02-08 13:53:55.182427
552	0	t	285	normal_username	_NOVALUE_	saryazdi	2024-02-27 13:57:45.549518
296	0	t	103	traffic_periodic_accounting_daily	90	66	2024-02-09 05:25:36.1714
297	0	t	103	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-02-09 05:25:36.1714
618	0	t	341	abs_exp_date	_NOVALUE_	2024-06-01 11:57	2024-03-06 10:57:58.321975
304	0	t	107	normal_username	_NOVALUE_	mahsa96	2024-02-09 06:07:46.404843
306	0	t	5	multi_login	2	1	2024-02-09 06:33:36.683844
307	0	t	108	normal_username	_NOVALUE_	cheraghi	2024-02-09 11:19:12.401579
309	0	t	109	abs_exp_date	_NOVALUE_	2024-04-03 16:09	2024-02-09 15:09:50.909875
310	0	t	110	normal_username	_NOVALUE_	mahroo	2024-02-09 15:21:37.358114
311	0	t	110	abs_exp_date	_NOVALUE_	2024-02-11 15:21	2024-02-09 15:21:50.168982
313	0	t	111	abs_exp_date	_NOVALUE_	2024-03-01 05:05	2024-02-10 05:05:36.772074
314	0	t	112	normal_username	_NOVALUE_	reza	2024-02-10 05:25:04.5191
315	0	t	112	multi_login	2	12	2024-02-10 05:25:24.031034
316	0	t	112	abs_exp_date	_NOVALUE_	2024-04-30 06:29	2024-02-10 05:29:31.898946
317	0	t	112	abs_exp_date	2024-04-30 06:29	2024-04-28 06:29	2024-02-10 05:29:51.632864
318	0	t	77	multi_login	2	2	2024-02-10 06:33:40.035777
320	0	t	113	normal_username	_NOVALUE_	ati	2024-02-10 07:47:25.95415
324	0	t	114	traffic_periodic_accounting_daily	60	45	2024-02-10 09:26:05.389124
325	0	t	114	traffic_periodic_accounting_daily_limit	70000M	50000M	2024-02-10 09:26:05.389124
326	0	t	115	normal_username	_NOVALUE_	javadi	2024-02-10 10:33:05.079484
330	0	t	116	traffic_periodic_accounting_daily	90	90	2024-02-10 11:54:53.0415
331	0	t	116	traffic_periodic_accounting_daily_limit	150000M	40000M	2024-02-10 11:54:53.0415
337	0	t	121	normal_username	_NOVALUE_	mcb	2024-02-11 15:35:23.73136
343	0	t	125	normal_username	_NOVALUE_	khhosseine	2024-02-12 01:55:20.358409
351	0	t	128	normal_username	_NOVALUE_	sabzineh	2024-02-12 03:19:52.239109
353	0	t	128	traffic_periodic_accounting_daily	60	39	2024-02-12 03:20:14.936297
354	0	t	128	traffic_periodic_accounting_daily_limit	70000M	50000M	2024-02-12 03:20:14.936297
362	0	t	134	normal_username	_NOVALUE_	bama2000	2024-02-12 05:12:08.092914
363	0	t	135	normal_username	_NOVALUE_	bama2001	2024-02-12 05:12:08.092914
364	0	t	136	normal_username	_NOVALUE_	bama2002	2024-02-12 05:12:08.092914
365	0	t	137	normal_username	_NOVALUE_	bama2003	2024-02-12 05:12:08.092914
366	0	t	138	normal_username	_NOVALUE_	bama2004	2024-02-12 05:12:08.092914
367	0	t	139	normal_username	_NOVALUE_	bama2005	2024-02-12 05:12:08.092914
368	0	t	140	normal_username	_NOVALUE_	bama2006	2024-02-12 05:12:08.092914
369	0	t	141	normal_username	_NOVALUE_	bama2007	2024-02-12 05:12:08.092914
370	0	t	142	normal_username	_NOVALUE_	bama2008	2024-02-12 05:12:08.092914
371	0	t	143	normal_username	_NOVALUE_	bama2009	2024-02-12 05:12:08.092914
372	0	t	132	multi_login	2	3	2024-02-12 05:23:41.573522
574	0	t	309	normal_username	_NOVALUE_	navid39	2024-03-01 08:25:57.442269
576	0	t	311	normal_username	_NOVALUE_	sarikhan2	2024-03-01 09:14:20.025536
388	0	t	153	normal_username	_NOVALUE_	hosniyeh	2024-02-13 15:48:12.054701
713	0	t	416	normal_username	_NOVALUE_	babaei	2024-03-16 13:11:37.205619
714	0	t	417	normal_username	_NOVALUE_	farzaneh	2024-03-16 15:15:34.709789
399	0	t	159	normal_username	_NOVALUE_	barati	2024-02-14 14:30:35.691628
405	0	t	164	normal_username	_NOVALUE_	sina	2024-02-15 04:26:34.020631
410	0	t	166	normal_username	_NOVALUE_	barati	2024-02-15 12:56:40.896016
412	0	t	168	normal_username	_NOVALUE_	mahla	2024-02-15 17:13:46.942836
417	0	t	176	normal_username	_NOVALUE_	kami	2024-02-17 01:01:32.189586
421	0	t	179	normal_username	_NOVALUE_	farzan1	2024-02-17 07:31:49.875377
423	0	t	179	traffic_periodic_accounting_daily	90	68	2024-02-17 07:34:47.693363
424	0	t	179	traffic_periodic_accounting_daily_limit	150000M	120000M	2024-02-17 07:34:47.693363
425	0	t	180	normal_username	_NOVALUE_	bargh	2024-02-17 08:26:09.547022
429	0	t	183	abs_exp_date	_NOVALUE_	2024-04-25 09:37	2024-02-17 08:37:45.876075
439	0	t	26	abs_exp_date	2024-02-16 14:06	2024-03-03 13:54	2024-02-17 13:54:02.917149
441	0	t	188	normal_username	_NOVALUE_	saghayi2	2024-02-17 14:12:03.677116
443	0	t	190	normal_username	_NOVALUE_	kami2	2024-02-18 07:54:30.216481
445	0	t	191	abs_exp_date	_NOVALUE_	2024-02-22 09:14	2024-02-18 09:14:09.851598
446	0	t	192	normal_username	_NOVALUE_	setayesh	2024-02-18 11:18:30.393143
447	0	t	192	abs_exp_date	_NOVALUE_	2024-03-10 12:18	2024-02-18 11:18:50.146051
675	0	t	395	group	1-Month-20G	2-Month-70G	2024-03-12 05:42:43.357135
456	0	t	198	normal_username	_NOVALUE_	shaghayegh	2024-02-18 17:01:12.623665
601	0	t	324	normal_username	_NOVALUE_	bama2030	2024-03-05 05:01:32.451994
462	0	t	201	abs_exp_date	_NOVALUE_	2024-04-29 05:47	2024-02-19 04:47:04.630602
619	0	t	342	normal_username	_NOVALUE_	salimian57	2024-03-06 14:02:35.221227
623	0	t	345	normal_username	_NOVALUE_	ghafari10	2024-03-06 23:53:57.409466
734	0	t	432	normal_username	_NOVALUE_	deniz	2024-03-19 05:04:52.037484
475	0	t	208	normal_username	_NOVALUE_	karbasi1	2024-02-19 15:41:29.729267
476	0	t	209	normal_username	_NOVALUE_	karbasi2	2024-02-19 15:43:23.498913
479	0	t	211	abs_exp_date	_NOVALUE_	2024-02-23 15:57	2024-02-19 15:57:05.515591
482	0	t	213	normal_username	_NOVALUE_	maziyarpc	2024-02-20 02:18:50.864681
488	0	t	219	normal_username	_NOVALUE_	bama16	2024-02-20 12:12:55.928717
489	0	t	220	normal_username	_NOVALUE_	bama17	2024-02-20 12:12:55.928717
490	0	t	221	normal_username	_NOVALUE_	bama18	2024-02-20 12:12:55.928717
620	0	t	342	abs_exp_date	_NOVALUE_	2024-05-02 15:02	2024-03-06 14:02:51.513203
599	0	t	322	normal_username	_NOVALUE_	sajad	2024-03-04 04:32:36.460015
465	0	t	202	normal_username	_NOVALUE_	daftarforoosh	2024-02-19 07:24:41.162736
93	0	t	15	abs_exp_date	_NOVALUE_	2024-02-21 13:33	2024-02-08 13:33:50.690007
98	0	t	18	normal_username	_NOVALUE_	msm67	2024-02-08 13:38:54.546263
550	0	t	283	normal_username	_NOVALUE_	mona	2024-02-26 15:04:43.730854
553	0	t	286	normal_username	_NOVALUE_	saljooghi	2024-02-28 06:53:22.117664
103	0	t	20	abs_exp_date	_NOVALUE_	2024-02-23 13:43	2024-02-08 13:43:50.959278
104	0	t	21	normal_username	_NOVALUE_	ghafari10	2024-02-08 13:52:47.433513
107	0	t	22	abs_exp_date	_NOVALUE_	2024-02-29 13:54	2024-02-08 13:54:09.441144
109	0	t	23	abs_exp_date	_NOVALUE_	2024-02-28 13:57	2024-02-08 13:57:01.568304
110	0	t	24	normal_username	_NOVALUE_	seyfi	2024-02-08 13:58:52.83192
111	0	t	25	normal_username	_NOVALUE_	golnaz	2024-02-08 14:00:59.594531
112	0	t	26	normal_username	_NOVALUE_	keyhan5	2024-02-08 14:06:20.190285
113	0	t	26	abs_exp_date	_NOVALUE_	2024-02-16 14:06	2024-02-08 14:06:32.025128
635	0	t	356	normal_username	_NOVALUE_	saharh	2024-03-09 03:40:52.411208
637	0	t	358	normal_username	_NOVALUE_	torkamandi	2024-03-09 12:32:45.620588
691	0	t	401	normal_username	_NOVALUE_	talkhabloo1	2024-03-13 14:41:44.632181
117	0	t	28	normal_username	_NOVALUE_	mostafa102	2024-02-08 14:10:34.49873
118	0	t	28	abs_exp_date	_NOVALUE_	2024-03-01 14:10	2024-02-08 14:10:55.905452
556	0	t	289	normal_username	_NOVALUE_	bama2020	2024-02-28 16:33:16.423524
557	0	t	290	normal_username	_NOVALUE_	bama2021	2024-02-28 16:33:16.423524
121	0	t	30	normal_username	_NOVALUE_	mostafa	2024-02-08 14:17:51.558141
122	0	t	30	abs_exp_date	_NOVALUE_	2024-03-01 14:18	2024-02-08 14:18:07.178985
123	0	t	31	normal_username	_NOVALUE_	mostafa100	2024-02-08 14:21:03.466684
124	0	t	31	abs_exp_date	_NOVALUE_	2024-02-24 14:23	2024-02-08 14:23:06.254775
400	0	t	160	normal_username	_NOVALUE_	sheyda77	2024-02-14 14:57:00.248193
406	0	t	164	group	1-Month-50G	1-Month-20G	2024-02-15 05:18:25.206143
127	0	t	33	normal_username	_NOVALUE_	jafari07	2024-02-08 14:31:53.796825
128	0	t	33	abs_exp_date	_NOVALUE_	2024-04-10 15:32	2024-02-08 14:32:16.288501
129	0	t	33	traffic_periodic_accounting_daily	90	62	2024-02-08 14:32:39.92498
130	0	t	33	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-02-08 14:32:39.92498
715	0	t	418	normal_username	_NOVALUE_	padideh	2024-03-16 15:17:29.248111
132	0	t	35	normal_username	_NOVALUE_	barati	2024-02-08 14:36:22.132072
133	0	t	35	abs_exp_date	_NOVALUE_	2024-02-13 14:36	2024-02-08 14:36:36.289752
134	0	t	36	normal_username	_NOVALUE_	farhad13	2024-02-08 14:39:51.617356
135	0	t	36	abs_exp_date	_NOVALUE_	2024-02-25 14:40	2024-02-08 14:40:35.404839
136	0	t	37	normal_username	_NOVALUE_	sadri	2024-02-08 14:59:30.891999
137	0	t	37	abs_exp_date	_NOVALUE_	2024-02-18 15:00	2024-02-08 15:00:09.980545
719	0	t	420	normal_username	_NOVALUE_	daftar11	2024-03-17 10:35:18.576865
140	0	t	39	normal_username	_NOVALUE_	sania	2024-02-08 15:02:29.521922
141	0	t	39	abs_exp_date	_NOVALUE_	2024-03-07 15:03	2024-02-08 15:03:06.768293
142	0	t	40	normal_username	_NOVALUE_	mehdi	2024-02-08 15:07:25.685396
143	0	t	40	abs_exp_date	_NOVALUE_	2025-01-29 15:07	2024-02-08 15:07:49.089065
144	0	t	40	traffic_periodic_accounting_daily	365	356	2024-02-08 15:08:14.560964
145	0	t	40	traffic_periodic_accounting_daily_limit	800000M	700000M	2024-02-08 15:08:14.560964
146	0	t	41	normal_username	_NOVALUE_	parastoo	2024-02-08 15:13:10.425036
147	0	t	41	abs_exp_date	_NOVALUE_	2024-02-24 15:13	2024-02-08 15:13:22.656752
148	0	t	42	normal_username	_NOVALUE_	tofighi	2024-02-08 15:14:39.326856
149	0	t	42	abs_exp_date	_NOVALUE_	2024-02-17 15:15	2024-02-08 15:15:10.884742
152	0	t	44	normal_username	_NOVALUE_	saber	2024-02-08 15:21:34.41694
153	0	t	44	abs_exp_date	_NOVALUE_	2025-01-24 15:22	2024-02-08 15:22:15.523858
154	0	t	45	normal_username	_NOVALUE_	yaser	2024-02-08 15:23:50.571373
155	0	t	45	abs_exp_date	_NOVALUE_	2025-01-24 15:24	2024-02-08 15:24:05.08973
156	0	t	45	traffic_periodic_accounting_daily	365	351	2024-02-08 15:24:45.42303
157	0	t	45	traffic_periodic_accounting_daily_limit	800000M	760000M	2024-02-08 15:24:45.42303
158	0	t	46	normal_username	_NOVALUE_	marjan	2024-02-08 15:25:57.612344
159	0	t	46	abs_exp_date	_NOVALUE_	2025-01-28 15:26	2024-02-08 15:26:10.615472
160	0	t	47	normal_username	_NOVALUE_	jalal	2024-02-08 15:26:44.744469
161	0	t	47	abs_exp_date	_NOVALUE_	2025-01-28 15:26	2024-02-08 15:26:59.353635
162	0	t	48	normal_username	_NOVALUE_	bagheri	2024-02-08 15:39:08.893004
163	0	t	48	abs_exp_date	_NOVALUE_	2024-02-16 15:39	2024-02-08 15:39:22.142014
164	0	t	49	normal_username	_NOVALUE_	danial	2024-02-08 15:45:43.471422
165	0	t	49	abs_exp_date	_NOVALUE_	2024-03-18 16:45	2024-02-08 15:45:56.799209
166	0	t	49	abs_exp_date	2024-03-18 16:45	2024-03-18 16:46	2024-02-08 15:46:10.854706
167	0	t	50	normal_username	_NOVALUE_	amin45	2024-02-08 15:48:47.748923
168	0	t	50	abs_exp_date	_NOVALUE_	2024-09-05 16:48	2024-02-08 15:48:59.425968
169	0	t	50	traffic_periodic_accounting_daily	365	210	2024-02-08 15:49:33.95373
170	0	t	50	traffic_periodic_accounting_daily_limit	600000M	450000M	2024-02-08 15:49:33.95373
602	0	t	325	normal_username	_NOVALUE_	bama2031	2024-03-05 05:01:32.451994
603	0	t	326	normal_username	_NOVALUE_	bama2032	2024-03-05 05:01:32.451994
173	0	t	52	normal_username	_NOVALUE_	mohammad90	2024-02-08 16:05:24.803859
174	0	t	52	abs_exp_date	_NOVALUE_	2024-04-20 17:05	2024-02-08 16:05:41.947793
175	0	t	52	traffic_periodic_accounting_daily	90	72	2024-02-08 16:06:18.51288
176	0	t	52	traffic_periodic_accounting_daily_limit	150000M	120000M	2024-02-08 16:06:18.51288
177	0	t	53	normal_username	_NOVALUE_	sarikhan1	2024-02-08 16:08:08.960433
178	0	t	53	abs_exp_date	_NOVALUE_	2024-02-29 16:09	2024-02-08 16:09:11.203922
179	0	t	54	normal_username	_NOVALUE_	sarikhan2	2024-02-08 16:09:59.185775
624	0	t	347	normal_username	_NOVALUE_	ghafari20	2024-03-06 23:55:31.706128
626	0	t	345	group	1-Month-50G	1-Month-35G	2024-03-06 23:56:36.807994
627	0	t	348	normal_username	_NOVALUE_	farnaz	2024-03-07 00:12:16.841554
180	0	t	54	abs_exp_date	_NOVALUE_	2024-02-08 16:33	2024-02-08 16:10:12.463076
187	0	t	57	abs_exp_date	_NOVALUE_	2024-02-29 16:29	2024-02-08 16:29:08.662407
191	0	t	59	abs_exp_date	_NOVALUE_	2024-03-18 17:39	2024-02-08 16:39:07.758495
206	0	t	65	abs_exp_date	_NOVALUE_	2024-03-19 18:08	2024-02-08 17:08:45.982842
207	0	t	67	normal_username	_NOVALUE_	arast	2024-02-08 17:12:13.142921
208	0	t	67	abs_exp_date	_NOVALUE_	2024-05-18 18:12	2024-02-08 17:12:26.485342
211	0	t	68	normal_username	_NOVALUE_	kiana	2024-02-08 17:15:48.02966
218	0	t	70	normal_username	_NOVALUE_	mirkazemi	2024-02-08 17:32:17.673864
219	0	t	70	abs_exp_date	_NOVALUE_	2024-04-13 18:32	2024-02-08 17:32:35.553822
586	0	t	313	normal_username	_NOVALUE_	mostafa105	2024-03-02 05:32:50.943928
227	0	t	74	normal_username	_NOVALUE_	setareh14	2024-02-08 17:44:36.058949
231	0	t	75	traffic_periodic_accounting_daily	90	72	2024-02-08 17:49:59.109285
232	0	t	75	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-02-08 17:49:59.109285
234	0	t	77	normal_username	_NOVALUE_	navid	2024-02-08 17:53:29.663691
237	0	t	78	abs_exp_date	_NOVALUE_	2024-02-18 18:09	2024-02-08 18:09:27.902902
298	0	t	104	normal_username	_NOVALUE_	sahar57	2024-02-09 05:32:19.705222
300	0	t	105	normal_username	_NOVALUE_	msharif1	2024-02-09 06:03:44.101385
301	0	t	105	abs_exp_date	_NOVALUE_	2024-03-27 07:04	2024-02-09 06:04:03.147837
305	0	t	107	abs_exp_date	_NOVALUE_	2024-02-23 06:08	2024-02-09 06:08:11.162713
319	0	t	77	multi_login	2	2	2024-02-10 06:33:42.394522
322	0	t	114	normal_username	_NOVALUE_	c103	2024-02-10 09:24:25.804996
323	0	t	114	abs_exp_date	_NOVALUE_	2024-03-26 10:24	2024-02-10 09:24:34.58942
329	0	t	116	group	1-Month-10G	3-Month-150G	2024-02-10 11:54:05.452156
333	0	t	118	traffic_periodic_accounting_daily	90	90	2024-02-10 11:55:33.58902
334	0	t	118	traffic_periodic_accounting_daily_limit	150000M	40000M	2024-02-10 11:55:33.58902
338	0	t	121	abs_exp_date	_NOVALUE_	2024-05-06 16:35	2024-02-11 15:35:35.049154
340	0	t	122	abs_exp_date	_NOVALUE_	2024-02-20 18:06	2024-02-11 18:06:45.166334
341	0	t	123	normal_username	_NOVALUE_	hadadi	2024-02-12 01:40:04.914371
342	0	t	124	normal_username	_NOVALUE_	rtp	2024-02-12 01:42:18.017187
344	0	t	126	normal_username	_NOVALUE_	khhosseini	2024-02-12 01:56:34.841726
346	0	t	126	traffic_periodic_accounting_daily	60	37	2024-02-12 01:57:15.005947
347	0	t	126	traffic_periodic_accounting_daily_limit	70000M	50000M	2024-02-12 01:57:15.005947
352	0	t	128	abs_exp_date	_NOVALUE_	2024-03-22 04:20	2024-02-12 03:20:02.283934
554	0	t	287	normal_username	_NOVALUE_	saghar	2024-02-28 07:41:22.837355
555	0	t	288	normal_username	_NOVALUE_	mylove	2024-02-28 16:23:35.710792
360	0	t	131	abs_exp_date	_NOVALUE_	2024-03-06 03:57	2024-02-12 03:57:48.842126
373	0	t	145	normal_username	_NOVALUE_	hamidreza	2024-02-12 05:39:55.453113
376	0	t	147	normal_username	_NOVALUE_	ahatami2d	2024-02-12 12:55:49.968577
377	0	t	147	abs_exp_date	_NOVALUE_	2025-02-11 12:56	2024-02-12 12:56:06.727837
389	0	t	153	abs_exp_date	_NOVALUE_	2024-03-05 15:48	2024-02-13 15:48:31.463957
390	0	t	154	normal_username	_NOVALUE_	maleki2	2024-02-13 17:22:32.691405
391	0	t	154	abs_exp_date	_NOVALUE_	2024-04-03 18:24	2024-02-13 17:24:29.637093
401	0	t	161	normal_username	_NOVALUE_	maleki	2024-02-14 16:28:14.502273
402	0	t	162	normal_username	_NOVALUE_	fkarimi	2024-02-15 02:18:35.530547
403	0	t	162	abs_exp_date	_NOVALUE_	2024-05-10 03:19	2024-02-15 02:19:11.41683
409	0	t	165	normal_username	_NOVALUE_	shooshtari	2024-02-15 10:42:40.683021
411	0	t	167	normal_username	_NOVALUE_	shirani	2024-02-15 16:34:15.625519
426	0	t	181	normal_username	_NOVALUE_	elna2	2024-02-17 08:34:26.787977
428	0	t	183	normal_username	_NOVALUE_	farzan2	2024-02-17 08:37:38.390474
430	0	t	183	traffic_periodic_accounting_daily	90	68	2024-02-17 08:37:57.12804
431	0	t	183	traffic_periodic_accounting_daily_limit	150000M	120000M	2024-02-17 08:37:57.12804
434	0	t	184	traffic_periodic_accounting_daily	30	21	2024-02-17 08:44:15.555771
435	0	t	185	normal_username	_NOVALUE_	aryo1	2024-02-17 13:17:00.404851
692	0	t	402	normal_username	_NOVALUE_	skeyhan	2024-03-13 16:19:50.583681
438	0	t	26	first_login	2024-02-08 14:08	_NOVALUE_	2024-02-17 13:53:43.414253
444	0	t	191	normal_username	_NOVALUE_	vafa	2024-02-18 09:14:02.052729
448	0	t	194	normal_username	_NOVALUE_	zomorod	2024-02-18 14:13:15.235129
457	0	t	198	abs_exp_date	_NOVALUE_	2024-05-15 18:01	2024-02-18 17:01:31.682412
604	0	t	327	normal_username	_NOVALUE_	bama2033	2024-03-05 05:01:32.451994
468	0	t	142	group	1-Month-35G	2-Month-70G	2024-02-19 12:45:05.13697
469	0	t	142	abs_exp_date	_NOVALUE_	2024-04-16 13:45	2024-02-19 12:45:27.632541
491	0	t	222	normal_username	_NOVALUE_	bama19	2024-02-20 12:12:55.928717
492	0	t	223	normal_username	_NOVALUE_	bama20	2024-02-20 12:12:55.928717
493	0	t	235	normal_username	_NOVALUE_	bama2010	2024-02-20 12:16:22.578632
494	0	t	236	normal_username	_NOVALUE_	bama2011	2024-02-20 12:16:22.578632
495	0	t	237	normal_username	_NOVALUE_	bama2012	2024-02-20 12:16:22.578632
496	0	t	238	normal_username	_NOVALUE_	bama2013	2024-02-20 12:16:22.578632
497	0	t	239	normal_username	_NOVALUE_	bama2014	2024-02-20 12:16:22.578632
498	0	t	240	normal_username	_NOVALUE_	bama2015	2024-02-20 12:16:22.578632
499	0	t	241	normal_username	_NOVALUE_	bama2016	2024-02-20 12:16:22.578632
500	0	t	242	normal_username	_NOVALUE_	bama2017	2024-02-20 12:16:22.578632
501	0	t	243	normal_username	_NOVALUE_	bama2018	2024-02-20 12:16:22.578632
502	0	t	244	normal_username	_NOVALUE_	bama2019	2024-02-20 12:16:22.578632
505	0	t	248	normal_username	_NOVALUE_	negin1	2024-02-20 16:19:27.127624
509	0	t	249	normal_username	_NOVALUE_	msm26	2024-02-21 15:20:33.517151
511	0	t	252	normal_username	_NOVALUE_	anderson	2024-02-22 04:33:43.428258
513	0	t	254	normal_username	_NOVALUE_	behrooz	2024-02-22 07:50:33.530227
764	0	t	132	first_login	2024-02-12 05:25	_NOVALUE_	2024-03-24 05:49:23.860675
516	0	t	257	normal_username	_NOVALUE_	shahin2	2024-02-23 03:10:57.28496
517	0	t	258	normal_username	_NOVALUE_	sheyda2	2024-02-23 04:40:27.054151
520	0	t	261	normal_username	_NOVALUE_	parisa	2024-02-24 07:19:14.110579
521	0	t	262	normal_username	_NOVALUE_	rahimi10	2024-02-24 10:27:40.819028
181	0	t	54	abs_exp_date	2024-02-08 16:33	2024-03-02 16:10	2024-02-08 16:10:33.353975
182	0	t	55	normal_username	_NOVALUE_	maroof	2024-02-08 16:22:34.402742
185	0	t	56	abs_exp_date	_NOVALUE_	2024-03-05 16:26	2024-02-08 16:26:44.422644
189	0	t	58	abs_exp_date	_NOVALUE_	2024-03-19 17:33	2024-02-08 16:33:56.284158
192	0	t	60	normal_username	_NOVALUE_	poorsalehi	2024-02-08 16:43:20.353927
194	0	t	61	normal_username	_NOVALUE_	ashoori3	2024-02-08 16:52:54.252175
195	0	t	61	abs_exp_date	_NOVALUE_	2024-03-02 16:53	2024-02-08 16:53:26.444973
196	0	t	62	normal_username	_NOVALUE_	dashti	2024-02-08 16:59:29.075452
201	0	t	63	abs_exp_date	_NOVALUE_	2024-02-28 17:02	2024-02-08 17:02:00.996057
600	0	t	323	normal_username	_NOVALUE_	rahimi11	2024-03-04 14:35:18.488158
209	0	t	67	traffic_periodic_accounting_daily	180	100	2024-02-08 17:12:48.05821
210	0	t	67	traffic_periodic_accounting_daily_limit	300000M	150000M	2024-02-08 17:12:48.05821
212	0	t	68	group	1-Month-35G	1-Month-70G	2024-02-08 17:16:00.240211
587	0	t	314	normal_username	_NOVALUE_	mostafa106	2024-03-02 05:34:10.705639
222	0	t	72	normal_username	_NOVALUE_	farnaz	2024-02-08 17:38:27.951707
223	0	t	72	abs_exp_date	_NOVALUE_	2024-03-08 17:38	2024-02-08 17:38:45.918674
226	0	t	73	abs_exp_date	_NOVALUE_	2024-02-29 17:41	2024-02-08 17:41:41.632327
228	0	t	74	abs_exp_date	_NOVALUE_	2024-02-22 17:45	2024-02-08 17:45:08.558947
229	0	t	75	normal_username	_NOVALUE_	samira2	2024-02-08 17:47:23.169374
236	0	t	78	normal_username	_NOVALUE_	asemi	2024-02-08 18:09:14.465981
397	0	t	157	normal_username	_NOVALUE_	rad	2024-02-13 23:57:49.295374
413	0	t	168	abs_exp_date	_NOVALUE_	2024-04-02 18:14	2024-02-15 17:14:07.839586
503	0	t	246	normal_username	_NOVALUE_	neishaboori	2024-02-20 13:47:18.602683
504	0	t	247	normal_username	_NOVALUE_	asal	2024-02-20 15:40:46.692652
507	0	t	248	traffic_periodic_accounting_daily	90	78	2024-02-20 16:19:58.85154
508	0	t	248	traffic_periodic_accounting_daily_limit	150000M	130000M	2024-02-20 16:19:58.85154
510	0	t	250	normal_username	_NOVALUE_	zand	2024-02-21 16:26:57.10119
512	0	t	253	normal_username	_NOVALUE_	anderson2	2024-02-22 07:48:27.995799
514	0	t	255	normal_username	_NOVALUE_	fariba	2024-02-22 10:35:44.432041
518	0	t	259	normal_username	_NOVALUE_	vafa	2024-02-23 04:48:21.607415
519	0	t	260	normal_username	_NOVALUE_	msm72	2024-02-23 15:47:17.797301
522	0	f	14	rel_exp_date	_NOVALUE_	3 Months	2024-02-24 11:00:16.797603
525	0	f	14	multi_login	_NOVALUE_	1	2024-02-24 11:00:49.817467
526	0	f	14	normal_charge	_NOVALUE_	Normal	2024-02-24 11:01:08.125623
527	0	t	236	group	1-Month-35G	3-month-100-G-bama	2024-02-24 11:01:40.52458
528	0	t	263	normal_username	_NOVALUE_	parastoo	2024-02-24 15:55:10.381793
529	0	t	264	normal_username	_NOVALUE_	aria1	2024-02-25 04:53:36.649677
530	0	t	265	normal_username	_NOVALUE_	aria2	2024-02-25 04:53:36.649677
533	0	t	269	normal_username	_NOVALUE_	aali	2024-02-25 12:58:52.71284
535	0	t	270	abs_exp_date	_NOVALUE_	2024-03-23 14:55	2024-02-25 13:55:03.631543
536	0	t	271	normal_username	_NOVALUE_	mostafa10	2024-02-25 14:22:45.44295
537	0	t	272	normal_username	_NOVALUE_	alipoor	2024-02-25 14:33:41.435613
638	0	t	1	group	1-Month-10G	12-Month-800G	2024-03-09 13:12:38.341302
640	0	t	360	normal_username	_NOVALUE_	solmaz	2024-03-10 03:00:56.742828
540	0	t	274	normal_username	_NOVALUE_	sasan2	2024-02-25 15:24:16.612731
541	0	t	275	normal_username	_NOVALUE_	msm78	2024-02-26 00:56:16.789943
542	0	t	276	normal_username	_NOVALUE_	msm37	2024-02-26 00:57:46.373756
543	0	t	277	normal_username	_NOVALUE_	msm35	2024-02-26 00:59:05.840525
544	0	t	278	normal_username	_NOVALUE_	msm36	2024-02-26 01:00:25.218419
558	0	t	291	normal_username	_NOVALUE_	bama2022	2024-02-28 16:33:16.423524
559	0	t	292	normal_username	_NOVALUE_	bama2023	2024-02-28 16:33:16.423524
560	0	t	293	normal_username	_NOVALUE_	bama2024	2024-02-28 16:33:16.423524
561	0	t	294	normal_username	_NOVALUE_	bama2025	2024-02-28 16:33:16.423524
562	0	t	295	normal_username	_NOVALUE_	bama2026	2024-02-28 16:33:16.423524
563	0	t	296	normal_username	_NOVALUE_	bama2027	2024-02-28 16:33:16.423524
564	0	t	297	normal_username	_NOVALUE_	bama2028	2024-02-28 16:33:16.423524
565	0	t	298	normal_username	_NOVALUE_	bama2029	2024-02-28 16:33:16.423524
567	0	t	301	normal_username	_NOVALUE_	mostafa104	2024-02-29 04:01:30.803679
569	0	t	304	normal_username	_NOVALUE_	maroof	2024-02-29 08:01:18.342434
572	0	t	307	normal_username	_NOVALUE_	yusefi	2024-03-01 01:40:16.964043
823	0	t	87	group	3-Month-150G	12-Month-600G	2024-04-01 07:37:19.495208
575	0	t	310	normal_username	_NOVALUE_	sarikhan1	2024-03-01 09:13:28.517774
577	0	t	311	abs_exp_date	_NOVALUE_	2024-04-04 10:14	2024-03-01 09:14:32.606769
578	0	t	311	traffic_periodic_accounting_daily	60	34	2024-03-01 09:14:49.377343
579	0	t	311	traffic_periodic_accounting_daily_limit	70000M	50000M	2024-03-01 09:14:49.377343
580	0	t	312	normal_username	_NOVALUE_	zahra	2024-03-01 13:42:36.092617
581	0	t	312	abs_exp_date	_NOVALUE_	2024-06-08 14:42	2024-03-01 13:42:52.313444
582	0	t	312	traffic_periodic_accounting_daily	180	99	2024-03-01 13:43:09.596265
583	0	t	312	traffic_periodic_accounting_daily_limit	300000M	150M	2024-03-01 13:43:09.596265
584	0	t	312	traffic_periodic_accounting_daily	99	99	2024-03-01 13:43:29.120333
585	0	t	312	traffic_periodic_accounting_daily_limit	150M	150000M	2024-03-01 13:43:29.120333
588	0	t	315	normal_username	_NOVALUE_	nikdel4	2024-03-02 06:47:06.150582
589	0	t	184	lock	_NOVALUE_		2024-03-02 11:07:09.335982
590	0	t	184	lock		2/3/2024	2024-03-02 11:07:35.365011
591	0	t	183	lock	_NOVALUE_	2/3/2024	2024-03-02 11:07:59.097747
592	0	t	316	normal_username	_NOVALUE_	msm80	2024-03-02 13:49:00.968856
593	0	t	317	normal_username	_NOVALUE_	amin66	2024-03-02 15:16:39.553145
594	0	t	317	abs_exp_date	_NOVALUE_	2025-03-01 15:17	2024-03-02 15:17:55.95621
595	0	t	318	normal_username	_NOVALUE_	nima	2024-03-02 15:34:38.007842
596	0	t	319	normal_username	_NOVALUE_	keyhan5	2024-03-02 15:39:48.710956
597	0	t	320	normal_username	_NOVALUE_	najar	2024-03-03 02:38:45.329439
605	0	t	328	normal_username	_NOVALUE_	bama2034	2024-03-05 05:01:32.451994
606	0	t	329	normal_username	_NOVALUE_	bama2035	2024-03-05 05:01:32.451994
183	0	t	55	abs_exp_date	_NOVALUE_	2024-02-28 16:22	2024-02-08 16:22:47.718911
184	0	t	56	normal_username	_NOVALUE_	meghdad	2024-02-08 16:26:19.972504
186	0	t	57	normal_username	_NOVALUE_	najar	2024-02-08 16:28:57.218009
188	0	t	58	normal_username	_NOVALUE_	mohammadi66	2024-02-08 16:33:41.738293
190	0	t	59	normal_username	_NOVALUE_	sadr	2024-02-08 16:38:51.22202
193	0	t	60	abs_exp_date	_NOVALUE_	2024-03-09 16:45	2024-02-08 16:45:38.770973
197	0	t	62	abs_exp_date	_NOVALUE_	2024-04-28 17:59	2024-02-08 16:59:43.940041
198	0	t	62	traffic_periodic_accounting_daily	90	80	2024-02-08 17:00:16.395536
199	0	t	62	traffic_periodic_accounting_daily_limit	150000M	140000M	2024-02-08 17:00:16.395536
200	0	t	63	normal_username	_NOVALUE_	melika70	2024-02-08 17:01:41.846613
607	0	t	330	normal_username	_NOVALUE_	bama2036	2024-03-05 05:01:32.451994
608	0	t	331	normal_username	_NOVALUE_	bama2037	2024-03-05 05:01:32.451994
205	0	t	65	normal_username	_NOVALUE_	arast3	2024-02-08 17:08:33.03241
213	0	t	68	abs_exp_date	_NOVALUE_	2024-03-01 17:16	2024-02-08 17:16:18.89439
705	0	t	411	normal_username	_NOVALUE_	mostofi1	2024-03-15 06:24:29.951367
773	0	t	447	normal_username	_NOVALUE_	sheyda3	2024-03-26 04:38:12.020285
708	0	t	412	normal_username	_NOVALUE_	mostofi	2024-03-15 08:25:39.012108
709	0	t	413	normal_username	_NOVALUE_	maleki3	2024-03-15 16:02:11.700989
224	0	t	72	abs_exp_date	2024-03-08 17:38	2024-03-07 17:39	2024-02-08 17:39:15.601552
225	0	t	73	normal_username	_NOVALUE_	leyla	2024-02-08 17:41:12.323532
230	0	t	75	abs_exp_date	_NOVALUE_	2024-04-20 18:47	2024-02-08 17:47:50.678512
233	0	t	76	normal_username	_NOVALUE_	jamali	2024-02-08 17:51:43.35428
235	0	t	77	abs_exp_date	_NOVALUE_	2024-06-25 18:54	2024-02-08 17:54:28.795224
568	0	t	303	normal_username	_NOVALUE_	nazanin	2024-02-29 07:54:32.309409
570	0	t	305	normal_username	_NOVALUE_	shshakeri	2024-02-29 13:21:19.84335
240	0	t	80	normal_username	_NOVALUE_	sajad	2024-02-08 18:13:33.229195
241	0	t	80	abs_exp_date	_NOVALUE_	2024-02-18 18:13	2024-02-08 18:13:58.012026
242	0	t	81	normal_username	_NOVALUE_	sheyda2	2024-02-08 18:15:05.199736
243	0	t	81	abs_exp_date	_NOVALUE_	2024-02-22 18:15	2024-02-08 18:15:19.381146
244	0	t	82	normal_username	_NOVALUE_	nazanin	2024-02-08 18:17:16.391172
245	0	t	82	abs_exp_date	_NOVALUE_	2024-02-28 18:17	2024-02-08 18:17:27.934872
246	0	t	83	normal_username	_NOVALUE_	esfandiari	2024-02-08 18:18:30.52316
247	0	t	83	abs_exp_date	_NOVALUE_	2024-02-28 18:18	2024-02-08 18:18:45.042611
248	0	t	84	normal_username	_NOVALUE_	soheyl	2024-02-08 18:20:28.516969
249	0	t	84	abs_exp_date	_NOVALUE_	2024-02-13 18:20	2024-02-08 18:20:40.26407
250	0	t	85	normal_username	_NOVALUE_	kami	2024-02-08 18:25:04.855564
251	0	t	85	abs_exp_date	_NOVALUE_	2024-03-09 18:25	2024-02-08 18:25:29.889083
252	0	t	86	normal_username	_NOVALUE_	sheyda	2024-02-08 18:28:11.885937
253	0	t	86	abs_exp_date	_NOVALUE_	2024-02-22 18:28	2024-02-08 18:28:23.756534
254	0	t	87	normal_username	_NOVALUE_	akbari	2024-02-08 18:31:28.729145
255	0	t	87	abs_exp_date	_NOVALUE_	2024-04-15 19:31	2024-02-08 18:31:44.063913
256	0	t	87	traffic_periodic_accounting_daily	90	67	2024-02-08 18:32:00.797848
257	0	t	87	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-02-08 18:32:00.797848
258	0	t	88	normal_username	_NOVALUE_	m38	2024-02-08 18:33:55.792451
259	0	t	88	abs_exp_date	_NOVALUE_	2024-03-07 18:34	2024-02-08 18:34:09.465988
260	0	t	89	normal_username	_NOVALUE_	m37	2024-02-08 18:36:07.052009
261	0	t	89	abs_exp_date	_NOVALUE_	2024-05-05 19:36	2024-02-08 18:36:28.233339
262	0	t	89	traffic_periodic_accounting_daily	90	87	2024-02-08 18:37:01.816198
263	0	t	89	traffic_periodic_accounting_daily_limit	150000M	60000M	2024-02-08 18:37:01.816198
264	0	t	90	normal_username	_NOVALUE_	m35	2024-02-08 18:38:01.453669
265	0	t	90	abs_exp_date	_NOVALUE_	2024-05-03 19:38	2024-02-08 18:38:43.330763
266	0	t	90	traffic_periodic_accounting_daily	90	85	2024-02-08 18:39:07.918022
267	0	t	90	traffic_periodic_accounting_daily_limit	150000M	70000M	2024-02-08 18:39:07.918022
268	0	t	91	normal_username	_NOVALUE_	m32	2024-02-08 18:40:18.013826
269	0	t	91	abs_exp_date	_NOVALUE_	2024-03-29 19:40	2024-02-08 18:40:38.610808
270	0	t	91	traffic_periodic_accounting_daily	60	50	2024-02-08 18:41:03.469381
271	0	t	91	traffic_periodic_accounting_daily_limit	70000M	60000M	2024-02-08 18:41:03.469381
272	0	t	92	normal_username	_NOVALUE_	melisa	2024-02-08 18:43:57.068766
273	0	t	92	abs_exp_date	_NOVALUE_	2024-02-24 18:44	2024-02-08 18:44:10.77039
274	0	t	93	normal_username	_NOVALUE_	danesh	2024-02-08 18:46:03.020302
275	0	t	93	abs_exp_date	_NOVALUE_	2024-03-24 19:46	2024-02-08 18:46:16.11022
506	0	t	248	abs_exp_date	_NOVALUE_	2024-05-08 17:19	2024-02-20 16:19:38.413283
523	0	f	14	traffic_periodic_accounting_daily	_NOVALUE_	90	2024-02-24 11:00:31.85516
278	0	t	95	normal_username	_NOVALUE_	cheraghi	2024-02-08 18:50:16.48441
279	0	t	95	abs_exp_date	_NOVALUE_	2024-02-11 18:50	2024-02-08 18:50:51.489543
280	0	t	96	normal_username	_NOVALUE_	negar11	2024-02-08 18:57:34.033733
281	0	t	96	abs_exp_date	_NOVALUE_	2024-02-17 18:58	2024-02-08 18:58:03.062861
282	0	t	97	normal_username	_NOVALUE_	negar12	2024-02-08 18:58:51.32091
283	0	t	97	abs_exp_date	_NOVALUE_	2024-02-17 18:59	2024-02-08 18:59:07.560643
284	0	t	98	normal_username	_NOVALUE_	hamidreza	2024-02-08 19:02:58.122451
285	0	t	98	abs_exp_date	_NOVALUE_	2024-02-11 19:03	2024-02-08 19:03:10.752857
566	0	t	300	normal_username	_NOVALUE_	mostafa102	2024-02-29 03:59:15.326198
571	0	t	306	normal_username	_NOVALUE_	nekoonampc	2024-02-29 14:29:32.220497
775	0	t	269	first_login	2024-02-25 13:09	_NOVALUE_	2024-03-26 06:32:46.128518
290	0	t	101	normal_username	_NOVALUE_	rezaei	2024-02-09 02:52:29.815691
291	0	t	101	abs_exp_date	_NOVALUE_	2024-02-27 02:52	2024-02-09 02:52:45.832411
524	0	f	14	traffic_periodic_accounting_daily_limit	_NOVALUE_	100000M	2024-02-24 11:00:31.85516
531	0	t	267	normal_username	_NOVALUE_	aghasemi	2024-02-25 06:17:54.580785
532	0	t	268	normal_username	_NOVALUE_	hatami	2024-02-25 12:06:14.82392
534	0	t	270	normal_username	_NOVALUE_	ataheri	2024-02-25 13:54:30.949819
710	0	t	414	normal_username	_NOVALUE_	imani	2024-03-15 16:24:48.394605
609	0	t	332	normal_username	_NOVALUE_	bama2038	2024-03-05 05:01:32.451994
610	0	t	333	normal_username	_NOVALUE_	bama2039	2024-03-05 05:01:32.451994
611	0	t	335	normal_username	_NOVALUE_	elmira	2024-03-05 08:40:33.912522
612	0	t	336	normal_username	_NOVALUE_	radan	2024-03-05 12:42:08.934617
613	0	t	337	normal_username	_NOVALUE_	rose	2024-03-05 14:35:32.194832
614	0	t	338	normal_username	_NOVALUE_	c105	2024-03-05 14:50:37.295108
615	0	t	339	normal_username	_NOVALUE_	arsa	2024-03-05 15:33:04.657317
621	0	t	344	normal_username	_NOVALUE_	elnaz	2024-03-06 15:55:57.640221
622	0	t	344	group	2-Month-70G	3-Month-150G	2024-03-06 15:56:50.144291
625	0	t	347	group	1-Month-50G	1-Month-35G	2024-03-06 23:56:15.403293
628	0	t	349	normal_username	_NOVALUE_	mostafa107	2024-03-07 03:36:05.417934
629	0	t	350	normal_username	_NOVALUE_	mostafa108	2024-03-07 03:37:21.525006
630	0	t	351	normal_username	_NOVALUE_	majid	2024-03-07 06:07:46.219358
631	0	t	352	normal_username	_NOVALUE_	erfan	2024-03-08 02:38:56.6044
632	0	t	353	normal_username	_NOVALUE_	behnam4	2024-03-08 07:00:11.142204
633	0	t	354	normal_username	_NOVALUE_	beheshti	2024-03-08 15:01:05.966954
634	0	t	355	normal_username	_NOVALUE_	babak	2024-03-08 15:19:25.644035
636	0	t	357	normal_username	_NOVALUE_	gorjian3	2024-03-09 03:43:11.354365
639	0	t	359	normal_username	_NOVALUE_	c106	2024-03-09 15:09:49.140077
642	0	t	362	normal_username	_NOVALUE_	setayesh	2024-03-10 13:28:33.414496
643	0	t	363	normal_username	_NOVALUE_	morteza	2024-03-10 13:30:04.40133
644	0	t	364	normal_username	_NOVALUE_	golnaz	2024-03-10 17:01:59.732719
645	0	t	366	normal_username	_NOVALUE_	yazdan	2024-03-10 17:20:47.725784
646	0	t	367	normal_username	_NOVALUE_	bama2006	2024-03-10 18:03:26.488911
647	0	t	367	group	1-Month-35G	2-Month-70G	2024-03-10 18:03:40.248889
648	0	t	367	abs_exp_date	_NOVALUE_	2024-04-17 18:03	2024-03-10 18:03:57.323612
649	0	t	368	normal_username	_NOVALUE_	bama2040	2024-03-10 18:06:02.961335
650	0	t	369	normal_username	_NOVALUE_	bama2041	2024-03-10 18:06:02.961335
651	0	t	370	normal_username	_NOVALUE_	bama2042	2024-03-10 18:06:02.961335
652	0	t	371	normal_username	_NOVALUE_	bama2043	2024-03-10 18:06:02.961335
653	0	t	372	normal_username	_NOVALUE_	bama2044	2024-03-10 18:06:02.961335
654	0	t	373	normal_username	_NOVALUE_	bama2045	2024-03-10 18:06:02.961335
655	0	t	374	normal_username	_NOVALUE_	bama2046	2024-03-10 18:06:02.961335
656	0	t	375	normal_username	_NOVALUE_	bama2047	2024-03-10 18:06:02.961335
657	0	t	376	normal_username	_NOVALUE_	bama2048	2024-03-10 18:06:02.961335
658	0	t	377	normal_username	_NOVALUE_	bama2049	2024-03-10 18:06:02.961335
659	0	t	379	normal_username	_NOVALUE_	bama2050	2024-03-10 18:10:32.646583
660	0	t	380	normal_username	_NOVALUE_	bama2051	2024-03-10 18:10:32.646583
661	0	t	381	normal_username	_NOVALUE_	bama2052	2024-03-10 18:10:32.646583
662	0	t	382	normal_username	_NOVALUE_	bama2053	2024-03-10 18:10:32.646583
663	0	t	383	normal_username	_NOVALUE_	bama2054	2024-03-10 18:10:32.646583
664	0	t	384	normal_username	_NOVALUE_	bama2055	2024-03-10 18:10:32.646583
665	0	t	385	normal_username	_NOVALUE_	bama2056	2024-03-10 18:10:32.646583
666	0	t	386	normal_username	_NOVALUE_	bama2057	2024-03-10 18:10:32.646583
667	0	t	387	normal_username	_NOVALUE_	bama2058	2024-03-10 18:10:32.646583
668	0	t	388	normal_username	_NOVALUE_	bama2059	2024-03-10 18:10:32.646583
671	0	t	393	normal_username	_NOVALUE_	meysam	2024-03-12 01:03:23.024224
672	0	t	394	normal_username	_NOVALUE_	jalalizadeh	2024-03-12 03:21:05.715954
673	0	t	394	abs_exp_date	_NOVALUE_	2024-03-23 03:22	2024-03-12 03:22:17.299988
676	0	t	395	abs_exp_date	_NOVALUE_	2024-04-26 05:42	2024-03-12 05:42:55.670243
677	0	t	395	traffic_periodic_accounting_daily	60	45	2024-03-12 05:43:26.215518
678	0	t	395	traffic_periodic_accounting_daily_limit	70000M	220000M	2024-03-12 05:43:26.215518
679	0	t	395	traffic_periodic_accounting_daily	45	45	2024-03-12 05:43:49.878601
680	0	t	395	traffic_periodic_accounting_daily_limit	220000M	21000M	2024-03-12 05:43:49.878601
681	0	t	119	first_login	2024-02-11 05:24	_NOVALUE_	2024-03-12 07:55:16.36821
682	0	t	396	normal_username	_NOVALUE_	hatami2	2024-03-12 13:47:22.222289
683	0	t	396	group	1-Month-10G	1-Month-20G	2024-03-12 13:47:37.865908
684	0	t	397	normal_username	_NOVALUE_	sedighi	2024-03-12 13:52:32.200649
685	0	t	397	abs_exp_date	_NOVALUE_	2024-04-25 13:52	2024-03-12 13:52:54.427325
686	0	t	397	traffic_periodic_accounting_daily	60	44	2024-03-12 13:53:12.310525
687	0	t	397	traffic_periodic_accounting_daily_limit	70000M	65000M	2024-03-12 13:53:12.310525
688	0	t	398	normal_username	_NOVALUE_	elna	2024-03-12 14:08:21.792746
689	0	t	399	normal_username	_NOVALUE_	mandana	2024-03-12 16:47:17.957559
693	0	t	403	normal_username	_NOVALUE_	niusha	2024-03-13 16:36:01.756069
694	0	t	404	normal_username	_NOVALUE_	farzin1	2024-03-13 16:49:34.835035
695	0	t	405	normal_username	_NOVALUE_	farzin2	2024-03-13 16:51:24.164072
696	0	t	134	first_login	2024-02-12 18:34	_NOVALUE_	2024-03-14 13:47:17.659463
697	0	t	406	normal_username	_NOVALUE_	minoo	2024-03-14 14:14:34.750535
698	0	t	406	abs_exp_date	_NOVALUE_	2024-07-09 14:15	2024-03-14 14:15:03.282483
699	0	t	406	traffic_periodic_accounting_daily	180	117	2024-03-14 14:15:22.72179
700	0	t	406	traffic_periodic_accounting_daily_limit	300000M	200000M	2024-03-14 14:15:22.72179
701	0	t	407	normal_username	_NOVALUE_	tahmineh	2024-03-14 14:29:16.885757
702	0	t	408	normal_username	_NOVALUE_	navayi	2024-03-14 14:41:26.988048
703	0	t	409	normal_username	_NOVALUE_	saragol	2024-03-14 19:06:24.782552
706	0	t	411	abs_exp_date	_NOVALUE_	2024-06-04 06:27	2024-03-15 06:27:40.618281
711	0	t	414	abs_exp_date	_NOVALUE_	2024-04-12 16:25	2024-03-15 16:25:57.139333
717	0	t	171	first_login	2024-02-16 16:20	_NOVALUE_	2024-03-16 17:07:30.717025
718	0	t	171	traffic_periodic_accounting_daily	30	30	2024-03-16 17:08:03.214823
720	0	t	421	normal_username	_NOVALUE_	afsane	2024-03-17 13:36:21.161856
721	0	t	422	normal_username	_NOVALUE_	arash	2024-03-17 13:36:45.13444
722	0	t	423	normal_username	_NOVALUE_	sahar1	2024-03-17 16:20:03.014395
723	0	t	424	normal_username	_NOVALUE_	jalalizadeh2	2024-03-17 16:23:30.397764
724	0	t	425	normal_username	_NOVALUE_	jalalizadeh3	2024-03-17 16:25:45.328273
725	0	t	427	normal_username	_NOVALUE_	namazian	2024-03-17 17:10:23.895433
726	0	t	427	abs_exp_date	_NOVALUE_	2024-05-24 17:10	2024-03-17 17:10:37.000259
729	0	t	428	normal_username	_NOVALUE_	hanieh2	2024-03-18 05:20:19.046434
731	0	t	430	normal_username	_NOVALUE_	msm26	2024-03-18 16:55:33.817058
732	0	t	431	normal_username	_NOVALUE_	bama2004	2024-03-18 17:04:39.070891
735	0	t	139	first_login	2024-02-18 06:58	_NOVALUE_	2024-03-19 10:08:40.356517
739	0	t	437	normal_username	_NOVALUE_	m40	2024-03-19 13:30:40.415282
740	0	t	436	multi_login	2	1	2024-03-19 13:31:06.791579
741	0	t	374	group	1-Month-35G	2-Month-70G	2024-03-19 14:46:15.202069
742	0	t	438	normal_username	_NOVALUE_	poneh	2024-03-19 15:15:55.592983
743	0	t	176	first_login	2024-02-17 08:32	_NOVALUE_	2024-03-19 15:40:46.882747
744	0	t	176	group	1-Month-35G	3-Month-150G	2024-03-19 15:41:04.165186
745	0	t	59	group	2-Month-70G	3-Month-150G	2024-03-19 18:04:06.387104
746	0	t	59	first_login	2024-02-08 18:10	_NOVALUE_	2024-03-19 18:04:14.573574
749	0	t	209	first_login	2024-02-20 15:26	_NOVALUE_	2024-03-20 04:33:46.507809
750	0	t	210	first_login	2024-02-22 03:58	_NOVALUE_	2024-03-20 04:34:10.432665
751	0	t	120	first_login	2024-02-11 08:01	_NOVALUE_	2024-03-20 06:05:17.946317
752	0	t	6	first_login	2024-02-08 13:20	_NOVALUE_	2024-03-20 12:21:35.797343
753	0	t	6	abs_exp_date	2024-03-19 09:04	2024-03-27 12:21	2024-03-20 12:21:51.689486
757	0	t	275	first_login	2024-02-26 10:44	_NOVALUE_	2024-03-23 03:28:11.459598
759	0	t	394	abs_exp_date	2024-03-23 03:22	_NOVALUE_	2024-03-23 03:30:14.829515
760	0	t	441	normal_username	_NOVALUE_	sheyda	2024-03-23 09:31:45.925553
765	0	t	444	normal_username	_NOVALUE_	mvo1	2024-03-24 10:47:46.653043
767	0	t	445	normal_username	_NOVALUE_	nazemian	2024-03-25 05:07:38.451949
771	0	t	261	first_login	2024-02-24 07:21	_NOVALUE_	2024-03-25 15:00:45.005618
772	0	t	258	first_login	2024-02-23 04:40	_NOVALUE_	2024-03-26 03:44:30.627898
774	0	t	447	abs_exp_date	_NOVALUE_	2024-03-27 04:38	2024-03-26 04:38:27.019974
777	0	t	207	group	1-Month-35G	3-Month-150G	2024-03-26 12:23:54.712313
779	0	t	272	first_login	2024-02-25 14:40	_NOVALUE_	2024-03-26 17:30:03.742332
781	0	t	448	normal_username	_NOVALUE_	msm20	2024-03-27 04:01:17.874462
782	0	t	447	group	1-Month-10G	3-Month-150G	2024-03-27 04:03:45.713449
786	0	t	448	group	1-Month-50G	2-Month-70G	2024-03-27 04:12:23.231471
789	0	t	450	abs_exp_date	_NOVALUE_	2024-04-12 04:18	2024-03-27 04:18:47.727795
791	0	t	93	abs_exp_date	2024-03-24 19:46	_NOVALUE_	2024-03-27 07:30:52.221127
793	0	t	440	group	1-Month-10G	3-Month-150G	2024-03-27 08:12:52.523437
796	0	t	279	first_login	2024-02-26 05:27	_NOVALUE_	2024-03-27 13:33:28.016847
797	0	t	6	first_login	2024-03-20 12:33	_NOVALUE_	2024-03-27 14:45:02.593489
798	0	t	6	abs_exp_date	2024-03-27 12:21	_NOVALUE_	2024-03-27 14:45:13.018486
799	0	t	6	group	2-Month-70G	3-Month-150G	2024-03-27 14:46:40.369486
801	0	t	280	first_login	2024-02-26 09:32	_NOVALUE_	2024-03-28 06:11:03.396826
802	0	t	452	normal_username	_NOVALUE_	leila24	2024-03-28 19:05:31.590711
803	0	t	452	abs_exp_date	_NOVALUE_	2024-04-09 19:05	2024-03-28 19:05:58.108276
804	0	t	453	normal_username	_NOVALUE_	mtaheri	2024-03-29 07:04:16.213383
807	0	t	286	first_login	2024-02-28 07:04	_NOVALUE_	2024-03-29 09:16:33.990474
808	0	t	164	first_login	2024-02-15 04:58	_NOVALUE_	2024-03-30 12:24:36.090692
810	0	t	303	first_login	2024-02-29 07:55	_NOVALUE_	2024-03-30 12:44:04.363481
811	0	t	455	normal_username	_NOVALUE_	sanjabi10	2024-03-30 15:11:32.937843
812	0	t	252	first_login	2024-02-22 07:04	_NOVALUE_	2024-03-30 16:08:40.850838
813	0	t	457	normal_username	_NOVALUE_	hadadi2	2024-03-31 04:06:04.111891
815	0	t	458	normal_username	_NOVALUE_	leyla	2024-03-31 12:16:10.124316
816	0	t	425	group	1-Month-35G	1-Month-70G	2024-03-31 13:50:23.806714
819	0	t	460	abs_exp_date	_NOVALUE_	2024-04-17 16:51	2024-03-31 16:51:28.215311
820	0	t	310	first_login	2024-03-01 10:33	_NOVALUE_	2024-03-31 16:52:12.530028
821	0	t	311	first_login	2024-03-01 15:49	_NOVALUE_	2024-03-31 16:53:02.593002
824	0	t	87	first_login	2024-02-09 01:42	_NOVALUE_	2024-04-01 07:37:29.093313
826	0	t	320	first_login	2024-03-03 03:33	_NOVALUE_	2024-04-01 08:16:27.984884
827	0	t	287	first_login	2024-02-28 08:46	_NOVALUE_	2024-04-01 12:19:33.218791
828	0	t	246	first_login	2024-02-20 14:01	_NOVALUE_	2024-04-01 16:03:47.203058
829	0	t	461	normal_username	_NOVALUE_	neishaboori	2024-04-01 16:05:34.031253
830	0	t	306	first_login	2024-02-29 14:29	_NOVALUE_	2024-04-01 17:05:08.262108
831	0	t	128	first_login	2024-02-12 03:22	_NOVALUE_	2024-04-02 04:26:43.588912
833	0	t	128	group	2-Month-70G	3-Month-150G	2024-04-02 04:26:58.324565
834	0	t	300	first_login	2024-02-29 04:55	_NOVALUE_	2024-04-02 04:37:06.110089
836	0	t	314	first_login	2024-03-02 07:27	_NOVALUE_	2024-04-02 04:38:08.532397
839	0	t	316	first_login	2024-03-02 15:50	_NOVALUE_	2024-04-02 04:40:57.050141
841	0	t	126	abs_exp_date	2024-03-20 02:56	_NOVALUE_	2024-04-02 07:00:14.406485
842	0	t	126	group	2-Month-70G	3-Month-150G	2024-04-02 07:00:23.442141
845	0	t	105	abs_exp_date	2024-03-27 07:04	_NOVALUE_	2024-04-02 09:08:58.475812
846	0	t	105	group	2-Month-70G	3-Month-150G	2024-04-02 09:09:07.010677
847	0	t	315	first_login	2024-03-02 07:03	_NOVALUE_	2024-04-02 12:40:24.783574
848	0	t	464	normal_username	_NOVALUE_	esi	2024-04-02 16:43:42.423925
850	0	t	202	first_login	2024-02-19 07:24	_NOVALUE_	2024-04-03 03:42:10.437658
851	0	t	153	first_login	2024-02-14 07:02	_NOVALUE_	2024-04-03 04:54:40.117212
852	0	t	153	abs_exp_date	2024-03-05 15:48	_NOVALUE_	2024-04-03 04:54:44.781043
854	0	t	161	first_login	2024-02-15 01:40	_NOVALUE_	2024-04-03 05:16:38.491565
855	0	t	161	group	2-Month-70G	3-Month-150G	2024-04-03 05:16:54.115502
856	0	t	127	group	2-Month-70G	6-Month-300G	2024-04-03 05:22:16.319847
858	0	t	127	abs_exp_date	_NOVALUE_	2024-07-11 05:22	2024-04-03 05:22:50.272535
863	0	t	467	normal_username	_NOVALUE_	bameri	2024-04-03 17:56:44.221015
864	0	t	468	normal_username	_NOVALUE_	shahi	2024-04-04 02:48:25.992195
865	0	t	195	abs_exp_date	2024-04-03 15:24	_NOVALUE_	2024-04-04 03:03:01.923814
867	0	t	195	traffic_periodic_accounting_daily	45	_NOVALUE_	2024-04-04 03:03:13.188156
727	0	t	427	traffic_periodic_accounting_daily	90	68	2024-03-17 17:11:04.629741
728	0	t	427	traffic_periodic_accounting_daily_limit	150000M	120000M	2024-03-17 17:11:04.629741
730	0	t	429	normal_username	_NOVALUE_	milad	2024-03-18 06:27:04.205117
736	0	t	433	normal_username	_NOVALUE_	danial	2024-03-19 12:38:58.639669
1062	0	t	538	normal_username	_NOVALUE_	nhasibi2	2024-04-23 05:07:39.528984
747	0	t	59	abs_exp_date	2024-03-18 17:39	_NOVALUE_	2024-03-19 18:04:26.912505
756	0	t	440	normal_username	_NOVALUE_	mahshid2	2024-03-22 13:35:19.900526
758	0	t	394	first_login	2024-03-17 14:15	_NOVALUE_	2024-03-23 03:29:55.773797
761	0	t	260	first_login	2024-02-23 15:47	_NOVALUE_	2024-03-23 09:33:16.825198
762	0	t	190	first_login	2024-02-18 07:54	_NOVALUE_	2024-03-23 09:33:56.625407
763	0	t	442	normal_username	_NOVALUE_	aghasemi	2024-03-23 09:42:50.596421
766	0	t	255	first_login	2024-02-22 13:03	_NOVALUE_	2024-03-24 13:03:01.904066
768	0	t	446	normal_username	_NOVALUE_	seyed	2024-03-25 06:06:01.747048
769	0	t	270	first_login	2024-02-25 16:17	_NOVALUE_	2024-03-25 06:38:20.913895
770	0	t	270	abs_exp_date	2024-03-23 14:55	_NOVALUE_	2024-03-25 06:38:35.543535
776	0	t	207	first_login	2024-02-19 15:14	_NOVALUE_	2024-03-26 12:23:39.315194
778	0	t	271	first_login	2024-02-25 14:23	_NOVALUE_	2024-03-26 16:30:08.800844
780	0	t	272	group	1-Month-50G	3-Month-150G	2024-03-26 17:30:20.114406
783	0	t	447	first_login	2024-03-27 03:48	_NOVALUE_	2024-03-27 04:03:54.059435
784	0	t	447	abs_exp_date	2024-03-27 04:38	_NOVALUE_	2024-03-27 04:04:08.094163
785	0	t	447	group	3-Month-150G	1-Month-50G	2024-03-27 04:04:23.39616
787	0	t	448	abs_exp_date	_NOVALUE_	2024-05-05 04:12	2024-03-27 04:12:52.640171
788	0	t	450	normal_username	_NOVALUE_	farnaz2	2024-03-27 04:18:29.891452
790	0	t	93	first_login	2024-02-08 20:03	_NOVALUE_	2024-03-27 07:30:43.476709
792	0	t	93	group	2-Month-70G	3-Month-150G	2024-03-27 07:31:08.418547
794	0	t	278	first_login	2024-02-26 02:37	_NOVALUE_	2024-03-27 10:41:24.769107
795	0	t	242	first_login	2024-02-26 04:08	_NOVALUE_	2024-03-27 11:44:42.960403
805	0	t	453	abs_exp_date	_NOVALUE_	2024-03-30 07:04	2024-03-29 07:04:34.724883
806	0	t	454	normal_username	_NOVALUE_	arash1	2024-03-29 09:09:08.119008
809	0	t	164	group	1-Month-20G	1-Month-35G	2024-03-30 12:25:14.337043
814	0	t	319	group	1-Month-35G	2-Month-70G	2024-03-31 06:24:45.935614
817	0	t	425	group	1-Month-70G	1-Month-35G	2024-03-31 13:53:46.617452
818	0	t	460	normal_username	_NOVALUE_	jalalizadeh2	2024-03-31 16:51:10.202278
822	0	t	311	abs_exp_date	2024-04-04 10:14	2024-05-04 16:53	2024-03-31 16:53:40.890407
825	0	t	87	abs_exp_date	2024-04-15 19:31	2024-10-11 07:37	2024-04-01 07:37:50.598809
832	0	t	128	abs_exp_date	2024-03-22 04:20	_NOVALUE_	2024-04-02 04:26:48.145874
835	0	t	301	first_login	2024-03-02 02:37	_NOVALUE_	2024-04-02 04:37:37.302645
837	0	t	313	first_login	2024-03-02 05:49	_NOVALUE_	2024-04-02 04:38:24.356851
838	0	t	462	normal_username	_NOVALUE_	mostafa109	2024-04-02 04:39:01.034229
840	0	t	126	first_login	2024-02-12 02:05	_NOVALUE_	2024-04-02 06:59:26.628874
843	0	t	463	normal_username	_NOVALUE_	jalalizadeh10	2024-04-02 07:19:48.786418
844	0	t	105	first_login	2024-02-09 06:14	_NOVALUE_	2024-04-02 09:08:53.281844
849	0	t	465	normal_username	_NOVALUE_	noora	2024-04-02 16:45:55.717832
853	0	t	391	group	1-Month-35G	1-Month-70G	2024-04-03 05:01:08.812414
857	0	t	127	first_login	2024-02-12 02:03	_NOVALUE_	2024-04-03 05:22:27.836269
859	0	t	127	traffic_periodic_accounting_daily	37	99	2024-04-03 05:24:03.386344
860	0	t	127	traffic_periodic_accounting_daily_limit	25000M	100000M	2024-04-03 05:24:03.386344
861	0	t	127	traffic_periodic_accounting_daily_usage	58591904	_NOVALUE_	2024-04-03 05:24:03.386344
862	0	t	322	first_login	2024-03-04 04:37	_NOVALUE_	2024-04-03 12:00:41.941637
866	0	t	195	first_login	2024-02-18 14:51	_NOVALUE_	2024-04-04 03:03:06.213401
868	0	t	195	traffic_periodic_accounting_daily_limit	60000M	_NOVALUE_	2024-04-04 03:03:13.188156
869	0	t	195	traffic_periodic_accounting_daily_usage	12939177	_NOVALUE_	2024-04-04 03:03:13.188156
870	0	t	195	group	2-Month-70G	3-Month-150G	2024-04-04 03:03:42.195481
871	0	t	154	first_login	2024-02-16 01:42	_NOVALUE_	2024-04-04 03:10:37.23006
872	0	t	154	abs_exp_date	2024-04-03 18:24	_NOVALUE_	2024-04-04 03:10:42.928453
873	0	t	154	group	2-Month-70G	3-Month-150G	2024-04-04 03:10:55.011984
874	0	t	277	first_login	2024-02-26 06:00	_NOVALUE_	2024-04-04 03:15:12.220191
875	0	t	276	first_login	2024-02-26 02:38	_NOVALUE_	2024-04-04 03:15:29.506624
876	0	t	469	normal_username	_NOVALUE_	asemi	2024-04-04 07:42:22.195627
877	0	t	470	normal_username	_NOVALUE_	salmani	2024-04-04 08:01:48.444608
878	0	t	471	normal_username	_NOVALUE_	mahshid	2024-04-04 09:42:17.8402
879	0	t	471	abs_exp_date	_NOVALUE_	2024-06-27 09:42	2024-04-04 09:42:54.262691
880	0	t	328	first_login	2024-03-05 12:11	_NOVALUE_	2024-04-04 11:51:15.045288
881	0	t	362	first_login	2024-03-10 13:32	_NOVALUE_	2024-04-04 15:38:55.496586
882	0	t	362	group	1-Month-35G	2-Month-70G	2024-04-04 15:39:18.51198
883	0	t	362	abs_exp_date	_NOVALUE_	2024-05-08 15:41	2024-04-04 15:41:49.273331
884	0	t	336	first_login	2024-03-05 21:48	_NOVALUE_	2024-04-04 19:28:53.636518
885	0	t	472	normal_username	_NOVALUE_	nabikhani	2024-04-05 04:26:44.486869
886	0	t	168	first_login	2024-02-20 09:54	_NOVALUE_	2024-04-05 08:41:54.493875
887	0	t	168	abs_exp_date	2024-04-02 18:14	_NOVALUE_	2024-04-05 08:42:08.727289
888	0	t	168	group	2-Month-70G	3-Month-150G	2024-04-05 08:42:31.167796
889	0	t	347	first_login	2024-03-07 01:26	_NOVALUE_	2024-04-05 10:04:11.843903
890	0	t	473	normal_username	_NOVALUE_	ghafari20	2024-04-05 10:05:18.983706
891	0	t	178	abs_exp_date	2024-03-15 06:03	_NOVALUE_	2024-04-05 13:24:51.337248
892	0	t	321	first_login	2024-03-03 14:37	_NOVALUE_	2024-04-05 13:46:32.988145
893	0	t	475	normal_username	_NOVALUE_	bagheri2	2024-04-05 16:14:45.130589
894	0	t	475	abs_exp_date	_NOVALUE_	2024-04-18 16:14	2024-04-05 16:14:59.760333
895	0	t	329	first_login	2024-03-06 11:57	_NOVALUE_	2024-04-05 16:43:59.245624
896	0	t	340	first_login	2024-03-06 09:03	_NOVALUE_	2024-04-06 06:23:50.060972
897	0	t	204	first_login	2024-02-19 09:31	_NOVALUE_	2024-04-06 10:01:13.139406
898	0	t	348	first_login	2024-03-07 02:27	_NOVALUE_	2024-04-06 11:30:07.477592
899	0	t	345	first_login	2024-03-07 04:04	_NOVALUE_	2024-04-06 13:23:45.445501
900	0	t	476	normal_username	_NOVALUE_	arianpc	2024-04-06 17:06:33.76723
901	0	t	476	abs_exp_date	_NOVALUE_	2024-11-12 16:07	2024-04-06 17:07:04.968057
904	0	t	352	first_login	2024-03-08 02:42	_NOVALUE_	2024-04-07 08:19:42.957485
905	0	t	39	first_login	2024-02-08 15:04	_NOVALUE_	2024-04-07 09:59:52.405365
907	0	t	353	first_login	2024-03-08 07:47	_NOVALUE_	2024-04-07 12:03:08.019172
908	0	t	409	group	1-Month-35G	1-Month-50G	2024-04-07 12:15:17.215054
909	0	t	239	first_login	2024-02-24 13:06	_NOVALUE_	2024-04-07 13:20:22.030854
910	0	t	477	normal_username	_NOVALUE_	omid1	2024-04-07 15:15:00.981381
911	0	t	268	first_login	2024-03-08 16:28	_NOVALUE_	2024-04-08 05:07:19.921331
912	0	t	268	group	1-Month-35G	2-Month-70G	2024-04-08 05:07:38.776684
914	0	t	478	normal_username	_NOVALUE_	saba	2024-04-08 16:23:24.599061
916	0	t	480	normal_username	_NOVALUE_	reyhaneh	2024-04-09 02:08:11.847582
918	0	t	357	first_login	2024-03-09 03:43	_NOVALUE_	2024-04-09 04:02:33.625377
919	0	t	357	group	1-Month-35G	3-Month-150G	2024-04-09 04:02:43.00586
921	0	t	481	normal_username	_NOVALUE_	msm86	2024-04-09 06:35:08.301565
922	0	t	482	normal_username	_NOVALUE_	bama-2060	2024-04-09 06:58:03.501772
923	0	t	483	normal_username	_NOVALUE_	bama-2061	2024-04-09 06:58:03.501772
924	0	t	484	normal_username	_NOVALUE_	bama-2062	2024-04-09 06:58:03.501772
925	0	t	485	normal_username	_NOVALUE_	bama-2063	2024-04-09 06:58:03.501772
926	0	t	486	normal_username	_NOVALUE_	bama-2064	2024-04-09 06:58:03.501772
927	0	t	487	normal_username	_NOVALUE_	bama-2065	2024-04-09 06:58:03.501772
928	0	t	488	normal_username	_NOVALUE_	bama-2066	2024-04-09 06:58:03.501772
929	0	t	489	normal_username	_NOVALUE_	bama-2067	2024-04-09 06:58:03.501772
930	0	t	490	normal_username	_NOVALUE_	bama-2068	2024-04-09 06:58:03.501772
931	0	t	491	normal_username	_NOVALUE_	bama-2069	2024-04-09 06:58:03.501772
932	0	t	493	normal_username	_NOVALUE_	bama2060	2024-04-09 07:01:23.530214
933	0	t	494	normal_username	_NOVALUE_	bama2061	2024-04-09 07:01:23.530214
934	0	t	495	normal_username	_NOVALUE_	bama2062	2024-04-09 07:01:23.530214
935	0	t	496	normal_username	_NOVALUE_	bama2063	2024-04-09 07:01:23.530214
937	0	t	498	normal_username	_NOVALUE_	bama2065	2024-04-09 07:01:23.530214
938	0	t	499	normal_username	_NOVALUE_	bama2066	2024-04-09 07:01:23.530214
939	0	t	500	normal_username	_NOVALUE_	bama2067	2024-04-09 07:01:23.530214
940	0	t	501	normal_username	_NOVALUE_	bama2068	2024-04-09 07:01:23.530214
941	0	t	502	normal_username	_NOVALUE_	bama2069	2024-04-09 07:01:23.530214
943	0	t	390	first_login	2024-03-11 17:17	_NOVALUE_	2024-04-09 07:17:16.786439
944	0	t	349	first_login	2024-03-09 08:28	_NOVALUE_	2024-04-09 08:09:32.324183
945	0	t	350	first_login	2024-03-11 05:27	_NOVALUE_	2024-04-09 08:09:46.258394
947	0	t	504	normal_username	_NOVALUE_	bameri2	2024-04-09 12:42:32.707222
948	0	t	391	first_login	2024-03-11 16:09	_NOVALUE_	2024-04-09 16:21:29.322668
949	0	t	84	abs_exp_date	2024-02-13 18:20	_NOVALUE_	2024-04-10 08:57:53.415827
951	0	t	505	normal_username	_NOVALUE_	asal2	2024-04-10 11:01:46.980856
952	0	t	505	abs_exp_date	_NOVALUE_	2024-04-11 11:03	2024-04-10 11:03:43.200001
953	0	t	505	group	1-Month-35G	3-Month-150G	2024-04-10 12:28:51.786366
954	0	t	505	abs_exp_date	2024-04-11 11:03	_NOVALUE_	2024-04-10 12:29:07.374639
956	0	t	33	abs_exp_date	2024-04-10 15:32	_NOVALUE_	2024-04-10 18:26:51.305172
960	0	t	335	first_login	2024-03-05 09:30	_NOVALUE_	2024-04-11 07:06:59.341778
962	0	t	506	normal_username	_NOVALUE_	parisa2	2024-04-11 11:32:34.514259
963	0	t	119	first_login	2024-03-12 10:54	_NOVALUE_	2024-04-11 12:22:30.905129
964	0	t	508	normal_username	_NOVALUE_	armand	2024-04-11 16:13:24.949612
965	0	t	508	abs_exp_date	_NOVALUE_	2024-04-27 16:14	2024-04-11 16:14:03.86989
966	0	t	399	first_login	2024-03-13 01:01	_NOVALUE_	2024-04-12 03:56:34.581246
967	0	t	359	first_login	2024-03-10 06:53	_NOVALUE_	2024-04-12 04:30:39.33102
968	0	t	509	normal_username	_NOVALUE_	mehdipoor	2024-04-12 14:40:09.887981
970	0	t	450	abs_exp_date	2024-04-12 04:18	_NOVALUE_	2024-04-12 15:10:32.500033
971	0	t	130	first_login	2024-02-13 00:40	_NOVALUE_	2024-04-13 05:42:39.999745
973	0	t	512	normal_username	_NOVALUE_	msm24	2024-04-14 02:19:16.100974
974	0	t	409	first_login	2024-03-14 19:16	_NOVALUE_	2024-04-14 06:07:33.506486
976	0	t	514	normal_username	_NOVALUE_	heliya	2024-04-14 13:40:59.991705
978	0	t	402	first_login	2024-03-13 16:35	_NOVALUE_	2024-04-14 14:30:09.09642
979	0	t	515	normal_username	_NOVALUE_	maziyar	2024-04-14 14:40:59.809444
982	0	t	520	normal_username	_NOVALUE_	leila25	2024-04-15 13:23:10.259223
984	0	t	103	abs_exp_date	2024-04-15 06:24	_NOVALUE_	2024-04-15 14:33:08.699512
986	0	t	5	first_login	2024-02-08 16:46	_NOVALUE_	2024-04-15 15:23:58.563381
988	0	t	5	traffic_periodic_accounting_daily	67	_NOVALUE_	2024-04-15 15:24:20.465304
989	0	t	5	traffic_periodic_accounting_daily_limit	100000M	_NOVALUE_	2024-04-15 15:24:20.465304
990	0	t	5	traffic_periodic_accounting_daily_usage	267878760	_NOVALUE_	2024-04-15 15:24:20.465304
991	0	t	521	normal_username	_NOVALUE_	naser15	2024-04-15 16:19:54.461949
992	0	t	522	normal_username	_NOVALUE_	rezakermani	2024-04-15 16:39:56.413992
993	0	t	171	first_login	2024-03-16 17:05	_NOVALUE_	2024-04-15 16:55:27.028384
995	0	t	200	first_login	2024-03-19 06:50	_NOVALUE_	2024-04-16 12:43:46.180006
998	0	t	523	abs_exp_date	2024-04-17 13:22	_NOVALUE_	2024-04-16 13:52:01.839168
999	0	t	523	group	1-Month-10G	1-Month-100G	2024-04-16 13:52:19.50618
1001	0	t	419	first_login	2024-03-16 16:44	_NOVALUE_	2024-04-16 13:53:00.250656
1005	0	t	420	first_login	2024-03-17 10:37	_NOVALUE_	2024-04-17 03:39:09.727882
1006	0	t	420	group	1-Month-10G	1-Month-20G	2024-04-17 03:39:30.712781
1007	0	t	413	first_login	2024-03-15 16:02	_NOVALUE_	2024-04-17 05:18:07.380649
1008	0	t	142	group	1-Month-35G	3-month-100-G-bama	2024-04-17 05:31:22.959866
1011	0	t	524	normal_username	_NOVALUE_	talkhabloo	2024-04-17 13:36:45.446629
1012	0	t	524	abs_exp_date	_NOVALUE_	2024-07-01 13:37	2024-04-17 13:37:01.809349
1017	0	t	480	abs_exp_date	2024-04-29 02:09	_NOVALUE_	2024-04-17 14:16:54.821659
902	0	t	476	traffic_periodic_accounting_daily	365	220	2024-04-06 17:07:48.023204
903	0	t	476	traffic_periodic_accounting_daily_limit	600000M	300000M	2024-04-06 17:07:48.023204
906	0	t	39	abs_exp_date	2024-03-07 15:03	_NOVALUE_	2024-04-07 10:04:40.426098
913	0	t	356	first_login	2024-03-09 04:00	_NOVALUE_	2024-04-08 11:26:52.317906
915	0	t	479	normal_username	_NOVALUE_	aghasemi2	2024-04-08 17:34:26.595688
917	0	t	480	abs_exp_date	_NOVALUE_	2024-04-29 02:09	2024-04-09 02:09:46.510586
920	0	t	364	first_login	2024-03-10 22:50	_NOVALUE_	2024-04-09 06:32:21.032905
942	0	t	354	first_login	2024-03-08 15:33	_NOVALUE_	2024-04-09 07:16:32.622627
946	0	t	361	first_login	2024-03-10 06:58	_NOVALUE_	2024-04-09 08:12:32.054705
950	0	t	84	group	1-Month-20G	1-Month-35G	2024-04-10 08:58:09.164818
955	0	t	33	first_login	2024-02-09 01:02	_NOVALUE_	2024-04-10 18:26:37.903324
957	0	t	33	traffic_periodic_accounting_daily	62	_NOVALUE_	2024-04-10 18:27:15.251593
958	0	t	33	traffic_periodic_accounting_daily_limit	100000M	_NOVALUE_	2024-04-10 18:27:15.251593
959	0	t	33	traffic_periodic_accounting_daily_usage	10210324359	_NOVALUE_	2024-04-10 18:27:15.251593
961	0	t	393	first_login	2024-03-12 04:08	_NOVALUE_	2024-04-11 09:03:05.136411
969	0	t	450	first_login	2024-03-27 04:40	_NOVALUE_	2024-04-12 15:08:31.501744
972	0	t	510	normal_username	_NOVALUE_	raeesi	2024-04-13 16:28:26.10632
975	0	t	513	normal_username	_NOVALUE_	akbari2	2024-04-14 06:14:47.440026
977	0	t	400	first_login	2024-03-13 15:58	_NOVALUE_	2024-04-14 14:29:44.123367
980	0	t	516	normal_username	_NOVALUE_	msm60	2024-04-14 14:54:51.346672
981	0	t	208	group	1-Month-35G	1-Month-70G	2024-04-14 17:42:06.990548
983	0	t	103	first_login	2024-02-09 05:26	_NOVALUE_	2024-04-15 14:32:43.606059
985	0	t	103	group	3-Month-150G	1-Month-35G	2024-04-15 14:33:22.021754
987	0	t	5	abs_exp_date	2024-04-15 14:13	_NOVALUE_	2024-04-15 15:24:08.851947
994	0	t	134	first_login	2024-03-15 12:17	_NOVALUE_	2024-04-15 17:12:42.503423
996	0	t	523	normal_username	_NOVALUE_	amirk	2024-04-16 13:22:39.485157
997	0	t	523	abs_exp_date	_NOVALUE_	2024-04-17 13:22	2024-04-16 13:22:58.937903
1000	0	t	523	abs_exp_date	_NOVALUE_	2024-05-04 13:52	2024-04-16 13:52:35.056666
1002	0	t	142	first_login	2024-02-19 12:04	_NOVALUE_	2024-04-16 15:41:21.905025
1003	0	t	142	abs_exp_date	2024-04-16 13:45	_NOVALUE_	2024-04-16 15:42:18.312054
1004	0	t	142	group	2-Month-70G	1-Month-35G	2024-04-16 15:42:53.945189
1009	0	t	423	first_login	2024-03-18 02:33	_NOVALUE_	2024-04-17 06:21:49.147474
1010	0	t	428	first_login	2024-03-18 05:26	_NOVALUE_	2024-04-17 12:47:03.788593
1013	0	t	524	traffic_periodic_accounting_daily	90	75	2024-04-17 13:37:24.460513
1014	0	t	524	traffic_periodic_accounting_daily_limit	150000M	130000M	2024-04-17 13:37:24.460513
1015	0	t	429	first_login	2024-03-18 07:07	_NOVALUE_	2024-04-17 14:16:02.705879
1016	0	t	480	first_login	2024-04-09 06:50	_NOVALUE_	2024-04-17 14:16:40.57735
1018	0	t	525	normal_username	_NOVALUE_	barkhordari	2024-04-17 17:11:16.605128
1019	0	t	188	first_login	2024-02-17 14:22	_NOVALUE_	2024-04-18 07:13:15.081205
1020	0	t	188	group	2-Month-70G	3-Month-150G	2024-04-18 07:13:52.213031
1021	0	t	419	first_login	2024-04-17 13:52	_NOVALUE_	2024-04-18 07:38:51.438673
1022	0	t	526	normal_username	_NOVALUE_	zohreh	2024-04-18 08:32:30.944717
1023	0	t	526	group	1-Month-50G	1-Month-35G	2024-04-18 08:32:44.831941
1024	0	t	527	normal_username	_NOVALUE_	soheyl2	2024-04-18 13:46:02.981169
1025	0	t	430	first_login	2024-03-19 03:26	_NOVALUE_	2024-04-18 19:42:02.997724
1026	0	t	528	normal_username	_NOVALUE_	bama2070	2024-04-18 19:50:34.794341
1027	0	t	528	abs_exp_date	_NOVALUE_	2024-05-11 19:51	2024-04-18 19:51:00.530406
1078	0	t	271	first_login	2024-03-26 18:06	_NOVALUE_	2024-04-26 02:09:39.103265
1029	0	t	530	normal_username	_NOVALUE_	sanjabi20	2024-04-19 08:03:50.935793
1030	0	t	208	first_login	2024-03-20 04:44	_NOVALUE_	2024-04-19 16:28:02.324424
1031	0	t	208	group	1-Month-70G	1-Month-50G	2024-04-19 16:28:23.233186
1032	0	t	209	first_login	2024-03-20 06:59	_NOVALUE_	2024-04-19 16:31:06.131854
1033	0	t	210	first_login	2024-03-20 05:03	_NOVALUE_	2024-04-19 16:33:37.564619
1034	0	t	128	traffic_periodic_accounting_daily	39	_NOVALUE_	2024-04-20 03:51:58.290958
1035	0	t	128	traffic_periodic_accounting_daily_limit	50000M	_NOVALUE_	2024-04-20 03:51:58.290958
1036	0	t	128	traffic_periodic_accounting_daily_usage	113648458	_NOVALUE_	2024-04-20 03:51:58.290958
1037	0	t	531	normal_username	_NOVALUE_	moein	2024-04-20 17:00:37.122994
1038	0	t	367	first_login	2024-03-11 00:17	_NOVALUE_	2024-04-21 11:33:43.652876
1039	0	t	367	abs_exp_date	2024-04-17 18:03	_NOVALUE_	2024-04-21 11:34:03.01625
1040	0	t	532	normal_username	_NOVALUE_	ghazal	2024-04-21 14:02:01.567245
1041	0	t	532	abs_exp_date	_NOVALUE_	2024-05-19 14:05	2024-04-21 14:05:44.152086
1042	0	t	52	first_login	2024-02-08 16:31	_NOVALUE_	2024-04-21 14:34:34.441721
1043	0	t	52	abs_exp_date	2024-04-20 17:05	_NOVALUE_	2024-04-21 14:34:53.621305
1044	0	t	254	first_login	2024-03-22 11:55	_NOVALUE_	2024-04-21 14:37:39.417526
1045	0	t	397	first_login	2024-03-12 15:47	_NOVALUE_	2024-04-21 14:44:37.546729
1046	0	t	397	abs_exp_date	2024-04-25 13:52	_NOVALUE_	2024-04-21 14:44:46.830545
1047	0	t	397	traffic_periodic_accounting_daily	44	_NOVALUE_	2024-04-21 14:45:00.1159
1048	0	t	397	traffic_periodic_accounting_daily_limit	65000M	_NOVALUE_	2024-04-21 14:45:00.1159
1049	0	t	397	traffic_periodic_accounting_daily_usage	3374506808	_NOVALUE_	2024-04-21 14:45:00.1159
1050	0	t	397	group	2-Month-70G	1-Month-50G	2024-04-21 14:45:17.816147
1051	0	t	534	normal_username	_NOVALUE_	habibi1	2024-04-21 15:47:06.464458
1052	0	t	534	group	1-Month-100G	1-Month-35G	2024-04-21 16:06:08.891853
1053	0	t	535	normal_username	_NOVALUE_	maleki1	2024-04-21 16:11:32.426442
1054	0	t	536	normal_username	_NOVALUE_	habibi2	2024-04-21 16:14:36.176771
1055	0	t	537	normal_username	_NOVALUE_	mohammadi66	2024-04-22 04:51:53.099719
1056	0	t	113	first_login	2024-02-10 07:47	_NOVALUE_	2024-04-22 04:54:48.313046
1057	0	t	113	group	2-Month-70G	3-Month-150G	2024-04-22 04:55:20.920297
1058	0	t	275	first_login	2024-03-23 03:41	_NOVALUE_	2024-04-22 11:01:07.083625
1059	0	t	441	first_login	2024-03-23 09:40	_NOVALUE_	2024-04-22 13:56:39.468513
1060	0	t	260	first_login	2024-03-23 09:56	_NOVALUE_	2024-04-22 14:02:49.456077
1061	0	t	120	first_login	2024-03-20 06:06	_NOVALUE_	2024-04-22 16:33:17.394811
1063	0	t	442	first_login	2024-03-23 10:46	_NOVALUE_	2024-04-23 05:15:32.614749
1064	0	t	132	first_login	2024-03-24 05:49	_NOVALUE_	2024-04-23 08:34:08.932137
1065	0	t	132	multi_login	3	2	2024-04-23 08:34:45.542673
1066	0	t	394	first_login	2024-03-23 14:13	_NOVALUE_	2024-04-23 13:23:43.620973
1067	0	t	540	normal_username	_NOVALUE_	mehrabi	2024-04-24 05:39:13.00514
1068	0	t	542	normal_username	_NOVALUE_	samira3	2024-04-24 16:46:56.757024
1069	0	t	542	abs_exp_date	_NOVALUE_	2024-10-16 16:47	2024-04-24 16:47:33.324625
1070	0	t	543	normal_username	_NOVALUE_	imani2	2024-04-25 06:39:02.727376
1071	0	t	270	first_login	2024-03-25 07:00	_NOVALUE_	2024-04-25 09:06:26.480112
1072	0	t	179	first_login	2024-02-17 08:00	_NOVALUE_	2024-04-25 09:43:54.952925
1073	0	t	179	traffic_periodic_accounting_daily	68	_NOVALUE_	2024-04-25 09:44:17.434532
1074	0	t	179	traffic_periodic_accounting_daily_limit	120000M	_NOVALUE_	2024-04-25 09:44:17.434532
1075	0	t	179	traffic_periodic_accounting_daily_usage	42342835	_NOVALUE_	2024-04-25 09:44:17.434532
1076	0	t	269	first_login	2024-03-26 06:41	_NOVALUE_	2024-04-25 09:46:42.465278
1077	0	t	179	abs_exp_date	2024-04-25 08:32	_NOVALUE_	2024-04-25 09:56:26.561539
1079	0	t	462	first_login	2024-04-02 04:51	_NOVALUE_	2024-04-26 02:10:11.536256
1080	0	t	447	first_login	2024-03-27 04:10	_NOVALUE_	2024-04-26 05:30:01.101373
1081	0	t	544	normal_username	_NOVALUE_	salimian	2024-04-26 07:56:58.907755
1082	0	t	544	abs_exp_date	_NOVALUE_	2024-07-17 07:57	2024-04-26 07:57:32.905282
1083	0	t	545	normal_username	_NOVALUE_	bama2071	2024-04-26 11:22:31.07957
1084	0	t	546	normal_username	_NOVALUE_	bama2072	2024-04-26 11:22:31.07957
1085	0	t	547	normal_username	_NOVALUE_	bama2073	2024-04-26 11:22:31.07957
1086	0	t	548	normal_username	_NOVALUE_	bama2074	2024-04-26 11:22:31.07957
1087	0	t	549	normal_username	_NOVALUE_	bama2075	2024-04-26 11:22:31.07957
1088	0	t	550	normal_username	_NOVALUE_	bama2076	2024-04-26 11:22:31.07957
1089	0	t	551	normal_username	_NOVALUE_	bama2077	2024-04-26 11:22:31.07957
1090	0	t	552	normal_username	_NOVALUE_	bama2078	2024-04-26 11:22:31.07957
1091	0	t	553	normal_username	_NOVALUE_	bama2079	2024-04-26 11:22:31.07957
1092	0	t	554	normal_username	_NOVALUE_	bama2080	2024-04-26 11:22:31.07957
1093	0	t	556	normal_username	_NOVALUE_	alipoor2	2024-04-26 12:14:31.305101
1094	0	t	557	normal_username	_NOVALUE_	ebi	2024-04-27 05:49:55.418569
1095	0	t	300	first_login	2024-04-02 04:51	_NOVALUE_	2024-04-27 12:25:14.108473
1096	0	t	314	first_login	2024-04-02 04:51	_NOVALUE_	2024-04-27 12:25:35.304567
1097	0	t	279	first_login	2024-03-27 14:43	_NOVALUE_	2024-04-27 12:28:40.441287
1098	0	t	190	first_login	2024-03-27 02:06	_NOVALUE_	2024-04-27 12:34:57.745337
1099	0	t	278	first_login	2024-03-27 12:44	_NOVALUE_	2024-04-27 12:37:51.914299
1100	0	t	280	first_login	2024-03-28 06:11	_NOVALUE_	2024-04-27 13:05:31.202507
1101	0	t	432	first_login	2024-03-19 05:21	_NOVALUE_	2024-04-27 14:33:55.33474
1102	0	t	121	first_login	2024-02-11 15:36	_NOVALUE_	2024-04-27 15:06:15.642786
1103	0	t	121	abs_exp_date	2024-05-06 16:35	_NOVALUE_	2024-04-27 15:06:31.832165
1104	0	t	121	group	3-Month-150G	1-Month-35G	2024-04-27 15:07:59.564731
1105	0	t	558	normal_username	_NOVALUE_	alvani	2024-04-28 01:05:03.78084
1106	0	t	558	abs_exp_date	_NOVALUE_	2024-04-30 01:05	2024-04-28 01:05:19.805624
1107	0	t	375	first_login	2024-03-28 15:10	_NOVALUE_	2024-04-28 12:32:03.654276
1108	0	t	375	group	1-Month-35G	2-Month-70G	2024-04-28 12:32:23.365366
1109	0	t	242	first_login	2024-03-27 11:59	_NOVALUE_	2024-04-28 12:32:58.006099
1110	0	t	286	first_login	2024-03-29 09:17	_NOVALUE_	2024-04-28 14:04:20.001385
1111	0	t	560	normal_username	_NOVALUE_	ghasemi	2024-04-28 14:22:23.892463
1112	0	t	561	normal_username	_NOVALUE_	mohammad91	2024-04-28 14:27:52.380423
1113	0	t	562	normal_username	_NOVALUE_	batool	2024-04-28 15:48:43.738567
1114	0	t	201	first_login	2024-02-19 04:58	_NOVALUE_	2024-04-28 16:57:13.361279
1115	0	t	201	abs_exp_date	2024-04-29 05:47	_NOVALUE_	2024-04-28 16:57:25.952646
1116	0	t	201	traffic_periodic_accounting_daily	70	_NOVALUE_	2024-04-28 16:57:47.583557
1117	0	t	201	traffic_periodic_accounting_daily_limit	90000M	_NOVALUE_	2024-04-28 16:57:47.583557
1118	0	t	201	traffic_periodic_accounting_daily_usage	13228815335	_NOVALUE_	2024-04-28 16:57:47.583557
1119	0	t	563	normal_username	_NOVALUE_	kahari	2024-04-29 04:23:46.002868
1120	0	t	62	first_login	2024-02-08 17:00	_NOVALUE_	2024-04-29 04:48:16.896373
1121	0	t	62	abs_exp_date	2024-04-28 17:59	_NOVALUE_	2024-04-29 04:48:25.601614
1122	0	t	475	first_login	2024-04-05 17:05	_NOVALUE_	2024-04-29 05:54:44.088655
1123	0	t	475	abs_exp_date	2024-04-18 16:14	_NOVALUE_	2024-04-29 05:54:53.064208
1124	0	t	564	normal_username	_NOVALUE_	zhestmezon	2024-04-29 06:30:04.376268
1125	0	t	258	first_login	2024-03-26 05:51	_NOVALUE_	2024-04-29 07:06:11.080967
1126	0	t	112	first_login	2024-02-10 05:28	_NOVALUE_	2024-04-29 07:08:14.896562
1127	0	t	112	abs_exp_date	2024-04-28 06:29	_NOVALUE_	2024-04-29 07:08:25.204698
1128	0	t	252	first_login	2024-03-30 16:37	_NOVALUE_	2024-04-29 16:47:43.759576
1129	0	t	565	normal_username	_NOVALUE_	ansari	2024-04-30 03:28:56.573349
1130	0	t	565	traffic_periodic_accounting_daily	365	365	2024-04-30 03:31:39.385923
1131	0	t	565	traffic_periodic_accounting_daily_limit	600000M	350000M	2024-04-30 03:31:39.385923
1132	0	t	420	first_login	2024-04-17 03:40	_NOVALUE_	2024-04-30 06:18:00.347334
1133	0	t	566	normal_username	_NOVALUE_	mina	2024-04-30 07:59:54.978941
1134	0	t	164	first_login	2024-03-30 12:24	_NOVALUE_	2024-04-30 13:12:09.91487
1135	0	t	568	normal_username	_NOVALUE_	bama2081	2024-04-30 14:19:32.736252
1136	0	t	569	normal_username	_NOVALUE_	bama2082	2024-04-30 14:19:32.736252
1137	0	t	570	normal_username	_NOVALUE_	bama2083	2024-04-30 14:19:32.736252
1138	0	t	571	normal_username	_NOVALUE_	bama2084	2024-04-30 14:19:32.736252
1139	0	t	572	normal_username	_NOVALUE_	bama2085	2024-04-30 14:19:32.736252
1140	0	t	573	normal_username	_NOVALUE_	bama2086	2024-04-30 14:19:32.736252
1141	0	t	574	normal_username	_NOVALUE_	bama2087	2024-04-30 14:19:32.736252
1142	0	t	575	normal_username	_NOVALUE_	bama2088	2024-04-30 14:19:32.736252
1143	0	t	576	normal_username	_NOVALUE_	bama2089	2024-04-30 14:19:32.736252
1144	0	t	577	normal_username	_NOVALUE_	bama2090	2024-04-30 14:19:32.736252
1145	0	t	458	first_login	2024-03-31 12:16	_NOVALUE_	2024-04-30 15:51:43.415102
1146	0	t	579	normal_username	_NOVALUE_	nazanin10	2024-05-01 00:49:32.418637
1147	0	t	558	first_login	2024-04-28 02:36	_NOVALUE_	2024-05-01 11:42:15.6112
1148	0	t	558	abs_exp_date	2024-04-30 01:05	_NOVALUE_	2024-05-01 11:42:27.813095
1149	0	t	558	group	1-Month-10G	1-Month-35G	2024-05-01 11:44:11.192806
1150	0	t	310	first_login	2024-03-31 16:54	_NOVALUE_	2024-05-01 13:00:26.720947
1151	0	t	580	normal_username	_NOVALUE_	hidokht	2024-05-01 14:28:36.069067
1152	0	t	320	first_login	2024-04-01 08:19	_NOVALUE_	2024-05-01 16:32:55.55255
1153	0	t	319	first_login	2024-03-03 00:20	_NOVALUE_	2024-05-01 16:35:48.095549
1154	0	t	287	first_login	2024-04-01 12:26	_NOVALUE_	2024-05-02 04:38:45.186254
1155	0	t	301	first_login	2024-04-02 05:04	_NOVALUE_	2024-05-02 09:03:04.96828
1156	0	t	581	normal_username	_NOVALUE_	bama2091	2024-05-02 09:12:50.851634
1157	0	t	581	multi_login	2	4	2024-05-02 09:14:40.102755
1158	0	t	306	first_login	2024-04-01 18:17	_NOVALUE_	2024-05-02 11:37:25.306454
1159	0	t	315	first_login	2024-04-02 12:50	_NOVALUE_	2024-05-02 15:13:56.711478
1160	0	t	153	first_login	2024-04-03 05:02	_NOVALUE_	2024-05-03 05:40:17.401452
1161	0	t	108	first_login	2024-02-09 14:29	_NOVALUE_	2024-05-03 11:28:27.919516
1162	0	t	322	first_login	2024-04-03 12:23	_NOVALUE_	2024-05-03 11:35:21.067603
1163	0	t	582	normal_username	_NOVALUE_	mostafa110	2024-05-03 13:10:34.366125
1164	0	t	321	first_login	2024-04-05 14:27	_NOVALUE_	2024-05-04 02:46:10.139546
1165	0	t	448	first_login	2024-03-27 08:31	_NOVALUE_	2024-05-04 07:21:02.663669
1166	0	t	448	abs_exp_date	2024-05-05 04:12	_NOVALUE_	2024-05-04 07:21:17.598045
1167	0	t	534	group	1-Month-35G	1-Month-70G	2024-05-04 11:45:20.381978
1168	0	t	523	first_login	2024-04-16 13:32	_NOVALUE_	2024-05-04 15:49:35.756108
1169	0	t	523	abs_exp_date	2024-05-04 13:52	_NOVALUE_	2024-05-04 15:50:04.079336
1170	0	t	316	first_login	2024-04-02 06:01	_NOVALUE_	2024-05-05 01:01:37.582927
1171	0	t	467	first_login	2024-04-04 11:21	_NOVALUE_	2024-05-05 08:22:33.970441
1172	0	t	336	first_login	2024-04-05 01:23	_NOVALUE_	2024-05-05 09:12:14.972892
1173	0	t	313	first_login	2024-04-02 07:27	_NOVALUE_	2024-05-05 10:23:04.986141
1174	0	t	90	first_login	2024-02-08 23:56	_NOVALUE_	2024-05-05 14:33:28.291904
1175	0	t	90	abs_exp_date	2024-05-03 19:38	_NOVALUE_	2024-05-05 14:33:35.63619
1176	0	t	90	traffic_periodic_accounting_daily	85	85	2024-05-05 14:33:47.667399
1177	0	t	90	traffic_periodic_accounting_daily	85	_NOVALUE_	2024-05-05 14:33:54.823876
1178	0	t	90	traffic_periodic_accounting_daily_limit	70000M	_NOVALUE_	2024-05-05 14:33:54.823876
1179	0	t	90	traffic_periodic_accounting_daily_usage	1015616829	_NOVALUE_	2024-05-05 14:33:54.823876
1180	0	t	90	multi_login	2	1	2024-05-05 14:34:14.154002
1181	0	t	436	first_login	2024-03-24 14:03	_NOVALUE_	2024-05-05 14:37:15.7652
1182	0	t	436	group	2-Month-70G	3-Month-150G	2024-05-05 14:37:27.399804
1183	0	t	436	traffic_periodic_accounting_daily	90	90	2024-05-05 14:38:27.408997
1184	0	t	436	traffic_periodic_accounting_daily_limit	150000M	100000M	2024-05-05 14:38:27.408997
1185	0	t	473	first_login	2024-04-05 11:15	_NOVALUE_	2024-05-05 14:48:53.275028
1186	0	t	277	first_login	2024-04-04 03:43	_NOVALUE_	2024-05-05 15:12:42.423406
1187	0	t	276	first_login	2024-04-04 06:31	_NOVALUE_	2024-05-05 15:13:02.736028
1188	0	t	380	first_login	2024-04-05 12:36	_NOVALUE_	2024-05-05 15:17:55.436108
1189	0	t	387	first_login	2024-04-08 12:10	_NOVALUE_	2024-05-05 15:18:39.020805
1190	0	t	583	normal_username	_NOVALUE_	bama2058	2024-05-05 15:20:21.260666
1191	0	t	584	normal_username	_NOVALUE_	khavari	2024-05-05 15:41:22.899681
1192	0	t	472	first_login	2024-04-06 13:14	_NOVALUE_	2024-05-06 05:18:12.704328
1193	0	t	202	first_login	2024-04-03 03:53	_NOVALUE_	2024-05-06 08:30:41.662863
1194	0	t	340	first_login	2024-04-06 07:15	_NOVALUE_	2024-05-06 15:25:07.921223
1195	0	t	348	first_login	2024-04-06 11:34	_NOVALUE_	2024-05-06 15:28:33.505201
1196	0	t	585	normal_username	_NOVALUE_	fereshteh	2024-05-06 15:30:52.637066
1197	0	t	585	abs_exp_date	_NOVALUE_	2024-05-31 15:31	2024-05-06 15:31:21.352977
1198	0	t	89	first_login	2024-02-10 06:40	_NOVALUE_	2024-05-07 03:57:13.265359
1199	0	t	89	abs_exp_date	2024-05-05 19:36	_NOVALUE_	2024-05-07 03:57:51.634455
1200	0	t	345	first_login	2024-04-06 13:55	_NOVALUE_	2024-05-07 04:23:12.446416
1201	0	t	461	first_login	2024-04-01 16:06	_NOVALUE_	2024-05-07 07:00:34.332782
1202	0	t	354	first_login	2024-04-09 07:19	_NOVALUE_	2024-05-07 08:27:07.834846
1203	0	t	353	first_login	2024-04-07 14:24	_NOVALUE_	2024-05-07 15:32:37.761577
1204	0	t	39	first_login	2024-04-07 10:12	_NOVALUE_	2024-05-07 15:33:26.296763
1205	0	t	352	first_login	2024-04-07 08:59	_NOVALUE_	2024-05-07 15:33:55.771383
1206	0	t	586	normal_username	_NOVALUE_	alipoor3	2024-05-08 07:39:32.359275
1207	0	t	536	group	1-Month-35G	1-Month-70G	2024-05-08 14:03:15.922796
1208	0	t	391	first_login	2024-04-09 16:18	_NOVALUE_	2024-05-08 14:42:00.090663
1209	0	t	587	normal_username	_NOVALUE_	akbar6	2024-05-08 15:21:12.678423
1210	0	t	587	abs_exp_date	_NOVALUE_	2024-09-13 15:21	2024-05-08 15:21:25.752508
1211	0	t	248	first_login	2024-02-20 16:33	_NOVALUE_	2024-05-08 15:22:53.564304
1212	0	t	248	abs_exp_date	2024-05-08 17:19	_NOVALUE_	2024-05-08 15:23:01.484975
1213	0	t	24	first_login	2024-02-08 14:07	_NOVALUE_	2024-05-08 15:23:52.039669
1214	0	t	588	normal_username	_NOVALUE_	bama2064	2024-05-08 16:09:27.565753
1215	0	t	399	first_login	2024-04-12 03:57	_NOVALUE_	2024-05-09 01:19:32.928172
1216	0	t	356	first_login	2024-04-09 03:39	_NOVALUE_	2024-05-09 04:46:35.702491
1217	0	t	76	first_login	2024-02-08 17:54	_NOVALUE_	2024-05-09 04:48:54.515093
1218	0	t	589	normal_username	_NOVALUE_	habibi4	2024-05-09 05:38:11.273091
1219	0	t	464	group	1-Month-35G	3-Month-150G	2024-05-09 09:09:02.891035
1220	0	t	464	group	3-Month-150G	2-Month-70G	2024-05-09 09:09:35.562647
1221	0	t	464	first_login	2024-04-02 16:47	_NOVALUE_	2024-05-09 09:09:54.389793
1222	0	t	465	group	1-Month-35G	2-Month-70G	2024-05-09 09:10:15.009797
1223	0	t	465	first_login	2024-04-02 16:51	_NOVALUE_	2024-05-09 09:10:23.489684
1224	0	t	364	first_login	2024-04-09 06:38	_NOVALUE_	2024-05-09 09:37:23.882737
1225	0	t	361	first_login	2024-04-09 08:23	_NOVALUE_	2024-05-09 12:59:59.199726
1228	0	t	504	first_login	2024-04-09 15:44	_NOVALUE_	2024-05-10 09:07:59.531924
1229	0	t	390	first_login	2024-04-09 09:34	_NOVALUE_	2024-05-10 16:51:01.161397
1230	0	t	116	first_login	2024-02-10 11:53	_NOVALUE_	2024-05-11 06:02:06.642375
1234	0	t	590	normal_username	_NOVALUE_	bama2092	2024-05-11 12:55:16.880378
1235	0	t	591	normal_username	_NOVALUE_	bama2093	2024-05-11 12:55:16.880378
1236	0	t	592	normal_username	_NOVALUE_	bama2094	2024-05-11 12:55:16.880378
1237	0	t	593	normal_username	_NOVALUE_	bama2095	2024-05-11 12:55:16.880378
1238	0	t	594	normal_username	_NOVALUE_	bama2096	2024-05-11 12:55:16.880378
1239	0	t	595	normal_username	_NOVALUE_	bama2097	2024-05-11 12:55:16.880378
1240	0	t	596	normal_username	_NOVALUE_	bama2098	2024-05-11 12:55:16.880378
1241	0	t	597	normal_username	_NOVALUE_	bama2099	2024-05-11 12:55:16.880378
1242	0	t	598	normal_username	_NOVALUE_	bama2100	2024-05-11 12:55:16.880378
1243	0	t	599	normal_username	_NOVALUE_	bama2101	2024-05-11 12:55:16.880378
1247	0	t	450	first_login	2024-04-12 17:32	_NOVALUE_	2024-05-12 11:43:03.797617
1250	0	t	528	abs_exp_date	2024-05-11 19:51	_NOVALUE_	2024-05-12 13:58:16.865025
1251	0	t	509	first_login	2024-04-12 17:00	_NOVALUE_	2024-05-13 02:32:50.750851
1253	0	t	401	first_login	2024-03-13 14:47	_NOVALUE_	2024-05-13 05:26:46.748525
1256	0	t	311	abs_exp_date	2024-05-04 16:53	_NOVALUE_	2024-05-13 08:34:49.372583
1257	0	t	311	group	2-Month-70G	1-Month-35G	2024-05-13 08:35:02.658877
1258	0	t	602	normal_username	_NOVALUE_	shekufeh	2024-05-13 15:41:03.593417
1261	0	t	603	normal_username	_NOVALUE_	najafi	2024-05-13 17:03:04.978419
1262	0	t	604	normal_username	_NOVALUE_	harandi	2024-05-13 17:07:47.383852
1263	0	t	335	first_login	2024-04-11 07:16	_NOVALUE_	2024-05-14 01:46:23.275587
1264	0	t	408	first_login	2024-03-14 16:42	_NOVALUE_	2024-05-14 02:15:44.045476
1265	0	t	408	group	2-Month-70G	3-Month-150G	2024-05-14 02:15:54.126348
1266	0	t	512	first_login	2024-04-14 02:42	_NOVALUE_	2024-05-14 06:18:58.518196
1269	0	t	158	first_login	2024-02-14 05:57	_NOVALUE_	2024-05-14 12:42:39.070549
1271	0	t	514	first_login	2024-04-14 13:45	_NOVALUE_	2024-05-14 14:20:51.399464
1272	0	t	46	multi_login	2	1	2024-05-14 16:26:46.192751
1273	0	t	606	normal_username	_NOVALUE_	hossein	2024-05-14 16:28:41.050824
1276	0	t	516	first_login	2024-04-15 02:07	_NOVALUE_	2024-05-15 07:04:53.035923
1282	0	t	607	traffic_periodic_accounting_daily	90	90	2024-05-15 16:27:12.87854
1283	0	t	607	traffic_periodic_accounting_daily_limit	30M	30000M	2024-05-15 16:27:12.87854
1284	0	t	103	first_login	2024-04-15 15:19	_NOVALUE_	2024-05-15 17:29:06.570868
1286	0	t	134	first_login	2024-04-15 17:53	_NOVALUE_	2024-05-16 10:37:35.175607
1290	0	t	428	first_login	2024-04-17 14:15	_NOVALUE_	2024-05-17 04:32:06.254586
1292	0	t	181	first_login	2024-02-17 08:37	_NOVALUE_	2024-05-17 14:32:46.648115
1295	0	t	609	normal_username	_NOVALUE_	saeed	2024-05-17 15:27:37.202972
1296	0	t	429	first_login	2024-04-17 14:23	_NOVALUE_	2024-05-17 17:11:01.229831
1297	0	t	534	first_login	2024-04-22 05:15	_NOVALUE_	2024-05-18 12:46:48.388806
1298	0	t	534	group	1-Month-70G	1-Month-35G	2024-05-18 12:48:03.857149
1299	0	t	610	normal_username	_NOVALUE_	habibi1	2024-05-18 13:33:54.953651
1302	0	t	526	first_login	2024-04-18 09:21	_NOVALUE_	2024-05-18 16:35:42.33153
1303	0	t	526	group	1-Month-35G	3-month-100-G-bama	2024-05-18 16:35:58.117066
1304	0	t	271	first_login	2024-04-26 06:14	_NOVALUE_	2024-05-19 12:45:56.621081
1305	0	t	611	normal_username	_NOVALUE_	javdani	2024-05-19 12:51:44.274301
1308	0	t	67	first_login	2024-02-08 19:03	_NOVALUE_	2024-05-19 13:17:49.05445
1312	0	t	508	abs_exp_date	2024-04-27 16:14	_NOVALUE_	2024-05-19 13:44:02.990504
1315	0	t	532	first_login	2024-04-21 15:02	_NOVALUE_	2024-05-19 14:24:21.30377
1317	0	t	527	first_login	2024-04-18 13:46	_NOVALUE_	2024-05-19 14:42:14.727179
1319	0	t	603	multi_login	2	4	2024-05-20 02:42:15.55267
1337	0	t	187	first_login	2024-02-17 14:16	_NOVALUE_	2024-05-21 12:13:03.880626
1323	0	t	615	normal_username	_NOVALUE_	bama2102	2024-05-20 05:44:50.68122
1324	0	t	616	normal_username	_NOVALUE_	bama2103	2024-05-20 05:44:50.68122
1325	0	t	617	normal_username	_NOVALUE_	bama2104	2024-05-20 05:44:50.68122
1326	0	t	618	normal_username	_NOVALUE_	bama2105	2024-05-20 05:44:50.68122
1327	0	t	619	normal_username	_NOVALUE_	bama2106	2024-05-20 05:44:50.68122
1328	0	t	620	normal_username	_NOVALUE_	bama2107	2024-05-20 05:44:50.68122
1329	0	t	621	normal_username	_NOVALUE_	bama2108	2024-05-20 05:44:50.68122
1330	0	t	622	normal_username	_NOVALUE_	bama2109	2024-05-20 05:44:50.68122
1331	0	t	623	normal_username	_NOVALUE_	bama2110	2024-05-20 05:44:50.68122
1332	0	t	624	normal_username	_NOVALUE_	bama2111	2024-05-20 05:44:50.68122
1333	0	t	209	first_login	2024-04-19 22:13	_NOVALUE_	2024-05-20 08:12:44.608095
1338	0	t	187	group	3-Month-150G	12-Month-600G	2024-05-21 12:13:18.187215
1339	0	t	254	first_login	2024-04-21 14:41	_NOVALUE_	2024-05-21 15:50:04.883917
1341	0	t	275	first_login	2024-04-22 12:58	_NOVALUE_	2024-05-22 14:01:04.293519
1343	0	t	260	first_login	2024-04-22 14:15	_NOVALUE_	2024-05-22 16:22:22.175388
1344	0	t	280	first_login	2024-04-27 13:09	_NOVALUE_	2024-05-23 05:51:17.552681
1347	0	t	257	first_login	2024-02-23 05:55	_NOVALUE_	2024-05-23 14:02:54.391742
1353	0	t	628	normal_username	_NOVALUE_	bama2058	2024-05-24 15:58:47.22121
1355	0	t	132	group	1-Month-50G	2-Month-70G	2024-05-25 03:15:04.690154
1356	0	t	269	first_login	2024-04-25 11:24	_NOVALUE_	2024-05-25 12:09:45.211963
1358	0	t	531	multi_login	1	2	2024-05-25 12:38:40.568609
1360	0	t	355	first_login	2024-03-08 15:20	_NOVALUE_	2024-05-25 13:59:01.580828
1361	0	t	318	first_login	2024-03-02 22:01	_NOVALUE_	2024-05-25 16:17:28.879662
1362	0	t	462	first_login	2024-04-26 03:14	_NOVALUE_	2024-05-26 06:11:13.383106
1366	0	t	203	first_login	2024-02-19 08:18	_NOVALUE_	2024-05-26 08:28:40.072605
1367	0	t	203	group	3-Month-150G	3-month-100-G-bama	2024-05-26 08:29:03.903169
1368	0	t	203	normal_username	abolfazl2	ab2	2024-05-26 08:31:29.116201
1369	0	t	203	group	3-month-100-G-bama	6-Month-300G	2024-05-26 08:31:53.194367
1370	0	t	536	first_login	2024-04-22 00:44	_NOVALUE_	2024-05-26 14:21:50.737348
1226	0	t	481	first_login	2024-04-09 06:45	_NOVALUE_	2024-05-09 16:02:31.065852
1231	0	t	119	first_login	2024-04-11 12:57	_NOVALUE_	2024-05-11 07:36:15.168371
1232	0	t	118	first_login	2024-02-10 11:56	_NOVALUE_	2024-05-11 08:58:01.181862
1233	0	t	84	first_login	2024-04-10 10:03	_NOVALUE_	2024-05-11 12:24:42.261166
1244	0	t	601	normal_username	_NOVALUE_	maral2	2024-05-11 13:03:05.460397
1248	0	t	145	first_login	2024-02-12 05:42	_NOVALUE_	2024-05-12 11:45:59.952458
1254	0	t	401	group	2-Month-70G	3-Month-150G	2024-05-13 05:27:02.226266
1259	0	t	602	abs_exp_date	_NOVALUE_	2024-05-31 15:42	2024-05-13 15:42:24.547708
1260	0	t	480	first_login	2024-04-18 02:24	_NOVALUE_	2024-05-13 15:43:22.900594
1267	0	t	409	first_login	2024-04-14 07:36	_NOVALUE_	2024-05-14 08:05:25.160979
1270	0	t	605	normal_username	_NOVALUE_	mirzaei	2024-05-14 14:09:02.324901
1274	0	t	349	first_login	2024-04-09 08:34	_NOVALUE_	2024-05-15 01:27:29.323018
1275	0	t	350	first_login	2024-04-14 06:56	_NOVALUE_	2024-05-15 01:28:02.804182
1277	0	t	400	first_login	2024-04-15 07:17	_NOVALUE_	2024-05-15 15:08:31.189583
1279	0	t	607	normal_username	_NOVALUE_	ayousefi2	2024-05-15 16:26:08.097718
1280	0	t	607	traffic_periodic_accounting_daily	90	90	2024-05-15 16:26:56.065346
1281	0	t	607	traffic_periodic_accounting_daily_limit	150000M	30M	2024-05-15 16:26:56.065346
1285	0	t	171	first_login	2024-04-15 17:19	_NOVALUE_	2024-05-15 19:04:06.252018
1287	0	t	198	first_login	2024-02-18 17:48	_NOVALUE_	2024-05-16 14:00:58.19805
1288	0	t	198	abs_exp_date	2024-05-15 18:01	_NOVALUE_	2024-05-16 14:01:07.119918
1291	0	t	522	first_login	2024-04-17 03:01	_NOVALUE_	2024-05-17 07:45:48.488919
1300	0	t	413	first_login	2024-04-17 05:18	_NOVALUE_	2024-05-18 14:59:46.207422
1306	0	t	430	first_login	2024-04-19 03:27	_NOVALUE_	2024-05-19 12:54:54.448078
1313	0	t	508	group	1-Month-35G	1-Month-20G	2024-05-19 13:44:46.681279
1314	0	t	612	normal_username	_NOVALUE_	roodaki	2024-05-19 14:22:33.998462
1316	0	t	532	abs_exp_date	2024-05-19 14:05	_NOVALUE_	2024-05-19 14:24:28.480813
1340	0	t	627	normal_username	_NOVALUE_	aliasadi	2024-05-21 15:54:38.95596
1334	0	t	210	first_login	2024-04-19 22:53	_NOVALUE_	2024-05-20 08:13:05.4343
1335	0	t	282	first_login	2024-02-26 13:22	_NOVALUE_	2024-05-20 12:15:59.09425
1336	0	t	282	abs_exp_date	2024-05-19 14:19	_NOVALUE_	2024-05-20 12:16:09.651452
1342	0	t	441	first_login	2024-04-22 13:58	_NOVALUE_	2024-05-22 15:45:40.255119
1345	0	t	176	lock	_NOVALUE_		2024-05-23 07:15:48.73275
1350	0	t	531	multi_login	2	1	2024-05-23 14:06:10.659741
1351	0	t	394	first_login	2024-04-23 13:25	_NOVALUE_	2024-05-23 14:17:05.659459
1354	0	t	132	first_login	2024-04-23 08:57	_NOVALUE_	2024-05-25 03:14:54.957341
1357	0	t	269	group	1-Month-35G	3-Month-150G	2024-05-25 12:10:32.222995
1363	0	t	270	first_login	2024-04-25 09:22	_NOVALUE_	2024-05-26 06:12:15.551573
1371	0	t	536	group	1-Month-70G	1-Month-50G	2024-05-26 14:22:21.148399
1372	0	t	630	normal_username	_NOVALUE_	habibi2	2024-05-26 14:23:28.913243
1385	0	t	283	first_login	2024-02-26 15:25	_NOVALUE_	2024-05-27 06:00:36.294417
1387	0	t	513	first_login	2024-04-14 10:04	_NOVALUE_	2024-05-27 13:39:26.457406
1388	0	t	281	first_login	2024-02-26 13:16	_NOVALUE_	2024-05-27 13:53:22.847613
1390	0	t	646	normal_username	_NOVALUE_	ghadimi	2024-05-27 16:32:41.687906
1394	0	t	279	first_login	2024-04-27 13:20	_NOVALUE_	2024-05-28 02:02:08.397998
1395	0	t	314	first_login	2024-04-27 12:40	_NOVALUE_	2024-05-28 06:07:02.530178
1401	0	t	336	first_login	2024-05-05 09:17	_NOVALUE_	2024-05-28 12:00:52.674999
1402	0	t	561	first_login	2024-04-28 14:51	_NOVALUE_	2024-05-28 16:23:05.285822
1404	0	t	121	first_login	2024-04-28 05:41	_NOVALUE_	2024-05-29 05:47:14.715552
1227	0	t	481	group	1-Month-35G	3-month-100-G-bama	2024-05-09 16:02:47.435992
1245	0	t	477	first_login	2024-04-07 15:53	_NOVALUE_	2024-05-11 14:44:02.76867
1246	0	t	393	first_login	2024-04-11 12:23	_NOVALUE_	2024-05-11 14:56:35.198984
1249	0	t	528	first_login	2024-04-20 18:11	_NOVALUE_	2024-05-12 13:58:06.252552
1252	0	t	509	group	1-Month-50G	3-Month-150G	2024-05-13 02:33:45.067273
1255	0	t	311	first_login	2024-04-01 15:09	_NOVALUE_	2024-05-13 08:34:37.192473
1268	0	t	120	first_login	2024-04-22 16:33	_NOVALUE_	2024-05-14 08:06:14.167079
1278	0	t	402	first_login	2024-04-14 16:32	_NOVALUE_	2024-05-15 15:08:57.779974
1289	0	t	200	first_login	2024-04-16 12:55	_NOVALUE_	2024-05-16 14:04:04.879327
1293	0	t	423	first_login	2024-04-17 08:15	_NOVALUE_	2024-05-17 14:37:39.084205
1294	0	t	595	group	1-Month-20G	3-month-100-G-bama	2024-05-17 14:50:53.492576
1301	0	t	419	first_login	2024-04-18 11:44	_NOVALUE_	2024-05-18 15:46:15.605242
1307	0	t	430	group	1-Month-35G	2-Month-70G	2024-05-19 12:55:15.290057
1309	0	t	67	abs_exp_date	2024-05-18 18:12	_NOVALUE_	2024-05-19 13:18:02.241488
1310	0	t	67	group	6-Month-300G	3-Month-150G	2024-05-19 13:18:18.233388
1311	0	t	508	first_login	2024-04-13 11:19	_NOVALUE_	2024-05-19 13:43:45.97433
1318	0	t	613	normal_username	_NOVALUE_	m41	2024-05-19 15:19:53.162773
1320	0	t	208	first_login	2024-04-19 16:50	_NOVALUE_	2024-05-20 02:56:07.437297
1346	0	t	442	first_login	2024-04-23 05:39	_NOVALUE_	2024-05-23 13:22:01.728722
1348	0	t	531	first_login	2024-04-20 19:48	_NOVALUE_	2024-05-23 14:03:43.658649
1349	0	t	531	group	1-Month-100G	3-Month-150G	2024-05-23 14:03:59.222631
1352	0	t	176	lock		_NOVALUE_	2024-05-23 17:34:34.485604
1359	0	t	531	multi_login	2	_NOVALUE_	2024-05-25 12:38:49.666972
1364	0	t	629	normal_username	_NOVALUE_	makki1	2024-05-26 06:41:00.7785
1365	0	t	274	first_login	2024-02-25 23:34	_NOVALUE_	2024-05-26 06:43:19.533888
1373	0	t	447	first_login	2024-04-26 05:30	_NOVALUE_	2024-05-26 16:53:05.532862
1374	0	t	631	normal_username	_NOVALUE_	bama2112	2024-05-26 17:24:07.16982
1375	0	t	632	normal_username	_NOVALUE_	bama2113	2024-05-26 17:24:07.16982
1376	0	t	633	normal_username	_NOVALUE_	bama2114	2024-05-26 17:24:07.16982
1377	0	t	634	normal_username	_NOVALUE_	bama2115	2024-05-26 17:24:07.16982
1378	0	t	635	normal_username	_NOVALUE_	bama2116	2024-05-26 17:24:07.16982
1379	0	t	636	normal_username	_NOVALUE_	bama2117	2024-05-26 17:24:07.16982
1380	0	t	637	normal_username	_NOVALUE_	bama2118	2024-05-26 17:24:07.16982
1381	0	t	638	normal_username	_NOVALUE_	bama2119	2024-05-26 17:24:07.16982
1382	0	t	639	normal_username	_NOVALUE_	bama2120	2024-05-26 17:24:07.16982
1383	0	t	640	normal_username	_NOVALUE_	bama2121	2024-05-26 17:24:07.16982
1384	0	t	644	normal_username	_NOVALUE_	elham1	2024-05-26 17:29:15.774853
1386	0	t	645	normal_username	_NOVALUE_	mirzayi	2024-05-27 10:20:09.153366
1389	0	t	307	first_login	2024-03-01 03:45	_NOVALUE_	2024-05-27 13:54:45.860951
1391	0	t	646	abs_exp_date	_NOVALUE_	2024-05-30 16:33	2024-05-27 16:33:00.279251
1392	0	t	647	normal_username	_NOVALUE_	fatemeh1	2024-05-27 16:42:57.800845
1393	0	t	648	normal_username	_NOVALUE_	fatemeh2	2024-05-27 16:44:05.731647
1396	0	t	300	first_login	2024-04-27 15:23	_NOVALUE_	2024-05-28 06:07:18.529408
1397	0	t	398	lock	_NOVALUE_		2024-05-28 08:08:05.826631
1398	0	t	190	first_login	2024-04-27 23:35	_NOVALUE_	2024-05-28 09:34:31.691131
1399	0	t	278	first_login	2024-04-27 12:56	_NOVALUE_	2024-05-28 09:34:53.986807
1400	0	t	164	first_login	2024-04-30 13:16	_NOVALUE_	2024-05-28 09:59:33.437227
1403	0	t	649	normal_username	_NOVALUE_	tdmsm	2024-05-29 01:51:12.588366
1405	0	t	650	normal_username	_NOVALUE_	melika	2024-05-29 05:52:19.249249
\.


--
-- Name: user_audit_log_user_audit_log_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('user_audit_log_user_audit_log_seq', 1405, true);


--
-- Data for Name: user_messages; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY user_messages (message_id, user_id, message_text, post_date) FROM stdin;
\.


--
-- Name: user_messages_message_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('user_messages_message_id', 1, false);


--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY users (user_id, owner_id, credit, group_id, creation_date) FROM stdin;
379	0	1.00	3	2024-03-10 18:09:50.871667
628	0	1.00	3	2024-05-24 15:58:23.66142
3	0	1.00	2	2024-02-08 12:46:42.473675
461	0	1.00	4	2024-04-01 16:05:13.152237
505	0	1.00	8	2024-04-10 11:01:23.42178
357	0	1.00	8	2024-03-09 03:42:54.804493
189	0	1.00	10	2024-02-18 07:15:14.617107
286	0	1.00	3	2024-02-28 06:52:53.252106
415	0	1.00	4	2024-03-16 13:09:11.027331
270	0	1.00	4	2024-02-25 13:51:14.030708
101	0	1.00	3	2024-02-09 02:51:59.513377
114	0	1.00	7	2024-02-10 09:24:13.0335
353	0	1.00	3	2024-03-08 06:59:47.820932
120	0	1.00	5	2024-02-11 08:00:32.519296
180	0	1.00	8	2024-02-17 08:25:55.911269
126	0	1.00	8	2024-02-12 01:56:19.835
207	0	1.00	8	2024-02-19 15:10:43.417985
91	0	1.00	7	2024-02-08 18:39:44.616953
476	0	1.00	12	2024-04-06 17:06:11.890976
361	0	1.00	3	2024-03-10 06:46:26.929817
557	0	1.00	10	2024-04-27 05:49:44.635441
535	0	1.00	3	2024-04-21 16:11:14.451339
390	0	1.00	3	2024-03-11 15:18:32.690718
649	0	1.00	2	2024-05-29 01:50:53.866818
527	0	1.00	3	2024-04-18 13:45:50.499774
311	0	1.00	3	2024-03-01 09:14:08.362988
435	0	1.00	7	2024-03-19 13:28:52.634064
481	0	1.00	14	2024-04-09 06:34:31.818438
341	0	1.00	8	2024-03-06 10:57:25.438606
508	0	1.00	2	2024-04-11 16:13:14.925558
65	0	1.00	7	2024-02-08 17:07:57.908943
179	0	1.00	8	2024-02-17 07:30:40.579232
204	0	1.00	1	2024-02-19 09:31:12.866335
300	0	1.00	3	2024-02-29 03:58:59.698787
30	0	1.00	3	2024-02-08 14:17:27.607655
127	0	1.00	10	2024-02-12 02:00:32.93574
104	0	1.00	3	2024-02-09 05:31:52.64075
517	0	1.00	8	2024-04-15 13:20:03.724124
469	0	1.00	9	2024-04-04 07:42:06.294876
324	0	1.00	3	2024-03-05 05:00:57.535553
45	0	1.00	13	2024-02-08 15:23:09.604866
274	0	1.00	4	2024-02-25 15:23:52.915951
89	0	1.00	8	2024-02-08 18:35:56.313145
367	0	1.00	7	2024-03-10 18:02:47.209079
359	0	1.00	4	2024-03-09 15:09:39.049045
50	0	1.00	12	2024-02-08 15:48:18.314194
113	0	1.00	8	2024-02-10 07:46:54.507898
463	0	1.00	3	2024-04-02 07:19:00.828746
160	0	1.00	2	2024-02-14 14:56:36.209591
445	0	1.00	8	2024-03-25 05:06:25.06298
351	0	1.00	8	2024-03-07 06:05:50.499192
208	0	1.00	4	2024-02-19 15:40:45.72095
105	0	1.00	8	2024-02-09 06:03:08.126403
522	0	1.00	3	2024-04-15 16:39:42.958322
364	0	1.00	5	2024-03-10 17:01:01.067054
540	0	1.00	3	2024-04-24 05:38:39.208176
585	0	1.00	3	2024-05-06 15:30:33.247072
559	0	1.00	6	2024-04-28 14:21:55.697691
443	0	1.00	3	2024-03-24 10:47:22.997643
449	0	1.00	3	2024-03-27 04:17:48.959583
36	0	1.00	3	2024-02-08 14:39:11.269543
46	0	1.00	13	2024-02-08 15:25:30.451904
304	0	1.00	5	2024-02-29 08:00:55.249679
340	0	1.00	4	2024-03-06 08:57:14.547105
123	0	1.00	5	2024-02-12 01:39:50.503975
418	0	1.00	3	2024-03-16 15:17:06.350084
107	0	1.00	3	2024-02-09 06:07:22.20394
134	0	1.00	3	2024-02-12 05:10:38.583048
202	0	1.00	1	2024-02-19 07:24:30.702266
558	0	1.00	3	2024-04-28 01:04:46.611648
607	0	1.00	8	2024-05-15 16:25:53.870628
316	0	1.00	3	2024-03-02 13:48:46.784526
209	0	1.00	3	2024-02-19 15:43:10.344407
452	0	1.00	3	2024-03-28 19:04:57.656197
582	0	1.00	3	2024-05-03 13:09:50.49619
162	0	1.00	8	2024-02-15 02:18:17.996582
118	0	1.00	8	2024-02-10 11:55:08.912966
462	0	1.00	3	2024-04-02 04:38:48.612309
512	0	1.00	3	2024-04-14 02:18:54.603106
258	0	1.00	4	2024-02-23 04:40:14.241468
513	0	1.00	4	2024-04-14 06:14:36.488609
276	0	1.00	3	2024-02-26 00:57:22.935463
392	0	1.00	2	2024-03-12 01:02:53.99307
47	0	1.00	13	2024-02-08 15:26:30.80363
301	0	1.00	3	2024-02-29 04:01:13.512525
414	0	1.00	5	2024-03-15 16:24:34.072754
177	0	1.00	4	2024-02-17 04:13:16.480501
475	0	1.00	3	2024-04-05 16:14:12.236169
313	0	1.00	4	2024-03-02 05:32:31.102492
112	0	1.00	8	2024-02-10 05:24:40.025935
210	0	1.00	3	2024-02-19 15:43:51.479777
629	0	1.00	7	2024-05-26 06:40:48.247527
537	0	1.00	10	2024-04-22 04:51:39.792328
543	0	1.00	6	2024-04-25 06:38:13.020286
70	0	1.00	7	2024-02-08 17:31:38.10798
116	0	1.00	8	2024-02-10 11:52:17.13621
306	0	1.00	3	2024-02-29 14:29:18.785154
130	0	1.00	7	2024-02-12 03:52:21.613128
124	0	1.00	4	2024-02-12 01:42:06.881916
457	0	1.00	3	2024-03-31 04:05:47.59491
358	0	1.00	8	2024-03-09 12:32:34.503039
494	0	10.00	3	2024-04-09 07:00:53.625043
128	0	1.00	8	2024-02-12 03:19:40.392797
284	0	1.00	4	2024-02-27 13:25:56.857627
52	0	1.00	8	2024-02-08 16:04:56.818468
92	0	1.00	3	2024-02-08 18:43:41.923139
394	0	1.00	4	2024-03-12 03:20:46.336617
132	0	1.00	7	2024-02-12 04:03:20.126794
563	0	1.00	8	2024-04-29 04:23:33.693948
136	0	1.00	3	2024-02-12 05:10:38.583048
441	0	1.00	4	2024-03-23 09:31:31.763565
6	0	1.00	8	2024-02-08 13:05:46.990989
121	0	1.00	3	2024-02-11 15:35:15.531548
93	0	1.00	8	2024-02-08 18:45:31.380583
460	0	1.00	3	2024-03-31 16:49:38.17245
146	0	1.00	2	2024-02-12 12:45:43.6846
459	0	1.00	3	2024-03-31 16:49:20.122651
608	0	1.00	11	2024-05-17 15:27:07.614163
539	0	1.00	4	2024-04-24 05:38:31.953369
111	0	1.00	3	2024-02-10 05:05:09.454029
444	0	1.00	3	2024-03-24 10:47:23.200898
122	0	1.00	2	2024-02-11 18:06:16.993356
346	0	1.00	4	2024-03-06 23:54:12.356643
135	0	1.00	3	2024-02-12 05:10:38.583048
150	0	1.00	10	2024-02-13 04:53:25.324289
467	0	1.00	4	2024-04-03 17:56:30.892787
332	0	1.00	3	2024-03-05 05:00:57.535553
212	0	1.00	4	2024-02-19 17:26:09.168813
330	0	1.00	3	2024-03-05 05:00:57.535553
586	0	1.00	8	2024-05-08 07:39:01.979045
277	0	1.00	3	2024-02-26 00:58:52.265105
302	0	1.00	4	2024-02-29 07:48:51.407859
243	0	1.00	3	2024-02-20 12:15:45.476432
336	0	1.00	4	2024-03-05 12:41:56.43579
137	0	1.00	3	2024-02-12 05:10:38.583048
531	0	1.00	8	2024-04-20 16:59:52.177614
412	0	1.00	10	2024-03-15 08:25:06.329371
241	0	1.00	3	2024-02-20 12:15:45.476432
431	0	1.00	3	2024-03-18 17:03:39.162335
421	0	1.00	12	2024-03-17 13:36:05.707956
139	0	1.00	3	2024-02-12 05:10:38.583048
326	0	1.00	3	2024-03-05 05:00:57.535553
477	0	1.00	4	2024-04-07 15:14:39.346483
393	0	1.00	2	2024-03-12 01:02:59.352974
350	0	1.00	4	2024-03-07 03:37:08.911645
259	0	1.00	6	2024-02-23 04:48:04.641016
61	0	1.00	6	2024-02-08 16:46:55.979783
615	0	1.00	2	2024-05-20 05:44:09.850926
470	0	1.00	4	2024-04-04 08:01:22.584124
238	0	1.00	3	2024-02-20 12:15:45.476432
213	0	1.00	10	2024-02-20 02:17:31.685205
442	0	1.00	3	2024-03-23 09:42:38.762101
331	0	1.00	3	2024-03-05 05:00:57.535553
560	0	1.00	3	2024-04-28 14:22:06.016681
176	0	1.00	8	2024-02-17 00:50:00.0375
438	0	1.00	13	2024-03-19 15:15:38.199182
145	0	1.00	8	2024-02-12 05:39:30.63768
190	0	1.00	4	2024-02-18 07:54:21.737729
257	0	1.00	8	2024-02-23 03:10:43.960777
75	0	1.00	8	2024-02-08 17:46:38.592854
108	0	1.00	8	2024-02-09 11:18:25.778687
289	0	1.00	3	2024-02-28 16:32:12.983881
354	0	1.00	4	2024-03-08 14:59:41.102641
184	0	1.00	3	2024-02-17 08:40:50.406759
96	0	1.00	2	2024-02-08 18:57:08.136535
288	0	1.00	13	2024-02-28 16:23:23.939964
397	0	1.00	4	2024-03-12 13:52:17.807229
322	0	1.00	4	2024-03-04 04:32:17.81503
244	0	1.00	3	2024-02-20 12:15:45.476432
404	0	1.00	8	2024-03-13 16:49:21.08036
349	0	1.00	4	2024-03-07 03:35:44.379637
616	0	1.00	2	2024-05-20 05:44:09.850926
151	0	1.00	7	2024-02-13 13:33:20.004034
255	0	1.00	3	2024-02-22 10:35:29.059131
83	0	1.00	3	2024-02-08 18:18:01.934431
247	0	1.00	7	2024-02-20 15:40:24.510284
360	0	1.00	3	2024-03-10 03:00:38.277781
97	0	1.00	2	2024-02-08 18:58:18.484352
44	0	1.00	13	2024-02-08 15:20:53.029425
250	0	1.00	4	2024-02-21 16:26:12.03428
605	0	1.00	3	2024-05-14 14:08:50.866259
589	0	1.00	3	2024-05-09 05:17:39.810573
240	0	1.00	3	2024-02-20 12:15:45.476432
272	0	1.00	8	2024-02-25 14:33:15.029855
68	0	1.00	5	2024-02-08 17:15:18.932373
328	0	1.00	3	2024-03-05 05:00:57.535553
115	0	1.00	3	2024-02-10 10:32:50.2415
590	0	1.00	2	2024-05-11 12:54:25.862361
297	0	1.00	3	2024-02-28 16:32:12.983881
320	0	1.00	3	2024-03-03 02:38:29.471585
440	0	1.00	8	2024-03-22 13:34:59.835774
298	0	1.00	3	2024-02-28 16:32:12.983881
84	0	1.00	3	2024-02-08 18:20:08.588818
584	0	1.00	6	2024-05-05 15:40:47.344853
478	0	1.00	4	2024-04-08 16:23:06.641348
7	0	1.00	2	2024-02-08 13:15:42.117472
183	0	1.00	8	2024-02-17 08:36:54.797731
303	0	1.00	4	2024-02-29 07:54:20.601197
325	0	1.00	3	2024-03-05 05:00:57.535553
591	0	1.00	2	2024-05-11 12:54:25.862361
355	0	1.00	3	2024-03-08 15:18:35.931753
143	0	1.00	3	2024-02-12 05:10:38.583048
427	0	1.00	8	2024-03-17 17:10:07.443731
147	0	1.00	12	2024-02-12 12:55:31.500876
119	0	1.00	4	2024-02-11 05:20:26.037277
338	0	1.00	3	2024-03-05 14:50:16.305911
195	0	1.00	8	2024-02-18 14:24:08.873741
236	0	1.00	14	2024-02-20 12:15:45.476432
59	0	1.00	8	2024-02-08 16:38:23.469719
293	0	1.00	3	2024-02-28 16:32:12.983881
453	0	1.00	1	2024-03-29 06:50:30.091866
242	0	1.00	3	2024-02-20 12:15:45.476432
312	0	1.00	10	2024-03-01 13:42:21.029527
296	0	1.00	3	2024-02-28 16:32:12.983881
329	0	1.00	3	2024-03-05 05:00:57.535553
74	0	1.00	2	2024-02-08 17:44:11.819471
403	0	1.00	13	2024-03-13 16:35:44.526289
479	0	1.00	3	2024-04-08 17:34:12.523864
413	0	1.00	4	2024-03-15 16:01:31.498116
87	0	1.00	12	2024-02-08 18:31:10.943736
612	0	1.00	3	2024-05-19 14:21:57.559899
602	0	1.00	3	2024-05-13 15:39:41.913433
275	0	1.00	3	2024-02-26 00:54:23.352068
31	0	1.00	3	2024-02-08 14:20:37.221001
268	0	1.00	7	2024-02-25 12:05:35.894948
63	0	1.00	3	2024-02-08 17:01:25.643002
362	0	1.00	7	2024-03-10 13:28:14.529517
446	0	1.00	8	2024-03-25 06:05:51.800033
295	0	1.00	3	2024-02-28 16:32:12.983881
290	0	1.00	3	2024-02-28 16:32:12.983881
235	0	1.00	3	2024-02-20 12:15:45.476432
630	0	1.00	4	2024-05-26 14:23:08.777793
261	0	1.00	3	2024-02-24 07:15:05.524345
425	0	1.00	3	2024-03-17 16:25:32.291984
185	0	1.00	4	2024-02-17 13:16:46.580686
239	0	1.00	3	2024-02-20 12:15:45.476432
422	0	1.00	12	2024-03-17 13:36:34.928339
291	0	1.00	3	2024-02-28 16:32:12.983881
285	0	1.00	4	2024-02-27 13:57:22.075902
365	0	1.00	8	2024-03-10 17:20:31.220807
294	0	1.00	3	2024-02-28 16:32:12.983881
141	0	1.00	3	2024-02-12 05:10:38.583048
237	0	1.00	3	2024-02-20 12:15:45.476432
292	0	1.00	3	2024-02-28 16:32:12.983881
203	0	1.00	10	2024-02-19 08:17:00.453193
337	0	1.00	3	2024-03-05 14:35:03.759314
327	0	1.00	3	2024-03-05 05:00:57.535553
518	0	1.00	8	2024-04-15 13:20:08.780559
164	0	1.00	3	2024-02-15 04:26:18.75731
333	0	1.00	3	2024-03-05 05:00:57.535553
507	0	1.00	3	2024-04-11 16:10:37.218422
561	0	1.00	3	2024-04-28 14:25:36.105633
428	0	1.00	3	2024-03-18 05:19:56.299288
495	0	10.00	3	2024-04-09 07:00:53.625043
263	0	1.00	4	2024-02-24 15:54:57.938705
480	0	1.00	2	2024-04-09 02:07:55.383622
408	0	1.00	8	2024-03-14 14:41:13.351149
381	0	1.00	3	2024-03-10 18:09:50.871667
198	0	1.00	8	2024-02-18 17:00:52.740738
200	0	1.00	3	2024-02-19 04:43:12.825648
1	0	1.00	13	2024-02-08 12:07:25.485885
436	0	1.00	8	2024-03-19 13:28:53.715318
90	0	1.00	8	2024-02-08 18:37:48.500696
528	0	1.00	3	2024-04-18 19:50:13.045101
391	0	1.00	5	2024-03-11 15:28:25.76632
352	0	1.00	4	2024-03-08 02:38:30.534633
410	0	1.00	13	2024-03-15 05:41:12.099052
516	0	1.00	3	2024-04-14 14:54:33.223839
260	0	1.00	3	2024-02-23 15:46:10.216662
269	0	1.00	8	2024-02-25 12:58:31.423827
370	0	1.00	3	2024-03-10 18:05:12.704752
645	0	1.00	8	2024-05-27 10:19:50.70976
650	0	1.00	8	2024-05-29 05:51:33.245409
500	0	10.00	3	2024-04-09 07:00:53.625043
197	0	1.00	10	2024-02-18 16:58:53.635175
24	0	1.00	8	2024-02-08 13:58:39.325223
504	0	1.00	3	2024-04-09 12:42:10.101029
248	0	1.00	8	2024-02-20 16:18:44.569364
525	0	1.00	3	2024-04-17 17:10:51.901291
407	0	1.00	8	2024-03-14 14:28:27.701138
383	0	1.00	3	2024-03-10 18:09:50.871667
366	0	1.00	8	2024-03-10 17:20:31.668703
587	0	1.00	10	2024-05-08 15:20:58.46898
380	0	1.00	3	2024-03-10 18:09:50.871667
187	0	1.00	12	2024-02-17 14:08:07.235222
411	0	1.00	8	2024-03-15 06:23:10.365107
374	0	1.00	7	2024-03-10 18:05:12.704752
201	0	1.00	8	2024-02-19 04:46:23.112115
278	0	1.00	3	2024-02-26 00:59:59.202105
617	0	1.00	2	2024-05-20 05:44:09.850926
538	0	1.00	11	2024-04-23 05:07:13.279648
501	0	10.00	3	2024-04-09 07:00:53.625043
399	0	1.00	3	2024-03-12 16:47:06.598462
167	0	1.00	8	2024-02-15 16:33:56.712177
386	0	1.00	3	2024-03-10 18:09:50.871667
521	0	1.00	3	2024-04-15 16:19:40.347876
502	0	10.00	3	2024-04-09 07:00:53.625043
493	0	10.00	3	2024-04-09 07:00:53.625043
368	0	1.00	3	2024-03-10 18:05:12.704752
464	0	1.00	7	2024-04-02 16:43:26.073768
371	0	1.00	3	2024-03-10 18:05:12.704752
430	0	1.00	7	2024-03-18 16:55:14.533163
396	0	1.00	2	2024-03-12 13:42:31.042079
556	0	1.00	4	2024-04-26 12:14:20.830347
447	0	1.00	4	2024-03-26 04:37:51.178187
282	0	1.00	8	2024-02-26 13:18:49.148396
606	0	1.00	8	2024-05-14 16:28:25.669461
40	0	1.00	13	2024-02-08 15:06:44.825837
279	0	1.00	5	2024-02-26 05:03:51.564189
419	0	1.00	4	2024-03-16 16:31:20.353758
627	0	1.00	2	2024-05-21 15:54:12.592719
339	0	1.00	3	2024-03-05 15:32:42.105301
473	0	1.00	3	2024-04-05 10:04:57.36128
603	0	1.00	4	2024-05-13 17:02:42.942628
604	0	1.00	4	2024-05-13 17:07:36.671514
646	0	1.00	1	2024-05-27 16:32:25.545891
318	0	1.00	8	2024-03-02 15:34:24.761574
402	0	1.00	3	2024-03-13 16:19:36.779179
526	0	1.00	14	2024-04-18 08:32:17.573216
465	0	1.00	7	2024-04-02 16:45:16.92598
468	0	1.00	8	2024-04-04 02:48:14.295831
417	0	1.00	3	2024-03-16 15:14:37.601633
514	0	1.00	4	2024-04-14 13:40:48.116792
423	0	1.00	3	2024-03-17 16:05:00.911528
373	0	1.00	3	2024-03-10 18:05:12.704752
401	0	1.00	8	2024-03-13 14:41:22.634767
458	0	1.00	4	2024-03-31 12:15:53.332324
409	0	1.00	4	2024-03-14 19:06:10.954127
319	0	1.00	7	2024-03-02 15:39:27.38323
426	0	1.00	4	2024-03-17 17:09:59.224768
406	0	1.00	10	2024-03-14 14:14:19.581121
5	0	1.00	8	2024-02-08 13:00:20.369133
142	0	1.00	14	2024-02-12 05:10:38.583048
158	0	1.00	8	2024-02-14 05:43:59.313749
305	0	1.00	9	2024-02-29 13:21:05.629605
262	0	1.00	10	2024-02-24 10:27:25.933415
450	0	1.00	3	2024-03-27 04:18:19.927976
448	0	1.00	7	2024-03-27 04:00:59.436791
252	0	1.00	5	2024-02-22 04:33:19.86013
643	0	1.00	4	2024-05-26 17:28:55.894104
321	0	1.00	3	2024-03-03 14:31:44.362726
369	0	1.00	3	2024-03-10 18:05:12.704752
580	0	1.00	13	2024-05-01 14:27:35.799164
592	0	1.00	2	2024-05-11 12:54:25.862361
498	0	10.00	3	2024-04-09 07:00:53.625043
544	0	1.00	8	2024-04-26 07:56:34.975717
613	0	1.00	14	2024-05-19 15:18:50.776592
76	0	1.00	9	2024-02-08 17:51:23.196207
254	0	1.00	4	2024-02-22 07:50:14.272811
317	0	1.00	12	2024-03-02 15:16:20.637222
77	0	1.00	10	2024-02-08 17:53:09.803565
375	0	1.00	7	2024-03-10 18:05:12.704752
433	0	1.00	8	2024-03-19 12:38:08.80833
314	0	1.00	4	2024-03-02 05:33:59.756135
509	0	1.00	8	2024-04-12 14:39:45.721084
372	0	1.00	3	2024-03-10 18:05:12.704752
420	0	1.00	2	2024-03-17 10:34:56.719979
499	0	10.00	3	2024-04-09 07:00:53.625043
388	0	1.00	3	2024-03-10 18:09:50.871667
562	0	1.00	9	2024-04-28 15:48:19.740941
154	0	1.00	8	2024-02-13 17:22:13.902337
345	0	1.00	3	2024-03-06 23:53:40.38729
287	0	1.00	4	2024-02-28 07:41:06.275061
171	0	1.00	4	2024-02-16 16:19:35.623153
33	0	1.00	8	2024-02-08 14:31:21.322747
405	0	1.00	8	2024-03-13 16:51:06.840234
520	0	1.00	8	2024-04-15 13:22:55.515901
382	0	1.00	3	2024-03-10 18:09:50.871667
519	0	1.00	8	2024-04-15 13:22:55.130303
496	0	10.00	3	2024-04-09 07:00:53.625043
376	0	1.00	3	2024-03-10 18:05:12.704752
384	0	1.00	3	2024-03-10 18:09:50.871667
385	0	1.00	3	2024-03-10 18:09:50.871667
377	0	1.00	3	2024-03-10 18:05:12.704752
342	0	1.00	7	2024-03-06 14:02:15.121769
567	0	1.00	2	2024-04-30 14:17:16.456045
631	0	1.00	2	2024-05-26 17:23:06.447219
39	0	1.00	4	2024-02-08 15:02:09.857903
623	0	1.00	2	2024-05-20 05:44:09.850926
599	0	1.00	2	2024-05-11 12:54:25.862361
67	0	1.00	8	2024-02-08 17:11:50.449276
610	0	1.00	3	2024-05-18 13:33:19.059646
594	0	1.00	2	2024-05-11 12:54:25.862361
524	0	1.00	8	2024-04-17 13:36:25.376367
188	0	1.00	8	2024-02-17 14:11:51.425393
356	0	1.00	4	2024-03-09 03:40:33.490566
577	0	10.00	2	2024-04-30 14:17:29.468115
549	0	10.00	2	2024-04-26 11:21:47.084987
570	0	10.00	2	2024-04-30 14:17:29.468115
541	0	1.00	10	2024-04-24 16:46:38.232362
569	0	10.00	2	2024-04-30 14:17:29.468115
280	0	1.00	3	2024-02-26 09:26:11.873396
618	0	1.00	2	2024-05-20 05:44:09.850926
510	0	1.00	10	2024-04-13 16:28:03.139897
588	0	1.00	3	2024-05-08 16:08:41.963839
335	0	1.00	3	2024-03-05 08:40:06.142146
568	0	10.00	2	2024-04-30 14:17:29.468115
472	0	1.00	3	2024-04-05 04:26:17.819118
532	0	1.00	3	2024-04-21 14:01:47.316077
554	0	10.00	2	2024-04-26 11:21:47.084987
323	0	1.00	10	2024-03-04 14:34:51.143077
437	0	1.00	7	2024-03-19 13:30:22.786649
523	0	1.00	6	2024-04-16 13:22:10.492902
515	0	1.00	7	2024-04-14 14:40:38.402361
547	0	10.00	2	2024-04-26 11:21:47.084987
471	0	1.00	8	2024-04-04 09:42:04.248402
595	0	1.00	14	2024-05-11 12:54:25.862361
283	0	1.00	8	2024-02-26 15:04:29.030657
181	0	1.00	8	2024-02-17 08:33:51.61661
572	0	10.00	2	2024-04-30 14:17:29.468115
310	0	1.00	4	2024-03-01 09:12:50.070792
315	0	1.00	4	2024-03-02 06:46:40.433233
455	0	1.00	8	2024-03-30 15:10:39.404419
634	0	1.00	2	2024-05-26 17:23:06.447219
573	0	10.00	2	2024-04-30 14:17:29.468115
550	0	10.00	2	2024-04-26 11:21:47.084987
648	0	1.00	10	2024-05-27 16:43:51.806987
576	0	10.00	2	2024-04-30 14:17:29.468115
307	0	1.00	8	2024-03-01 01:40:05.406616
153	0	1.00	3	2024-02-13 15:47:43.212031
530	0	1.00	10	2024-04-19 08:03:40.373298
597	0	1.00	2	2024-05-11 12:54:25.862361
281	0	1.00	8	2024-02-26 09:36:49.329718
309	0	1.00	8	2024-03-01 08:25:41.545372
593	0	1.00	2	2024-05-11 12:54:25.862361
62	0	1.00	8	2024-02-08 16:59:07.681019
103	0	1.00	3	2024-02-09 05:23:48.015332
635	0	1.00	2	2024-05-26 17:23:06.447219
548	0	10.00	2	2024-04-26 11:21:47.084987
619	0	1.00	2	2024-05-20 05:44:09.850926
400	0	1.00	3	2024-03-13 13:42:02.017208
575	0	10.00	2	2024-04-30 14:17:29.468115
564	0	1.00	8	2024-04-29 06:29:42.874429
157	0	1.00	10	2024-02-13 23:57:36.502052
622	0	1.00	2	2024-05-20 05:44:09.850926
647	0	1.00	10	2024-05-27 16:42:39.117526
624	0	1.00	2	2024-05-20 05:44:09.850926
170	0	1.00	10	2024-02-16 04:54:13.019616
621	0	1.00	2	2024-05-20 05:44:09.850926
542	0	1.00	10	2024-04-24 16:46:40.169206
271	0	1.00	4	2024-02-25 14:22:21.38498
636	0	1.00	2	2024-05-26 17:23:06.447219
429	0	1.00	3	2024-03-18 06:26:51.643607
644	0	1.00	4	2024-05-26 17:28:57.088945
611	0	1.00	4	2024-05-19 12:50:59.381759
565	0	1.00	12	2024-04-30 03:28:49.466591
581	0	1.00	4	2024-05-02 09:12:09.66008
553	0	10.00	2	2024-04-26 11:21:47.084987
348	0	1.00	4	2024-03-07 00:12:04.122209
620	0	1.00	2	2024-05-20 05:44:09.850926
546	0	10.00	2	2024-04-26 11:21:47.084987
579	0	1.00	2	2024-05-01 00:49:06.225561
598	0	1.00	2	2024-05-11 12:54:25.862361
545	0	10.00	2	2024-04-26 11:21:47.084987
632	0	1.00	2	2024-05-26 17:23:06.447219
363	0	1.00	8	2024-03-10 13:29:49.900097
551	0	10.00	2	2024-04-26 11:21:47.084987
637	0	1.00	2	2024-05-26 17:23:06.447219
638	0	1.00	2	2024-05-26 17:23:06.447219
571	0	10.00	2	2024-04-30 14:17:29.468115
574	0	10.00	2	2024-04-30 14:17:29.468115
633	0	1.00	2	2024-05-26 17:23:06.447219
639	0	1.00	2	2024-05-26 17:23:06.447219
552	0	10.00	2	2024-04-26 11:21:47.084987
566	0	1.00	3	2024-04-30 07:59:40.886052
640	0	1.00	2	2024-05-26 17:23:06.447219
161	0	1.00	8	2024-02-14 16:27:13.377782
168	0	1.00	8	2024-02-15 17:13:26.954406
506	0	1.00	13	2024-04-11 11:31:48.807046
344	0	1.00	8	2024-03-06 15:55:16.495993
596	0	1.00	2	2024-05-11 12:54:25.862361
601	0	1.00	3	2024-05-11 13:02:55.306002
\.


--
-- Name: users_user_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('users_user_id_seq', 650, true);


--
-- Data for Name: voip_charge_rule_tariff; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY voip_charge_rule_tariff (tariff_id, tariff_name, comment) FROM stdin;
\.


--
-- Name: voip_charge_rule_tariff_tariff_id_seq; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('voip_charge_rule_tariff_tariff_id_seq', 1, false);


--
-- Data for Name: voip_charge_rules; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY voip_charge_rules (charge_id, charge_rule_id, start_time, end_time, time_limit, ras_id, tariff_id) FROM stdin;
\.


--
-- Data for Name: voip_onlines_snapshot; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY voip_onlines_snapshot (snp_date, ras_id, value) FROM stdin;
\.


--
-- Data for Name: voip_users; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY voip_users (user_id, voip_username, voip_password) FROM stdin;
\.


--
-- Data for Name: web_analyzer_log; Type: TABLE DATA; Schema: public; Owner: ibs
--

COPY web_analyzer_log (log_id, _date, user_id, ip_addr, url, elapsed, bytes, miss, hit, successful, failure, _count) FROM stdin;
\.


--
-- Name: web_analyzer_log_log_id; Type: SEQUENCE SET; Schema: public; Owner: ibs
--

SELECT pg_catalog.setval('web_analyzer_log_log_id', 1, false);


--
-- Name: add_user_save_details_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY add_user_save_details
    ADD CONSTRAINT add_user_save_details_pkey PRIMARY KEY (add_user_save_id, user_id);


--
-- Name: add_user_saves_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY add_user_saves
    ADD CONSTRAINT add_user_saves_pkey PRIMARY KEY (add_user_save_id);


--
-- Name: admin_deposit_change_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_deposit_change
    ADD CONSTRAINT admin_deposit_change_pkey PRIMARY KEY (admin_deposit_change_id);


--
-- Name: admin_locks_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_locks
    ADD CONSTRAINT admin_locks_pkey PRIMARY KEY (lock_id);


--
-- Name: admin_messages_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_messages
    ADD CONSTRAINT admin_messages_pkey PRIMARY KEY (message_id);


--
-- Name: admin_perm_templates_detail_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_perm_templates_detail
    ADD CONSTRAINT admin_perm_templates_detail_pkey PRIMARY KEY (template_id, perm_name);


--
-- Name: admin_perm_templates_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_perm_templates
    ADD CONSTRAINT admin_perm_templates_pkey PRIMARY KEY (template_id);


--
-- Name: admin_perms_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admin_perms
    ADD CONSTRAINT admin_perms_pkey PRIMARY KEY (admin_id, perm_name);


--
-- Name: admins_extended_attrs_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admins_extended_attrs
    ADD CONSTRAINT admins_extended_attrs_pkey PRIMARY KEY (admin_id, attr_name);


--
-- Name: admins_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admins
    ADD CONSTRAINT admins_pkey PRIMARY KEY (admin_id);


--
-- Name: admins_username_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY admins
    ADD CONSTRAINT admins_username_key UNIQUE (username);


--
-- Name: bw_interface_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_interface
    ADD CONSTRAINT bw_interface_pkey PRIMARY KEY (interface_id);


--
-- Name: bw_leaf_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_leaf
    ADD CONSTRAINT bw_leaf_pkey PRIMARY KEY (leaf_id);


--
-- Name: bw_leaf_services_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_leaf_services
    ADD CONSTRAINT bw_leaf_services_pkey PRIMARY KEY (leaf_service_id);


--
-- Name: bw_node_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_node
    ADD CONSTRAINT bw_node_pkey PRIMARY KEY (node_id);


--
-- Name: bw_static_ip_ip_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_static_ip
    ADD CONSTRAINT bw_static_ip_ip_key UNIQUE (ip);


--
-- Name: bw_static_ip_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY bw_static_ip
    ADD CONSTRAINT bw_static_ip_pkey PRIMARY KEY (bw_static_ip_id);


--
-- Name: caller_id_users_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY caller_id_users
    ADD CONSTRAINT caller_id_users_pkey PRIMARY KEY (caller_id);


--
-- Name: charge_rule_day_of_weeks_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY charge_rule_day_of_weeks
    ADD CONSTRAINT charge_rule_day_of_weeks_pkey PRIMARY KEY (charge_rule_id, day_of_week);


--
-- Name: charge_rule_ports_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY charge_rule_ports
    ADD CONSTRAINT charge_rule_ports_pkey PRIMARY KEY (charge_rule_id, ras_port);


--
-- Name: charge_rules_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY charge_rules
    ADD CONSTRAINT charge_rules_pkey PRIMARY KEY (charge_rule_id);


--
-- Name: charges_name_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY charges
    ADD CONSTRAINT charges_name_key UNIQUE (name);


--
-- Name: charges_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY charges
    ADD CONSTRAINT charges_pkey PRIMARY KEY (charge_id);


--
-- Name: connection_log_details_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY connection_log_details
    ADD CONSTRAINT connection_log_details_pkey PRIMARY KEY (connection_log_id, name);


--
-- Name: connection_log_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY connection_log
    ADD CONSTRAINT connection_log_pkey PRIMARY KEY (connection_log_id);


--
-- Name: credit_change_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY credit_change
    ADD CONSTRAINT credit_change_pkey PRIMARY KEY (credit_change_id);


--
-- Name: credit_change_userid_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY credit_change_userid
    ADD CONSTRAINT credit_change_userid_pkey PRIMARY KEY (credit_change_id, user_id);


--
-- Name: defs_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY defs
    ADD CONSTRAINT defs_pkey PRIMARY KEY (name);


--
-- Name: group_attrs_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY group_attrs
    ADD CONSTRAINT group_attrs_pkey PRIMARY KEY (group_id, attr_name);


--
-- Name: groups_group_name_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY groups
    ADD CONSTRAINT groups_group_name_key UNIQUE (group_name);


--
-- Name: groups_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY groups
    ADD CONSTRAINT groups_pkey PRIMARY KEY (group_id);


--
-- Name: ias_event_extended_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ias_event_extended
    ADD CONSTRAINT ias_event_extended_pkey PRIMARY KEY (event_id, name);


--
-- Name: ias_event_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ias_event
    ADD CONSTRAINT ias_event_pkey PRIMARY KEY (event_id);


--
-- Name: ibs_states_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ibs_states
    ADD CONSTRAINT ibs_states_pkey PRIMARY KEY (name);


--
-- Name: internet_bw_snapshot_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY internet_bw_snapshot
    ADD CONSTRAINT internet_bw_snapshot_pkey PRIMARY KEY (user_id, snp_date);


--
-- Name: internet_charge_rules_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY internet_charge_rules
    ADD CONSTRAINT internet_charge_rules_pkey PRIMARY KEY (charge_rule_id);


--
-- Name: internet_onlines_snapshot_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY internet_onlines_snapshot
    ADD CONSTRAINT internet_onlines_snapshot_pkey PRIMARY KEY (snp_date, ras_id);


--
-- Name: ippool_ips_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ippool_ips
    ADD CONSTRAINT ippool_ips_pkey PRIMARY KEY (ippool_id, ip);


--
-- Name: ippool_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ippool
    ADD CONSTRAINT ippool_pkey PRIMARY KEY (ippool_id);


--
-- Name: normal_users_normal_username_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY normal_users
    ADD CONSTRAINT normal_users_normal_username_key UNIQUE (normal_username);


--
-- Name: persistent_lan_users_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY persistent_lan_users
    ADD CONSTRAINT persistent_lan_users_pkey PRIMARY KEY (persistent_lan_mac, persistent_lan_ip);


--
-- Name: ras_attrs_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras_attrs
    ADD CONSTRAINT ras_attrs_pkey PRIMARY KEY (ras_id, attr_name);


--
-- Name: ras_ippools_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras_ippools
    ADD CONSTRAINT ras_ippools_pkey PRIMARY KEY (serial);


--
-- Name: ras_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras
    ADD CONSTRAINT ras_pkey PRIMARY KEY (ras_id);


--
-- Name: ras_ports_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras_ports
    ADD CONSTRAINT ras_ports_pkey PRIMARY KEY (ras_id, port_name);


--
-- Name: ras_ras_description_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras
    ADD CONSTRAINT ras_ras_description_key UNIQUE (ras_description);


--
-- Name: ras_ras_ip_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY ras
    ADD CONSTRAINT ras_ras_ip_key UNIQUE (ras_ip);


--
-- Name: tariff_prefix_list_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY tariff_prefix_list
    ADD CONSTRAINT tariff_prefix_list_pkey PRIMARY KEY (prefix_id);


--
-- Name: user_attrs_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY user_attrs
    ADD CONSTRAINT user_attrs_pkey PRIMARY KEY (user_id, attr_name);


--
-- Name: user_audit_log_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY user_audit_log
    ADD CONSTRAINT user_audit_log_pkey PRIMARY KEY (user_audit_log);


--
-- Name: user_messages_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY user_messages
    ADD CONSTRAINT user_messages_pkey PRIMARY KEY (message_id);


--
-- Name: users_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_pkey PRIMARY KEY (user_id);


--
-- Name: voip_charge_rule_tariff_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY voip_charge_rule_tariff
    ADD CONSTRAINT voip_charge_rule_tariff_pkey PRIMARY KEY (tariff_id);


--
-- Name: voip_charge_rules_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY voip_charge_rules
    ADD CONSTRAINT voip_charge_rules_pkey PRIMARY KEY (charge_rule_id);


--
-- Name: voip_onlines_snapshot_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY voip_onlines_snapshot
    ADD CONSTRAINT voip_onlines_snapshot_pkey PRIMARY KEY (snp_date, ras_id);


--
-- Name: voip_users_voip_username_key; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY voip_users
    ADD CONSTRAINT voip_users_voip_username_key UNIQUE (voip_username);


--
-- Name: web_analyzer_log_pkey; Type: CONSTRAINT; Schema: public; Owner: ibs; Tablespace: 
--

ALTER TABLE ONLY web_analyzer_log
    ADD CONSTRAINT web_analyzer_log_pkey PRIMARY KEY (log_id);


--
-- Name: caller_id_users_user_id; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX caller_id_users_user_id ON caller_id_users USING btree (user_id);


--
-- Name: connection_log_details_name_value_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX connection_log_details_name_value_index ON connection_log_details USING btree (name, value);


--
-- Name: connection_log_login_time_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX connection_log_login_time_index ON connection_log USING btree (login_time);


--
-- Name: connection_log_userid_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX connection_log_userid_index ON connection_log USING btree (user_id);


--
-- Name: credit_change_userid_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX credit_change_userid_index ON credit_change_userid USING btree (user_id);


--
-- Name: group_attrs_name_value; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX group_attrs_name_value ON group_attrs USING btree (attr_name, attr_value);


--
-- Name: ippool_ips_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX ippool_ips_index ON ippool_ips USING btree (ippool_id, ip);


--
-- Name: normal_users_user_id; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX normal_users_user_id ON normal_users USING btree (user_id);


--
-- Name: persistent_lan_ras_id_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX persistent_lan_ras_id_index ON persistent_lan_users USING btree (persistent_lan_ras_id);


--
-- Name: persistent_lan_user_id; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX persistent_lan_user_id ON persistent_lan_users USING btree (user_id);


--
-- Name: prefix_name_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX prefix_name_index ON tariff_prefix_list USING btree (tariff_id, prefix_code);


--
-- Name: ras_attrs_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX ras_attrs_index ON ras_attrs USING btree (ras_id, attr_name);


--
-- Name: ras_ports_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX ras_ports_index ON ras_ports USING btree (ras_id, port_name);


--
-- Name: user_attrs_abs_exp_date; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX user_attrs_abs_exp_date ON user_attrs USING btree (attr_name, ((attr_value)::bigint)) WHERE (attr_name = ANY (ARRAY['abs_exp_date'::text, 'first_login'::text]));


--
-- Name: user_attrs_name_value; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX user_attrs_name_value ON user_attrs USING btree (attr_name, attr_value);


--
-- Name: users_group_id; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX users_group_id ON users USING btree (group_id);


--
-- Name: voip_users_user_id; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE UNIQUE INDEX voip_users_user_id ON voip_users USING btree (user_id);


--
-- Name: web_analyzer_log_date_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX web_analyzer_log_date_index ON web_analyzer_log USING btree (_date);


--
-- Name: web_analyzer_log_user_id_index; Type: INDEX; Schema: public; Owner: ibs; Tablespace: 
--

CREATE INDEX web_analyzer_log_user_id_index ON web_analyzer_log USING btree (user_id);


--
-- Name: system_admin; Type: RULE; Schema: public; Owner: ibs
--

CREATE RULE system_admin AS ON DELETE TO admins WHERE (old.admin_id = 0) DO INSTEAD NOTHING;


--
-- Name: system_admin_god; Type: RULE; Schema: public; Owner: ibs
--

CREATE RULE system_admin_god AS ON DELETE TO admin_perms WHERE ((old.admin_id = 0) AND (old.perm_name = 'GOD'::text)) DO INSTEAD NOTHING;


--
-- Name: add_user_save_details_add_user_save_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY add_user_save_details
    ADD CONSTRAINT add_user_save_details_add_user_save_id_fkey FOREIGN KEY (add_user_save_id) REFERENCES add_user_saves(add_user_save_id);


--
-- Name: add_user_saves_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY add_user_saves
    ADD CONSTRAINT add_user_saves_admin_id_fkey FOREIGN KEY (admin_id) REFERENCES admins(admin_id);


--
-- Name: admin_locks_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admin_locks
    ADD CONSTRAINT admin_locks_admin_id_fkey FOREIGN KEY (admin_id) REFERENCES admins(admin_id);


--
-- Name: admin_locks_locker_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admin_locks
    ADD CONSTRAINT admin_locks_locker_admin_id_fkey FOREIGN KEY (locker_admin_id) REFERENCES admins(admin_id);


--
-- Name: admin_messages_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admin_messages
    ADD CONSTRAINT admin_messages_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: admin_perm_templates_detail_template_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admin_perm_templates_detail
    ADD CONSTRAINT admin_perm_templates_detail_template_id_fkey FOREIGN KEY (template_id) REFERENCES admin_perm_templates(template_id);


--
-- Name: admin_perms_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admin_perms
    ADD CONSTRAINT admin_perms_admin_id_fkey FOREIGN KEY (admin_id) REFERENCES admins(admin_id);


--
-- Name: admins_extended_attrs_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY admins_extended_attrs
    ADD CONSTRAINT admins_extended_attrs_admin_id_fkey FOREIGN KEY (admin_id) REFERENCES admins(admin_id);


--
-- Name: bw_leaf_interface_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_leaf
    ADD CONSTRAINT bw_leaf_interface_id_fkey FOREIGN KEY (interface_id) REFERENCES bw_interface(interface_id);


--
-- Name: bw_leaf_parent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_leaf
    ADD CONSTRAINT bw_leaf_parent_id_fkey FOREIGN KEY (parent_id) REFERENCES bw_node(node_id);


--
-- Name: bw_leaf_services_leaf_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_leaf_services
    ADD CONSTRAINT bw_leaf_services_leaf_id_fkey FOREIGN KEY (leaf_id) REFERENCES bw_leaf(leaf_id);


--
-- Name: bw_node_interface_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_node
    ADD CONSTRAINT bw_node_interface_id_fkey FOREIGN KEY (interface_id) REFERENCES bw_interface(interface_id);


--
-- Name: bw_node_parent_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_node
    ADD CONSTRAINT bw_node_parent_id_fkey FOREIGN KEY (parent_id) REFERENCES bw_node(node_id);


--
-- Name: bw_static_ip_receive_leaf_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_static_ip
    ADD CONSTRAINT bw_static_ip_receive_leaf_id_fkey FOREIGN KEY (receive_leaf_id) REFERENCES bw_leaf(leaf_id);


--
-- Name: bw_static_ip_transmit_leaf_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY bw_static_ip
    ADD CONSTRAINT bw_static_ip_transmit_leaf_id_fkey FOREIGN KEY (transmit_leaf_id) REFERENCES bw_leaf(leaf_id);


--
-- Name: caller_id_users_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY caller_id_users
    ADD CONSTRAINT caller_id_users_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: charge_rules_charge_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY charge_rules
    ADD CONSTRAINT charge_rules_charge_id_fkey FOREIGN KEY (charge_id) REFERENCES charges(charge_id);


--
-- Name: charge_rules_ras_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY charge_rules
    ADD CONSTRAINT charge_rules_ras_id_fkey FOREIGN KEY (ras_id) REFERENCES ras(ras_id);


--
-- Name: charges_admin_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY charges
    ADD CONSTRAINT charges_admin_id_fkey FOREIGN KEY (admin_id) REFERENCES admins(admin_id);


--
-- Name: connection_log_details_connection_log_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY connection_log_details
    ADD CONSTRAINT connection_log_details_connection_log_id_fkey FOREIGN KEY (connection_log_id) REFERENCES connection_log(connection_log_id);


--
-- Name: credit_change_userid_credit_change_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY credit_change_userid
    ADD CONSTRAINT credit_change_userid_credit_change_id_fkey FOREIGN KEY (credit_change_id) REFERENCES credit_change(credit_change_id);


--
-- Name: group_attrs_group_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY group_attrs
    ADD CONSTRAINT group_attrs_group_id_fkey FOREIGN KEY (group_id) REFERENCES groups(group_id);


--
-- Name: groups_owner_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY groups
    ADD CONSTRAINT groups_owner_id_fkey FOREIGN KEY (owner_id) REFERENCES admins(admin_id);


--
-- Name: ias_event_extended_event_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ias_event_extended
    ADD CONSTRAINT ias_event_extended_event_id_fkey FOREIGN KEY (event_id) REFERENCES ias_event(event_id);


--
-- Name: internet_bw_snapshot_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY internet_bw_snapshot
    ADD CONSTRAINT internet_bw_snapshot_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: internet_charge_rules_bw_receive_leaf_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY internet_charge_rules
    ADD CONSTRAINT internet_charge_rules_bw_receive_leaf_id_fkey FOREIGN KEY (bw_receive_leaf_id) REFERENCES bw_leaf(leaf_id);


--
-- Name: internet_charge_rules_bw_transmit_leaf_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY internet_charge_rules
    ADD CONSTRAINT internet_charge_rules_bw_transmit_leaf_id_fkey FOREIGN KEY (bw_transmit_leaf_id) REFERENCES bw_leaf(leaf_id);


--
-- Name: ippool_ips_ippool_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ippool_ips
    ADD CONSTRAINT ippool_ips_ippool_id_fkey FOREIGN KEY (ippool_id) REFERENCES ippool(ippool_id);


--
-- Name: normal_users_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY normal_users
    ADD CONSTRAINT normal_users_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: persistent_lan_users_persistent_lan_ras_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY persistent_lan_users
    ADD CONSTRAINT persistent_lan_users_persistent_lan_ras_id_fkey FOREIGN KEY (persistent_lan_ras_id) REFERENCES ras(ras_id);


--
-- Name: persistent_lan_users_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY persistent_lan_users
    ADD CONSTRAINT persistent_lan_users_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: ras_attrs_ras_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ras_attrs
    ADD CONSTRAINT ras_attrs_ras_id_fkey FOREIGN KEY (ras_id) REFERENCES ras(ras_id);


--
-- Name: ras_ippools_ippool_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ras_ippools
    ADD CONSTRAINT ras_ippools_ippool_id_fkey FOREIGN KEY (ippool_id) REFERENCES ippool(ippool_id);


--
-- Name: ras_ippools_ras_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ras_ippools
    ADD CONSTRAINT ras_ippools_ras_id_fkey FOREIGN KEY (ras_id) REFERENCES ras(ras_id);


--
-- Name: ras_ports_ras_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY ras_ports
    ADD CONSTRAINT ras_ports_ras_id_fkey FOREIGN KEY (ras_id) REFERENCES ras(ras_id);


--
-- Name: tariff_prefix_list_tariff_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY tariff_prefix_list
    ADD CONSTRAINT tariff_prefix_list_tariff_id_fkey FOREIGN KEY (tariff_id) REFERENCES voip_charge_rule_tariff(tariff_id);


--
-- Name: user_attrs_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY user_attrs
    ADD CONSTRAINT user_attrs_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: user_messages_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY user_messages
    ADD CONSTRAINT user_messages_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: users_owner_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY users
    ADD CONSTRAINT users_owner_id_fkey FOREIGN KEY (owner_id) REFERENCES admins(admin_id);


--
-- Name: voip_charge_rules_tariff_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY voip_charge_rules
    ADD CONSTRAINT voip_charge_rules_tariff_id_fkey FOREIGN KEY (tariff_id) REFERENCES voip_charge_rule_tariff(tariff_id);


--
-- Name: voip_users_user_id_fkey; Type: FK CONSTRAINT; Schema: public; Owner: ibs
--

ALTER TABLE ONLY voip_users
    ADD CONSTRAINT voip_users_user_id_fkey FOREIGN KEY (user_id) REFERENCES users(user_id);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

